"use strict";(self.webpackChunk_N_E=self.webpackChunk_N_E||[]).push([[616],{23541:function(e,t,n){n.d(t,{Ry:function(){return s}});var r=new WeakMap,o=new WeakMap,i={},a=0,l=function(e){return e&&(e.host||l(e.parentNode))},u=function(e,t,n,u){var s=(Array.isArray(e)?e:[e]).map(function(e){if(t.contains(e))return e;var n=l(e);return n&&t.contains(n)?n:(console.error("aria-hidden",e,"in not contained inside",t,". Doing nothing"),null)}).filter(function(e){return!!e});i[n]||(i[n]=new WeakMap);var c=i[n],d=[],f=new Set,p=new Set(s),m=function(e){!e||f.has(e)||(f.add(e),m(e.parentNode))};s.forEach(m);var h=function(e){!e||p.has(e)||Array.prototype.forEach.call(e.children,function(e){if(f.has(e))h(e);else try{var t=e.getAttribute(u),i=null!==t&&"false"!==t,a=(r.get(e)||0)+1,l=(c.get(e)||0)+1;r.set(e,a),c.set(e,l),d.push(e),1===a&&i&&o.set(e,!0),1===l&&e.setAttribute(n,"true"),i||e.setAttribute(u,"true")}catch(t){console.error("aria-hidden: cannot operate on ",e,t)}})};return h(t),f.clear(),a++,function(){d.forEach(function(e){var t=r.get(e)-1,i=c.get(e)-1;r.set(e,t),c.set(e,i),t||(o.has(e)||e.removeAttribute(u),o.delete(e)),i||e.removeAttribute(n)}),--a||(r=new WeakMap,r=new WeakMap,o=new WeakMap,i={})}},s=function(e,t,n){void 0===n&&(n="data-aria-hidden");var r=Array.from(Array.isArray(e)?e:[e]),o=t||("undefined"==typeof document?null:(Array.isArray(e)?e[0]:e).ownerDocument.body);return o?(r.push.apply(r,Array.from(o.querySelectorAll("[aria-live], script"))),u(r,o,n,"aria-hidden")):function(){return null}}},60998:function(e,t,n){n.d(t,{Z:function(){return u}});var r=n(67294);/**
 * @license lucide-react v0.407.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */let o=e=>e.replace(/([a-z0-9])([A-Z])/g,"$1-$2").toLowerCase(),i=function(){for(var e=arguments.length,t=Array(e),n=0;n<e;n++)t[n]=arguments[n];return t.filter((e,t,n)=>!!e&&n.indexOf(e)===t).join(" ")};/**
 * @license lucide-react v0.407.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */var a={xmlns:"http://www.w3.org/2000/svg",width:24,height:24,viewBox:"0 0 24 24",fill:"none",stroke:"currentColor",strokeWidth:2,strokeLinecap:"round",strokeLinejoin:"round"};/**
 * @license lucide-react v0.407.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */let l=(0,r.forwardRef)((e,t)=>{let{color:n="currentColor",size:o=24,strokeWidth:l=2,absoluteStrokeWidth:u,className:s="",children:c,iconNode:d,...f}=e;return(0,r.createElement)("svg",{ref:t,...a,width:o,height:o,stroke:n,strokeWidth:u?24*Number(l)/Number(o):l,className:i("lucide",s),...f},[...d.map(e=>{let[t,n]=e;return(0,r.createElement)(t,n)}),...Array.isArray(c)?c:[c]])}),u=(e,t)=>{let n=(0,r.forwardRef)((n,a)=>{let{className:u,...s}=n;return(0,r.createElement)(l,{ref:a,iconNode:t,className:i("lucide-".concat(o(e)),u),...s})});return n.displayName="".concat(e),n}},70282:function(e,t,n){n.d(t,{Z:function(){return r}});/**
 * @license lucide-react v0.407.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */let r=(0,n(60998).Z)("Check",[["path",{d:"M20 6 9 17l-5-5",key:"1gmf2c"}]])},45895:function(e,t,n){n.d(t,{Z:function(){return r}});/**
 * @license lucide-react v0.407.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */let r=(0,n(60998).Z)("ChevronDown",[["path",{d:"m6 9 6 6 6-6",key:"qrunsl"}]])},7242:function(e,t,n){n.d(t,{Z:function(){return r}});/**
 * @license lucide-react v0.407.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */let r=(0,n(60998).Z)("ChevronUp",[["path",{d:"m18 15-6-6-6 6",key:"153udz"}]])},6223:function(e,t,n){n.d(t,{Z:function(){return Z}});var r,o,i,a,l,u,s,c=function(){return(c=Object.assign||function(e){for(var t,n=1,r=arguments.length;n<r;n++)for(var o in t=arguments[n])Object.prototype.hasOwnProperty.call(t,o)&&(e[o]=t[o]);return e}).apply(this,arguments)};function d(e,t){var n={};for(var r in e)Object.prototype.hasOwnProperty.call(e,r)&&0>t.indexOf(r)&&(n[r]=e[r]);if(null!=e&&"function"==typeof Object.getOwnPropertySymbols)for(var o=0,r=Object.getOwnPropertySymbols(e);o<r.length;o++)0>t.indexOf(r[o])&&Object.prototype.propertyIsEnumerable.call(e,r[o])&&(n[r[o]]=e[r[o]]);return n}"function"==typeof SuppressedError&&SuppressedError;var f=n(67294),p="right-scroll-bar-position",m="width-before-scroll-bar";function h(e,t){return"function"==typeof e?e(t):e&&(e.current=t),e}var v="undefined"!=typeof window?f.useLayoutEffect:f.useEffect,g=new WeakMap,b=(void 0===o&&(o={}),(void 0===i&&(i=function(e){return e}),a=[],l=!1,u={read:function(){if(l)throw Error("Sidecar: could not `read` from an `assigned` medium. `read` could be used only with `useMedium`.");return a.length?a[a.length-1]:null},useMedium:function(e){var t=i(e,l);return a.push(t),function(){a=a.filter(function(e){return e!==t})}},assignSyncMedium:function(e){for(l=!0;a.length;){var t=a;a=[],t.forEach(e)}a={push:function(t){return e(t)},filter:function(){return a}}},assignMedium:function(e){l=!0;var t=[];if(a.length){var n=a;a=[],n.forEach(e),t=a}var r=function(){var n=t;t=[],n.forEach(e)},o=function(){return Promise.resolve().then(r)};o(),a={push:function(e){t.push(e),o()},filter:function(e){return t=t.filter(e),a}}}}).options=c({async:!0,ssr:!1},o),u),y=function(){},w=f.forwardRef(function(e,t){var n,r,o,i,a=f.useRef(null),l=f.useState({onScrollCapture:y,onWheelCapture:y,onTouchMoveCapture:y}),u=l[0],s=l[1],p=e.forwardProps,m=e.children,w=e.className,x=e.removeScrollBar,E=e.enabled,C=e.shards,S=e.sideCar,M=e.noRelative,k=e.noIsolation,T=e.inert,P=e.allowPinchZoom,R=e.as,L=e.gapMode,j=d(e,["forwardProps","children","className","removeScrollBar","enabled","shards","sideCar","noRelative","noIsolation","inert","allowPinchZoom","as","gapMode"]),A=(n=[a,t],r=function(e){return n.forEach(function(t){return h(t,e)})},(o=(0,f.useState)(function(){return{value:null,callback:r,facade:{get current(){return o.value},set current(value){var e=o.value;e!==value&&(o.value=value,o.callback(value,e))}}}})[0]).callback=r,i=o.facade,v(function(){var e=g.get(i);if(e){var t=new Set(e),r=new Set(n),o=i.current;t.forEach(function(e){r.has(e)||h(e,null)}),r.forEach(function(e){t.has(e)||h(e,o)})}g.set(i,n)},[n]),i),O=c(c({},j),u);return f.createElement(f.Fragment,null,E&&f.createElement(S,{sideCar:b,removeScrollBar:x,shards:C,noRelative:M,noIsolation:k,inert:T,setCallbacks:s,allowPinchZoom:!!P,lockRef:a,gapMode:L}),p?f.cloneElement(f.Children.only(m),c(c({},O),{ref:A})):f.createElement(void 0===R?"div":R,c({},O,{className:w,ref:A}),m))});w.defaultProps={enabled:!0,removeScrollBar:!0,inert:!1},w.classNames={fullWidth:m,zeroRight:p};var x=function(e){var t=e.sideCar,n=d(e,["sideCar"]);if(!t)throw Error("Sidecar: please provide `sideCar` property to import the right car");var r=t.read();if(!r)throw Error("Sidecar medium not found");return f.createElement(r,c({},n))};x.isSideCarExport=!0;var E=function(){var e=0,t=null;return{add:function(o){if(0==e&&(t=function(){if(!document)return null;var e=document.createElement("style");e.type="text/css";var t=r||n.nc;return t&&e.setAttribute("nonce",t),e}())){var i,a;(i=t).styleSheet?i.styleSheet.cssText=o:i.appendChild(document.createTextNode(o)),a=t,(document.head||document.getElementsByTagName("head")[0]).appendChild(a)}e++},remove:function(){--e||!t||(t.parentNode&&t.parentNode.removeChild(t),t=null)}}},C=function(){var e=E();return function(t,n){f.useEffect(function(){return e.add(t),function(){e.remove()}},[t&&n])}},S=function(){var e=C();return function(t){return e(t.styles,t.dynamic),null}},M={left:0,top:0,right:0,gap:0},k=function(e){return parseInt(e||"",10)||0},T=function(e){var t=window.getComputedStyle(document.body),n=t["padding"===e?"paddingLeft":"marginLeft"],r=t["padding"===e?"paddingTop":"marginTop"],o=t["padding"===e?"paddingRight":"marginRight"];return[k(n),k(r),k(o)]},P=function(e){if(void 0===e&&(e="margin"),"undefined"==typeof window)return M;var t=T(e),n=document.documentElement.clientWidth,r=window.innerWidth;return{left:t[0],top:t[1],right:t[2],gap:Math.max(0,r-n+t[2]-t[0])}},R=S(),L="data-scroll-locked",j=function(e,t,n,r){var o=e.left,i=e.top,a=e.right,l=e.gap;return void 0===n&&(n="margin"),"\n  .".concat("with-scroll-bars-hidden"," {\n   overflow: hidden ").concat(r,";\n   padding-right: ").concat(l,"px ").concat(r,";\n  }\n  body[").concat(L,"] {\n    overflow: hidden ").concat(r,";\n    overscroll-behavior: contain;\n    ").concat([t&&"position: relative ".concat(r,";"),"margin"===n&&"\n    padding-left: ".concat(o,"px;\n    padding-top: ").concat(i,"px;\n    padding-right: ").concat(a,"px;\n    margin-left:0;\n    margin-top:0;\n    margin-right: ").concat(l,"px ").concat(r,";\n    "),"padding"===n&&"padding-right: ".concat(l,"px ").concat(r,";")].filter(Boolean).join(""),"\n  }\n  \n  .").concat(p," {\n    right: ").concat(l,"px ").concat(r,";\n  }\n  \n  .").concat(m," {\n    margin-right: ").concat(l,"px ").concat(r,";\n  }\n  \n  .").concat(p," .").concat(p," {\n    right: 0 ").concat(r,";\n  }\n  \n  .").concat(m," .").concat(m," {\n    margin-right: 0 ").concat(r,";\n  }\n  \n  body[").concat(L,"] {\n    ").concat("--removed-body-scroll-bar-size",": ").concat(l,"px;\n  }\n")},A=function(){var e=parseInt(document.body.getAttribute(L)||"0",10);return isFinite(e)?e:0},O=function(){f.useEffect(function(){return document.body.setAttribute(L,(A()+1).toString()),function(){var e=A()-1;e<=0?document.body.removeAttribute(L):document.body.setAttribute(L,e.toString())}},[])},D=function(e){var t=e.noRelative,n=e.noImportant,r=e.gapMode,o=void 0===r?"margin":r;O();var i=f.useMemo(function(){return P(o)},[o]);return f.createElement(R,{styles:j(i,!t,o,n?"":"!important")})},W=!1;if("undefined"!=typeof window)try{var N=Object.defineProperty({},"passive",{get:function(){return W=!0,!0}});window.addEventListener("test",N,N),window.removeEventListener("test",N,N)}catch(e){W=!1}var I=!!W&&{passive:!1},_=function(e,t){if(!(e instanceof Element))return!1;var n=window.getComputedStyle(e);return"hidden"!==n[t]&&!(n.overflowY===n.overflowX&&"TEXTAREA"!==e.tagName&&"visible"===n[t])},z=function(e,t){var n=t.ownerDocument,r=t;do{if("undefined"!=typeof ShadowRoot&&r instanceof ShadowRoot&&(r=r.host),F(e,r)){var o=H(e,r);if(o[1]>o[2])return!0}r=r.parentNode}while(r&&r!==n.body);return!1},F=function(e,t){return"v"===e?_(t,"overflowY"):_(t,"overflowX")},H=function(e,t){return"v"===e?[t.scrollTop,t.scrollHeight,t.clientHeight]:[t.scrollLeft,t.scrollWidth,t.clientWidth]},$=function(e,t,n,r,o){var i,a=(i=window.getComputedStyle(t).direction,"h"===e&&"rtl"===i?-1:1),l=a*r,u=n.target,s=t.contains(u),c=!1,d=l>0,f=0,p=0;do{if(!u)break;var m=H(e,u),h=m[0],v=m[1]-m[2]-a*h;(h||v)&&F(e,u)&&(f+=v,p+=h);var g=u.parentNode;u=g&&g.nodeType===Node.DOCUMENT_FRAGMENT_NODE?g.host:g}while(!s&&u!==document.body||s&&(t.contains(u)||t===u));return d&&(o&&1>Math.abs(f)||!o&&l>f)?c=!0:!d&&(o&&1>Math.abs(p)||!o&&-l>p)&&(c=!0),c},V=function(e){return"changedTouches"in e?[e.changedTouches[0].clientX,e.changedTouches[0].clientY]:[0,0]},B=function(e){return[e.deltaX,e.deltaY]},X=function(e){return e&&"current"in e?e.current:e},Y=0,U=[],q=(s=function(e){var t=f.useRef([]),n=f.useRef([0,0]),r=f.useRef(),o=f.useState(Y++)[0],i=f.useState(S)[0],a=f.useRef(e);f.useEffect(function(){a.current=e},[e]),f.useEffect(function(){if(e.inert){document.body.classList.add("block-interactivity-".concat(o));var t=(function(e,t,n){if(n||2==arguments.length)for(var r,o=0,i=t.length;o<i;o++)!r&&o in t||(r||(r=Array.prototype.slice.call(t,0,o)),r[o]=t[o]);return e.concat(r||Array.prototype.slice.call(t))})([e.lockRef.current],(e.shards||[]).map(X),!0).filter(Boolean);return t.forEach(function(e){return e.classList.add("allow-interactivity-".concat(o))}),function(){document.body.classList.remove("block-interactivity-".concat(o)),t.forEach(function(e){return e.classList.remove("allow-interactivity-".concat(o))})}}},[e.inert,e.lockRef.current,e.shards]);var l=f.useCallback(function(e,t){if("touches"in e&&2===e.touches.length||"wheel"===e.type&&e.ctrlKey)return!a.current.allowPinchZoom;var o,i=V(e),l=n.current,u="deltaX"in e?e.deltaX:l[0]-i[0],s="deltaY"in e?e.deltaY:l[1]-i[1],c=e.target,d=Math.abs(u)>Math.abs(s)?"h":"v";if("touches"in e&&"h"===d&&"range"===c.type)return!1;var f=z(d,c);if(!f)return!0;if(f?o=d:(o="v"===d?"h":"v",f=z(d,c)),!f)return!1;if(!r.current&&"changedTouches"in e&&(u||s)&&(r.current=o),!o)return!0;var p=r.current||o;return $(p,t,e,"h"===p?u:s,!0)},[]),u=f.useCallback(function(e){if(U.length&&U[U.length-1]===i){var n="deltaY"in e?B(e):V(e),r=t.current.filter(function(t){var r;return t.name===e.type&&(t.target===e.target||e.target===t.shadowParent)&&(r=t.delta)[0]===n[0]&&r[1]===n[1]})[0];if(r&&r.should){e.cancelable&&e.preventDefault();return}if(!r){var o=(a.current.shards||[]).map(X).filter(Boolean).filter(function(t){return t.contains(e.target)});(o.length>0?l(e,o[0]):!a.current.noIsolation)&&e.cancelable&&e.preventDefault()}}},[]),s=f.useCallback(function(e,n,r,o){var i={name:e,delta:n,target:r,should:o,shadowParent:function(e){for(var t=null;null!==e;)e instanceof ShadowRoot&&(t=e.host,e=e.host),e=e.parentNode;return t}(r)};t.current.push(i),setTimeout(function(){t.current=t.current.filter(function(e){return e!==i})},1)},[]),c=f.useCallback(function(e){n.current=V(e),r.current=void 0},[]),d=f.useCallback(function(t){s(t.type,B(t),t.target,l(t,e.lockRef.current))},[]),p=f.useCallback(function(t){s(t.type,V(t),t.target,l(t,e.lockRef.current))},[]);f.useEffect(function(){return U.push(i),e.setCallbacks({onScrollCapture:d,onWheelCapture:d,onTouchMoveCapture:p}),document.addEventListener("wheel",u,I),document.addEventListener("touchmove",u,I),document.addEventListener("touchstart",c,I),function(){U=U.filter(function(e){return e!==i}),document.removeEventListener("wheel",u,I),document.removeEventListener("touchmove",u,I),document.removeEventListener("touchstart",c,I)}},[]);var m=e.removeScrollBar,h=e.inert;return f.createElement(f.Fragment,null,h?f.createElement(i,{styles:"\n  .block-interactivity-".concat(o," {pointer-events: none;}\n  .allow-interactivity-").concat(o," {pointer-events: all;}\n")}):null,m?f.createElement(D,{noRelative:e.noRelative,gapMode:e.gapMode}):null)},b.useMedium(s),x),K=f.forwardRef(function(e,t){return f.createElement(w,c({},e,{ref:t,sideCar:q}))});K.classNames=w.classNames;var Z=K},53302:function(e,t,n){let r,o,i;n.d(t,{e:function(){return rb}});var a,l,u,s,c,d,f=n(67294);let p={},m=0,h=!1,v=null,g=null,b="undefined"!=typeof document?f.useLayoutEffect:()=>{},y={prefix:String(Math.round(1e10*Math.random())),current:0},w=f.createContext(y),x=f.createContext(!1);"undefined"!=typeof window&&window.document&&window.document.createElement;let E=new WeakMap,C="function"==typeof f.useId?function(e){let t=f.useId(),[n]=(0,f.useState)(T()),r=n?"react-aria":`react-aria${y.prefix}`;return e||`${r}-${t}`}:function(e){let t=(0,f.useContext)(w),n=function(e=!1){let t=(0,f.useContext)(w),n=(0,f.useRef)(null);if(null===n.current&&!e){var r,o;let e=null===(o=f.__SECRET_INTERNALS_DO_NOT_USE_OR_YOU_WILL_BE_FIRED)||void 0===o?void 0:null===(r=o.ReactCurrentOwner)||void 0===r?void 0:r.current;if(e){let n=E.get(e);null==n?E.set(e,{id:t.current,state:e.memoizedState}):e.memoizedState!==n.state&&(t.current=n.id,E.delete(e))}n.current=++t.current}return n.current}(!!e),r=`react-aria${t.prefix}`;return e||`${r}-${n}`};function S(){return!1}function M(){return!0}function k(e){return()=>{}}function T(){return"function"==typeof f.useSyncExternalStore?f.useSyncExternalStore(k,S,M):(0,f.useContext)(x)}let P=!!("undefined"!=typeof window&&window.document&&window.document.createElement),R=new Map;var L=n(90512);function j(...e){let t={...e[0]};for(let n=1;n<e.length;n++){let r=e[n];for(let e in r){let n=t[e],o=r[e];"function"==typeof n&&"function"==typeof o&&"o"===e[0]&&"n"===e[1]&&e.charCodeAt(2)>=65&&90>=e.charCodeAt(2)?t[e]=function(...e){return(...t)=>{for(let n of e)"function"==typeof n&&n(...t)}}(n,o):("className"===e||"UNSAFE_className"===e)&&"string"==typeof n&&"string"==typeof o?t[e]=(0,L.Z)(n,o):"id"===e&&n&&o?t.id=function(e,t){if(e===t)return e;let n=R.get(e);if(n)return n.forEach(e=>e(t)),t;let r=R.get(t);return r?(r.forEach(t=>t(e)),e):t}(n,o):t[e]=void 0!==o?o:n}}return t}function A(e){var t;return"undefined"!=typeof window&&null!=window.navigator&&((null===(t=window.navigator.userAgentData)||void 0===t?void 0:t.brands.some(t=>e.test(t.brand)))||e.test(window.navigator.userAgent))}function O(e){var t;return"undefined"!=typeof window&&null!=window.navigator&&e.test((null===(t=window.navigator.userAgentData)||void 0===t?void 0:t.platform)||window.navigator.platform)}function D(e){let t=null;return()=>(null==t&&(t=e()),t)}let W=D(function(){return O(/^Mac/i)}),N=D(function(){return O(/^iPhone/i)}),I=D(function(){return O(/^iPad/i)||W()&&navigator.maxTouchPoints>1}),_=D(function(){return N()||I()});D(function(){return W()||_()});let z=D(function(){return A(/AppleWebKit/i)&&!F()}),F=D(function(){return A(/Chrome/i)}),H=D(function(){return A(/Android/i)});D(function(){return A(/Firefox/i)});let $=e=>{var t;return null!==(t=null==e?void 0:e.ownerDocument)&&void 0!==t?t:document},V=e=>e&&"window"in e&&e.window===e?e:$(e).defaultView||window,B=null,X=new Set,Y=new Map,U=!1,q=!1;function K(e,t){for(let n of X)n(e,t)}function Z(e){U=!0,e.metaKey||!W()&&e.altKey||e.ctrlKey||"Control"===e.key||"Shift"===e.key||"Meta"===e.key||(B="keyboard",K("keyboard",e))}function G(e){B="pointer",("mousedown"===e.type||"pointerdown"===e.type)&&(U=!0,K("pointer",e))}function J(e){(0===e.mozInputSource&&e.isTrusted||(H()&&e.pointerType?"click"===e.type&&1===e.buttons:0===e.detail&&!e.pointerType))&&(U=!0,B="virtual")}function Q(e){e.target!==window&&e.target!==document&&(U||q||(B="virtual",K("virtual",e)),U=!1,q=!1)}function ee(){U=!1,q=!0}function et(e){if("undefined"==typeof window||Y.get(V(e)))return;let t=V(e),n=$(e),r=t.HTMLElement.prototype.focus;t.HTMLElement.prototype.focus=function(){U=!0,r.apply(this,arguments)},n.addEventListener("keydown",Z,!0),n.addEventListener("keyup",Z,!0),n.addEventListener("click",J,!0),t.addEventListener("focus",Q,!0),t.addEventListener("blur",ee,!1),"undefined"!=typeof PointerEvent?(n.addEventListener("pointerdown",G,!0),n.addEventListener("pointermove",G,!0),n.addEventListener("pointerup",G,!0)):(n.addEventListener("mousedown",G,!0),n.addEventListener("mousemove",G,!0),n.addEventListener("mouseup",G,!0)),t.addEventListener("beforeunload",()=>{en(e)},{once:!0}),Y.set(t,{focus:r})}let en=(e,t)=>{let n=V(e),r=$(e);t&&r.removeEventListener("DOMContentLoaded",t),Y.has(n)&&(n.HTMLElement.prototype.focus=Y.get(n).focus,r.removeEventListener("keydown",Z,!0),r.removeEventListener("keyup",Z,!0),r.removeEventListener("click",J,!0),n.removeEventListener("focus",Q,!0),n.removeEventListener("blur",ee,!1),"undefined"!=typeof PointerEvent?(r.removeEventListener("pointerdown",G,!0),r.removeEventListener("pointermove",G,!0),r.removeEventListener("pointerup",G,!0)):(r.removeEventListener("mousedown",G,!0),r.removeEventListener("mousemove",G,!0),r.removeEventListener("mouseup",G,!0)),Y.delete(n))};"undefined"!=typeof document&&function(e){let t;let n=$(void 0);"loading"!==n.readyState?et(void 0):(t=()=>{et(void 0)},n.addEventListener("DOMContentLoaded",t)),()=>en(e,t)}();let er=!1,eo=0;function ei(){er=!0,setTimeout(()=>{er=!1},50)}function ea(e){"touch"===e.pointerType&&ei()}function el(){if("undefined"!=typeof document)return"undefined"!=typeof PointerEvent?document.addEventListener("pointerup",ea):document.addEventListener("touchend",ei),eo++,()=>{--eo>0||("undefined"!=typeof PointerEvent?document.removeEventListener("pointerup",ea):document.removeEventListener("touchend",ei))}}function eu(e){let{onHoverStart:t,onHoverChange:n,onHoverEnd:r,isDisabled:o}=e,[i,a]=(0,f.useState)(!1),l=(0,f.useRef)({isHovered:!1,ignoreEmulatedMouseEvents:!1,pointerType:"",target:null}).current;(0,f.useEffect)(el,[]);let{hoverProps:u,triggerHoverEnd:s}=(0,f.useMemo)(()=>{let e=(e,r)=>{if(l.pointerType=r,o||"touch"===r||l.isHovered||!e.currentTarget.contains(e.target))return;l.isHovered=!0;let i=e.currentTarget;l.target=i,t&&t({type:"hoverstart",target:i,pointerType:r}),n&&n(!0),a(!0)},i=(e,t)=>{if(l.pointerType="",l.target=null,"touch"===t||!l.isHovered)return;l.isHovered=!1;let o=e.currentTarget;r&&r({type:"hoverend",target:o,pointerType:t}),n&&n(!1),a(!1)},u={};return"undefined"!=typeof PointerEvent?(u.onPointerEnter=t=>{er&&"mouse"===t.pointerType||e(t,t.pointerType)},u.onPointerLeave=e=>{!o&&e.currentTarget.contains(e.target)&&i(e,e.pointerType)}):(u.onTouchStart=()=>{l.ignoreEmulatedMouseEvents=!0},u.onMouseEnter=t=>{l.ignoreEmulatedMouseEvents||er||e(t,"mouse"),l.ignoreEmulatedMouseEvents=!1},u.onMouseLeave=e=>{!o&&e.currentTarget.contains(e.target)&&i(e,"mouse")}),{hoverProps:u,triggerHoverEnd:i}},[t,n,r,o,l]);return(0,f.useEffect)(()=>{o&&s({currentTarget:l.target},l.pointerType)},[o]),{hoverProps:u,isHovered:i}}let es="undefined"!=typeof document?f.useLayoutEffect:()=>{};function ec(e){var t;return"undefined"!=typeof window&&null!=window.navigator&&((null===(t=window.navigator.userAgentData)||void 0===t?void 0:t.brands.some(t=>e.test(t.brand)))||e.test(window.navigator.userAgent))}function ed(e){var t;return"undefined"!=typeof window&&null!=window.navigator&&e.test((null===(t=window.navigator.userAgentData)||void 0===t?void 0:t.platform)||window.navigator.platform)}function ef(e){let t=null;return()=>(null==t&&(t=e()),t)}let ep=ef(function(){return ed(/^Mac/i)}),em=ef(function(){return ed(/^iPhone/i)}),eh=ef(function(){return ed(/^iPad/i)||ep()&&navigator.maxTouchPoints>1}),ev=ef(function(){return em()||eh()});ef(function(){return ep()||ev()}),ef(function(){return ec(/AppleWebKit/i)&&!eg()});let eg=ef(function(){return ec(/Chrome/i)}),eb=ef(function(){return ec(/Android/i)});ef(function(){return ec(/Firefox/i)});let ey=e=>{var t;return null!==(t=null==e?void 0:e.ownerDocument)&&void 0!==t?t:document},ew=e=>e&&"window"in e&&e.window===e?e:ey(e).defaultView||window,ex=null,eE=new Set,eC=new Map,eS=!1,eM=!1;function ek(e,t){for(let n of eE)n(e,t)}function eT(e){eS=!0,e.metaKey||!ep()&&e.altKey||e.ctrlKey||"Control"===e.key||"Shift"===e.key||"Meta"===e.key||(ex="keyboard",ek("keyboard",e))}function eP(e){ex="pointer",("mousedown"===e.type||"pointerdown"===e.type)&&(eS=!0,ek("pointer",e))}function eR(e){(0===e.mozInputSource&&e.isTrusted||(eb()&&e.pointerType?"click"===e.type&&1===e.buttons:0===e.detail&&!e.pointerType))&&(eS=!0,ex="virtual")}function eL(e){e.target!==window&&e.target!==document&&e.isTrusted&&(eS||eM||(ex="virtual",ek("virtual",e)),eS=!1,eM=!1)}function ej(){eS=!1,eM=!0}function eA(e){if("undefined"==typeof window||"undefined"==typeof document||eC.get(ew(e)))return;let t=ew(e),n=ey(e),r=t.HTMLElement.prototype.focus;t.HTMLElement.prototype.focus=function(){eS=!0,r.apply(this,arguments)},n.addEventListener("keydown",eT,!0),n.addEventListener("keyup",eT,!0),n.addEventListener("click",eR,!0),t.addEventListener("focus",eL,!0),t.addEventListener("blur",ej,!1),"undefined"!=typeof PointerEvent&&(n.addEventListener("pointerdown",eP,!0),n.addEventListener("pointermove",eP,!0),n.addEventListener("pointerup",eP,!0)),t.addEventListener("beforeunload",()=>{eO(e)},{once:!0}),eC.set(t,{focus:r})}let eO=(e,t)=>{let n=ew(e),r=ey(e);t&&r.removeEventListener("DOMContentLoaded",t),eC.has(n)&&(n.HTMLElement.prototype.focus=eC.get(n).focus,r.removeEventListener("keydown",eT,!0),r.removeEventListener("keyup",eT,!0),r.removeEventListener("click",eR,!0),n.removeEventListener("focus",eL,!0),n.removeEventListener("blur",ej,!1),"undefined"!=typeof PointerEvent&&(r.removeEventListener("pointerdown",eP,!0),r.removeEventListener("pointermove",eP,!0),r.removeEventListener("pointerup",eP,!0)),eC.delete(n))};"undefined"!=typeof document&&function(e){let t;let n=ey(void 0);"loading"!==n.readyState?eA(void 0):(t=()=>{eA(void 0)},n.addEventListener("DOMContentLoaded",t)),()=>eO(e,t)}();let eD=(e=document)=>e.activeElement,eW=new Map,eN=new Set;function eI(){if("undefined"==typeof window)return;function e(e){return"propertyName"in e}let t=n=>{if(!e(n)||!n.target)return;let r=eW.get(n.target);if(r&&(r.delete(n.propertyName),0===r.size&&(n.target.removeEventListener("transitioncancel",t),eW.delete(n.target)),0===eW.size)){for(let e of eN)e();eN.clear()}};document.body.addEventListener("transitionrun",n=>{if(!e(n)||!n.target)return;let r=eW.get(n.target);r||(r=new Set,eW.set(n.target,r),n.target.addEventListener("transitioncancel",t,{once:!0})),r.add(n.propertyName)}),document.body.addEventListener("transitionend",t)}function e_(e){if(function(){if(null==ez){ez=!1;try{document.createElement("div").focus({get preventScroll(){return ez=!0,!0}})}catch{}}return ez}())e.focus({preventScroll:!0});else{let t=function(e){let t=e.parentNode,n=[],r=document.scrollingElement||document.documentElement;for(;t instanceof HTMLElement&&t!==r;)(t.offsetHeight<t.scrollHeight||t.offsetWidth<t.scrollWidth)&&n.push({element:t,scrollTop:t.scrollTop,scrollLeft:t.scrollLeft}),t=t.parentNode;return r instanceof HTMLElement&&n.push({element:r,scrollTop:r.scrollTop,scrollLeft:r.scrollLeft}),n}(e);e.focus(),function(e){for(let{element:t,scrollTop:n,scrollLeft:r}of e)t.scrollTop=n,t.scrollLeft=r}(t)}}"undefined"!=typeof document&&("loading"!==document.readyState?eI():document.addEventListener("DOMContentLoaded",eI));let ez=null;function eF(e){if(!e)return;let t=!0;return n=>{e({...n,preventDefault(){n.preventDefault()},isDefaultPrevented:()=>n.isDefaultPrevented(),stopPropagation(){t=!0},continuePropagation(){t=!1},isPropagationStopped:()=>t}),t&&n.stopPropagation()}}"undefined"!=typeof window&&window.document&&window.document.createElement;let eH=new Map;function e$(...e){let t={...e[0]};for(let n=1;n<e.length;n++){let r=e[n];for(let e in r){let n=t[e],o=r[e];"function"==typeof n&&"function"==typeof o&&"o"===e[0]&&"n"===e[1]&&e.charCodeAt(2)>=65&&90>=e.charCodeAt(2)?t[e]=function(...e){return(...t)=>{for(let n of e)"function"==typeof n&&n(...t)}}(n,o):("className"===e||"UNSAFE_className"===e)&&"string"==typeof n&&"string"==typeof o?t[e]=(0,L.Z)(n,o):"id"===e&&n&&o?t.id=function(e,t){if(e===t)return e;let n=eH.get(e);if(n)return n.forEach(e=>e.current=t),t;let r=eH.get(t);return r?(r.forEach(t=>t.current=e),e):t}(n,o):t[e]=void 0!==o?o:n}}return t}"undefined"!=typeof FinalizationRegistry&&new FinalizationRegistry(e=>{eH.delete(e)});let eV=f.createContext(null),eB=new Set(["id"]),eX=new Set(["aria-label","aria-labelledby","aria-describedby","aria-details"]),eY=new Set(["href","hrefLang","target","rel","download","ping","referrerPolicy"]),eU=/^(data-.*)$/;function eq(e,t=-1/0,n=1/0){return Math.min(Math.max(e,t),n)}let eK={top:"top",bottom:"top",left:"left",right:"left"},eZ={top:"bottom",bottom:"top",left:"right",right:"left"},eG={top:"left",left:"top"},eJ={top:"height",left:"width"},eQ={width:"totalWidth",height:"totalHeight"},e0={},e1="undefined"!=typeof document?window.visualViewport:null;function e2(e){var t,n,r,o,i;let a=0,l=0,u=0,s=0,c=0,d=0,f={},p=(null!==(t=null==e1?void 0:e1.scale)&&void 0!==t?t:1)>1;if("BODY"===e.tagName){let t=document.documentElement;u=t.clientWidth,s=t.clientHeight,a=null!==(n=null==e1?void 0:e1.width)&&void 0!==n?n:u,l=null!==(r=null==e1?void 0:e1.height)&&void 0!==r?r:s,f.top=t.scrollTop||e.scrollTop,f.left=t.scrollLeft||e.scrollLeft,e1&&(c=e1.offsetTop,d=e1.offsetLeft)}else({width:a,height:l,top:c,left:d}=e7(e)),f.top=e.scrollTop,f.left=e.scrollLeft,u=a,s=l;return z()&&("BODY"===e.tagName||"HTML"===e.tagName)&&p&&(f.top=0,f.left=0,c=null!==(o=null==e1?void 0:e1.pageTop)&&void 0!==o?o:0,d=null!==(i=null==e1?void 0:e1.pageLeft)&&void 0!==i?i:0),{width:a,height:l,totalWidth:u,totalHeight:s,scroll:f,top:c,left:d}}function e5(e,t,n,r,o,i,a){var l;let u=null!==(l=o.scroll[e])&&void 0!==l?l:0,s=r[eJ[e]],c=r.scroll[eK[e]]+i,d=s+r.scroll[eK[e]]-i,f=t-u+a[e]-r[eK[e]],p=t-u+n+a[e]-r[eK[e]];return f<c?c-f:p>d?Math.max(d-p,c-f):0}function e9(e){if(e0[e])return e0[e];let[t,n]=e.split(" "),r=eK[t]||"right",o=eG[r];eK[n]||(n="center");let i=eJ[r],a=eJ[o];return e0[e]={placement:t,crossPlacement:n,axis:r,crossAxis:o,size:i,crossSize:a},e0[e]}function e4(e,t,n,r,o,i,a,l,u,s){var c,d,f,p,m;let{placement:h,crossPlacement:v,axis:g,crossAxis:b,size:y,crossSize:w}=r,x={};x[b]=null!==(c=e[b])&&void 0!==c?c:0,"center"===v?x[b]+=((null!==(d=e[w])&&void 0!==d?d:0)-(null!==(f=n[w])&&void 0!==f?f:0))/2:v!==b&&(x[b]+=(null!==(p=e[w])&&void 0!==p?p:0)-(null!==(m=n[w])&&void 0!==m?m:0)),x[b]+=i;let E=e[b]-n[w]+u+s,C=e[b]+e[w]-u-s;if(x[b]=eq(x[b],E,C),h===g){let n=l?a[y]:t[eQ[y]];x[eZ[g]]=Math.floor(n-e[g]+o)}else x[g]=Math.floor(e[g]+e[y]+o);return x}function e3(e,t,n,r,o,i){var a,l,u;let{placement:s,axis:c,size:d}=i;return s===c?Math.max(0,n[c]-e[c]-(null!==(a=e.scroll[c])&&void 0!==a?a:0)+t[c]-(null!==(l=r[c])&&void 0!==l?l:0)-r[eZ[c]]-o):Math.max(0,e[d]+e[c]+e.scroll[c]-t[c]-n[c]-n[d]-(null!==(u=r[c])&&void 0!==u?u:0)-r[eZ[c]]-o)}function e7(e){let{top:t,left:n,width:r,height:o}=e.getBoundingClientRect(),{scrollTop:i,scrollLeft:a,clientTop:l,clientLeft:u}=document.documentElement;return{top:t+i-l,left:n+a-u,width:r,height:o}}function e6(e,t){let n,r=window.getComputedStyle(e);if("fixed"===r.position){let{top:t,left:r,width:o,height:i}=e.getBoundingClientRect();n={top:t,left:r,width:o,height:i}}else{n=e7(e);let r=e7(t),o=window.getComputedStyle(t);r.top+=(parseInt(o.borderTopWidth,10)||0)-t.scrollTop,r.left+=(parseInt(o.borderLeftWidth,10)||0)-t.scrollLeft,n.top-=r.top,n.left-=r.left}return n.top-=parseInt(r.marginTop,10)||0,n.left-=parseInt(r.marginLeft,10)||0,n}function e8(e){let t=window.getComputedStyle(e);return"none"!==t.transform||/transform|perspective/.test(t.willChange)||"none"!==t.filter||"paint"===t.contain||"backdropFilter"in t&&"none"!==t.backdropFilter||"WebkitBackdropFilter"in t&&"none"!==t.WebkitBackdropFilter}let te=new WeakMap;function tt(e){let{ref:t,box:n,onResize:r}=e;(0,f.useEffect)(()=>{let e=null==t?void 0:t.current;if(e){if(!(void 0!==window.ResizeObserver))return window.addEventListener("resize",r,!1),()=>{window.removeEventListener("resize",r,!1)};{let t=new window.ResizeObserver(e=>{e.length&&r()});return t.observe(e,{box:n}),()=>{e&&t.unobserve(e)}}}},[r,t,n])}let tn=new Set(["Arab","Syrc","Samr","Mand","Thaa","Mend","Nkoo","Adlm","Rohg","Hebr"]),tr=new Set(["ae","ar","arc","bcc","bqi","ckb","dv","fa","glk","he","ku","mzn","nqo","pnb","ps","sd","ug","ur","yi"]),to=Symbol.for("react-aria.i18n.locale");function ti(){let e="undefined"!=typeof window&&window[to]||"undefined"!=typeof navigator&&(navigator.language||navigator.userLanguage)||"en-US";try{Intl.DateTimeFormat.supportedLocalesOf([e])}catch{e="en-US"}return{locale:e,direction:!function(e){if(Intl.Locale){let t=new Intl.Locale(e).maximize(),n="function"==typeof t.getTextInfo?t.getTextInfo():t.textInfo;if(n)return"rtl"===n.direction;if(t.script)return tn.has(t.script)}let t=e.split("-")[0];return tr.has(t)}(e)?"ltr":"rtl"}}let ta=ti(),tl=new Set;function tu(){for(let e of(ta=ti(),tl))e(ta)}let ts=f.createContext(null),tc="undefined"!=typeof document?window.visualViewport:null;function td(e,t){return!!e&&!!t&&t.some(t=>t.contains(e))}class tf{get size(){return this.fastMap.size}getTreeNode(e){return this.fastMap.get(e)}addTreeNode(e,t,n){let r=this.fastMap.get(null!=t?t:null);if(!r)return;let o=new tp({scopeRef:e});r.addChild(o),o.parent=r,this.fastMap.set(e,o),n&&(o.nodeToRestore=n)}addNode(e){this.fastMap.set(e.scopeRef,e)}removeTreeNode(e){if(null===e)return;let t=this.fastMap.get(e);if(!t)return;let n=t.parent;for(let e of this.traverse())e!==t&&t.nodeToRestore&&e.nodeToRestore&&t.scopeRef&&t.scopeRef.current&&td(e.nodeToRestore,t.scopeRef.current)&&(e.nodeToRestore=t.nodeToRestore);let r=t.children;n&&(n.removeChild(t),r.size>0&&r.forEach(e=>n&&n.addChild(e))),this.fastMap.delete(t.scopeRef)}*traverse(e=this.root){if(null!=e.scopeRef&&(yield e),e.children.size>0)for(let t of e.children)yield*this.traverse(t)}clone(){var e,t;let n=new tf;for(let r of this.traverse())n.addTreeNode(r.scopeRef,null!==(t=null===(e=r.parent)||void 0===e?void 0:e.scopeRef)&&void 0!==t?t:null,r.nodeToRestore);return n}constructor(){this.fastMap=new Map,this.root=new tp({scopeRef:null}),this.fastMap.set(null,this.root)}}class tp{addChild(e){this.children.add(e),e.parent=this}removeChild(e){this.children.delete(e),e.parent=void 0}constructor(e){this.children=new Set,this.contain=!1,this.scopeRef=e.scopeRef}}let tm=new tf;function th(e){let t=(0,f.useRef)(null);return b(()=>{t.current=e},[e]),(0,f.useCallback)((...e)=>{let n=t.current;return null==n?void 0:n(...e)},[])}function tv(e,t){if(e.button>0)return!1;if(e.target){let t=e.target.ownerDocument;if(!t||!t.documentElement.contains(e.target)||e.target.closest("[data-react-aria-top-layer]"))return!1}return t.current&&!t.current.contains(e.target)}class tg{isDefaultPrevented(){return this.nativeEvent.defaultPrevented}preventDefault(){this.defaultPrevented=!0,this.nativeEvent.preventDefault()}stopPropagation(){this.nativeEvent.stopPropagation(),this.isPropagationStopped=()=>!0}isPropagationStopped(){return!1}persist(){}constructor(e,t){this.nativeEvent=t,this.target=t.target,this.currentTarget=t.currentTarget,this.relatedTarget=t.relatedTarget,this.bubbles=t.bubbles,this.cancelable=t.cancelable,this.defaultPrevented=t.defaultPrevented,this.eventPhase=t.eventPhase,this.isTrusted=t.isTrusted,this.timeStamp=t.timeStamp,this.type=e}}let tb=[];var[ty,tw]=function(e={}){let{strict:t=!0,errorMessage:n="useContext: `context` is undefined. Seems you forgot to wrap component within the Provider",name:r}=e,o=f.createContext(void 0);return o.displayName=r,[o.Provider,function e(){var r;let i=f.useContext(o);if(!i&&t){let t=Error(n);throw t.name="ContextError",null==(r=Error.captureStackTrace)||r.call(Error,t,e),t}return i},o]}({name:"ProviderContext",strict:!1}),tx=(e,t,n=!0)=>{if(!t)return[e,{}];let r=t.reduce((t,n)=>n in e?{...t,[n]:e[n]}:t,{});return n?[Object.keys(e).filter(e=>!t.includes(e)).reduce((t,n)=>({...t,[n]:e[n]}),{}),r]:[e,r]},tE=["small","medium","large"],tC={theme:{opacity:["disabled"],spacing:["divider"],borderWidth:tE,borderRadius:tE},classGroups:{shadow:[{shadow:tE}],"font-size":[{text:["tiny",...tE]}],"bg-image":["bg-stripe-gradient-default","bg-stripe-gradient-primary","bg-stripe-gradient-secondary","bg-stripe-gradient-success","bg-stripe-gradient-warning","bg-stripe-gradient-danger"]}},tS=e=>"boolean"==typeof e?`${e}`:0===e?"0":e,tM=e=>!e||"object"!=typeof e||0===Object.keys(e).length,tk=(e,t)=>JSON.stringify(e)===JSON.stringify(t);function tT(e){let t=[];return function e(t,n){t.forEach(function(t){Array.isArray(t)?e(t,n):n.push(t)})}(e,t),t}var tP=(...e)=>tT(e).filter(Boolean),tR=(e,t)=>{let n={},r=Object.keys(e),o=Object.keys(t);for(let i of r)if(o.includes(i)){let r=e[i],o=t[i];"object"==typeof r&&"object"==typeof o?n[i]=tR(r,o):Array.isArray(r)||Array.isArray(o)?n[i]=tP(o,r):n[i]=o+" "+r}else n[i]=e[i];for(let e of o)r.includes(e)||(n[e]=t[e]);return n},tL=e=>e&&"string"==typeof e?e.replace(/\s+/g," ").trim():e,tj=/^\[(.+)\]$/;function tA(e,t){var n=e;return t.split("-").forEach(function(e){n.nextPart.has(e)||n.nextPart.set(e,{nextPart:new Map,validators:[]}),n=n.nextPart.get(e)}),n}var tO=/\s+/;function tD(){for(var e,t,n=0,r="";n<arguments.length;)(e=arguments[n++])&&(t=function e(t){if("string"==typeof t)return t;for(var n,r="",o=0;o<t.length;o++)t[o]&&(n=e(t[o]))&&(r&&(r+=" "),r+=n);return r}(e))&&(r&&(r+=" "),r+=t);return r}function tW(){for(var e,t,n,r=arguments.length,o=Array(r),i=0;i<r;i++)o[i]=arguments[i];var a=function(r){var i=o[0];return t=(e=function(e){var t,n,r,o,i,a,l,u,s,c,d;return{cache:function(e){if(e<1)return{get:function(){},set:function(){}};var t=0,n=new Map,r=new Map;function o(o,i){n.set(o,i),++t>e&&(t=0,r=n,n=new Map)}return{get:function(e){var t=n.get(e);return void 0!==t?t:void 0!==(t=r.get(e))?(o(e,t),t):void 0},set:function(e,t){n.has(e)?n.set(e,t):o(e,t)}}}(e.cacheSize),splitModifiers:(n=1===(t=e.separator||":").length,r=t[0],o=t.length,function(e){for(var i,a=[],l=0,u=0,s=0;s<e.length;s++){var c=e[s];if(0===l){if(c===r&&(n||e.slice(s,s+o)===t)){a.push(e.slice(u,s)),u=s+o;continue}if("/"===c){i=s;continue}}"["===c?l++:"]"===c&&l--}var d=0===a.length?e:e.substring(u),f=d.startsWith("!"),p=f?d.substring(1):d;return{modifiers:a,hasImportantModifier:f,baseClassName:p,maybePostfixModifierPosition:i&&i>u?i-u:void 0}}),...(u=e.theme,s=e.prefix,c={nextPart:new Map,validators:[]},(d=Object.entries(e.classGroups),s?d.map(function(e){return[e[0],e[1].map(function(e){return"string"==typeof e?s+e:"object"==typeof e?Object.fromEntries(Object.entries(e).map(function(e){return[s+e[0],e[1]]})):e})]}):d).forEach(function(e){var t=e[0];(function e(t,n,r,o){t.forEach(function(t){if("string"==typeof t){(""===t?n:tA(n,t)).classGroupId=r;return}if("function"==typeof t){if(t.isThemeGetter){e(t(o),n,r,o);return}n.validators.push({validator:t,classGroupId:r});return}Object.entries(t).forEach(function(t){var i=t[0];e(t[1],tA(n,i),r,o)})})})(e[1],c,t,u)}),i=e.conflictingClassGroups,l=void 0===(a=e.conflictingClassGroupModifiers)?{}:a,{getClassGroupId:function(e){var t=e.split("-");return""===t[0]&&1!==t.length&&t.shift(),function e(t,n){if(0===t.length)return n.classGroupId;var r=t[0],o=n.nextPart.get(r),i=o?e(t.slice(1),o):void 0;if(i)return i;if(0!==n.validators.length){var a=t.join("-");return n.validators.find(function(e){return(0,e.validator)(a)})?.classGroupId}}(t,c)||function(e){if(tj.test(e)){var t=tj.exec(e)[1],n=t?.substring(0,t.indexOf(":"));if(n)return"arbitrary.."+n}}(e)},getConflictingClassGroupIds:function(e,t){var n=i[e]||[];return t&&l[e]?[].concat(n,l[e]):n}})}}(o.slice(1).reduce(function(e,t){return t(e)},i()))).cache.get,n=e.cache.set,a=l,l(r)};function l(r){var o,i,a,l,u,s=t(r);if(s)return s;var c=(i=(o=e).splitModifiers,a=o.getClassGroupId,l=o.getConflictingClassGroupIds,u=new Set,r.trim().split(tO).map(function(e){var t=i(e),n=t.modifiers,r=t.hasImportantModifier,o=t.baseClassName,l=t.maybePostfixModifierPosition,u=a(l?o.substring(0,l):o),s=!!l;if(!u){if(!l||!(u=a(o)))return{isTailwindClass:!1,originalClassName:e};s=!1}var c=(function(e){if(e.length<=1)return e;var t=[],n=[];return e.forEach(function(e){"["===e[0]?(t.push.apply(t,n.sort().concat([e])),n=[]):n.push(e)}),t.push.apply(t,n.sort()),t})(n).join(":");return{isTailwindClass:!0,modifierId:r?c+"!":c,classGroupId:u,originalClassName:e,hasPostfixModifier:s}}).reverse().filter(function(e){if(!e.isTailwindClass)return!0;var t=e.modifierId,n=e.classGroupId,r=e.hasPostfixModifier,o=t+n;return!u.has(o)&&(u.add(o),l(n,r).forEach(function(e){return u.add(t+e)}),!0)}).reverse().map(function(e){return e.originalClassName}).join(" "));return n(r,c),c}return function(){return a(tD.apply(null,arguments))}}function tN(e){var t=function(t){return t[e]||[]};return t.isThemeGetter=!0,t}var tI=/^\[(?:([a-z-]+):)?(.+)\]$/i,t_=/^\d+\/\d+$/,tz=new Set(["px","full","screen"]),tF=/^(\d+(\.\d+)?)?(xs|sm|md|lg|xl)$/,tH=/\d+(%|px|r?em|[sdl]?v([hwib]|min|max)|pt|pc|in|cm|mm|cap|ch|ex|r?lh|cq(w|h|i|b|min|max))|\b(calc|min|max|clamp)\(.+\)|^0$/,t$=/^-?((\d+)?\.?(\d+)[a-z]+|0)_-?((\d+)?\.?(\d+)[a-z]+|0)/;function tV(e){return tK(e)||tz.has(e)||t_.test(e)||tB(e)}function tB(e){return t2(e,"length",t5)}function tX(e){return t2(e,"size",t9)}function tY(e){return t2(e,"position",t9)}function tU(e){return t2(e,"url",t4)}function tq(e){return t2(e,"number",tK)}function tK(e){return!Number.isNaN(Number(e))}function tZ(e){return e.endsWith("%")&&tK(e.slice(0,-1))}function tG(e){return t3(e)||t2(e,"number",t3)}function tJ(e){return tI.test(e)}function tQ(){return!0}function t0(e){return tF.test(e)}function t1(e){return t2(e,"",t7)}function t2(e,t,n){var r=tI.exec(e);return!!r&&(r[1]?r[1]===t:n(r[2]))}function t5(e){return tH.test(e)}function t9(){return!1}function t4(e){return e.startsWith("url(")}function t3(e){return Number.isInteger(Number(e))}function t7(e){return t$.test(e)}function t6(){var e=tN("colors"),t=tN("spacing"),n=tN("blur"),r=tN("brightness"),o=tN("borderColor"),i=tN("borderRadius"),a=tN("borderSpacing"),l=tN("borderWidth"),u=tN("contrast"),s=tN("grayscale"),c=tN("hueRotate"),d=tN("invert"),f=tN("gap"),p=tN("gradientColorStops"),m=tN("gradientColorStopPositions"),h=tN("inset"),v=tN("margin"),g=tN("opacity"),b=tN("padding"),y=tN("saturate"),w=tN("scale"),x=tN("sepia"),E=tN("skew"),C=tN("space"),S=tN("translate"),M=function(){return["auto","contain","none"]},k=function(){return["auto","hidden","clip","visible","scroll"]},T=function(){return["auto",tJ,t]},P=function(){return[tJ,t]},R=function(){return["",tV]},L=function(){return["auto",tK,tJ]},j=function(){return["bottom","center","left","left-bottom","left-top","right","right-bottom","right-top","top"]},A=function(){return["solid","dashed","dotted","double","none"]},O=function(){return["normal","multiply","screen","overlay","darken","lighten","color-dodge","color-burn","hard-light","soft-light","difference","exclusion","hue","saturation","color","luminosity","plus-lighter"]},D=function(){return["start","end","center","between","around","evenly","stretch"]},W=function(){return["","0",tJ]},N=function(){return["auto","avoid","all","avoid-page","page","left","right","column"]},I=function(){return[tK,tq]},_=function(){return[tK,tJ]};return{cacheSize:500,theme:{colors:[tQ],spacing:[tV],blur:["none","",t0,tJ],brightness:I(),borderColor:[e],borderRadius:["none","","full",t0,tJ],borderSpacing:P(),borderWidth:R(),contrast:I(),grayscale:W(),hueRotate:_(),invert:W(),gap:P(),gradientColorStops:[e],gradientColorStopPositions:[tZ,tB],inset:T(),margin:T(),opacity:I(),padding:P(),saturate:I(),scale:I(),sepia:W(),skew:_(),space:P(),translate:P()},classGroups:{aspect:[{aspect:["auto","square","video",tJ]}],container:["container"],columns:[{columns:[t0]}],"break-after":[{"break-after":N()}],"break-before":[{"break-before":N()}],"break-inside":[{"break-inside":["auto","avoid","avoid-page","avoid-column"]}],"box-decoration":[{"box-decoration":["slice","clone"]}],box:[{box:["border","content"]}],display:["block","inline-block","inline","flex","inline-flex","table","inline-table","table-caption","table-cell","table-column","table-column-group","table-footer-group","table-header-group","table-row-group","table-row","flow-root","grid","inline-grid","contents","list-item","hidden"],float:[{float:["right","left","none"]}],clear:[{clear:["left","right","both","none"]}],isolation:["isolate","isolation-auto"],"object-fit":[{object:["contain","cover","fill","none","scale-down"]}],"object-position":[{object:[].concat(j(),[tJ])}],overflow:[{overflow:k()}],"overflow-x":[{"overflow-x":k()}],"overflow-y":[{"overflow-y":k()}],overscroll:[{overscroll:M()}],"overscroll-x":[{"overscroll-x":M()}],"overscroll-y":[{"overscroll-y":M()}],position:["static","fixed","absolute","relative","sticky"],inset:[{inset:[h]}],"inset-x":[{"inset-x":[h]}],"inset-y":[{"inset-y":[h]}],start:[{start:[h]}],end:[{end:[h]}],top:[{top:[h]}],right:[{right:[h]}],bottom:[{bottom:[h]}],left:[{left:[h]}],visibility:["visible","invisible","collapse"],z:[{z:["auto",tG]}],basis:[{basis:T()}],"flex-direction":[{flex:["row","row-reverse","col","col-reverse"]}],"flex-wrap":[{flex:["wrap","wrap-reverse","nowrap"]}],flex:[{flex:["1","auto","initial","none",tJ]}],grow:[{grow:W()}],shrink:[{shrink:W()}],order:[{order:["first","last","none",tG]}],"grid-cols":[{"grid-cols":[tQ]}],"col-start-end":[{col:["auto",{span:["full",tG]},tJ]}],"col-start":[{"col-start":L()}],"col-end":[{"col-end":L()}],"grid-rows":[{"grid-rows":[tQ]}],"row-start-end":[{row:["auto",{span:[tG]},tJ]}],"row-start":[{"row-start":L()}],"row-end":[{"row-end":L()}],"grid-flow":[{"grid-flow":["row","col","dense","row-dense","col-dense"]}],"auto-cols":[{"auto-cols":["auto","min","max","fr",tJ]}],"auto-rows":[{"auto-rows":["auto","min","max","fr",tJ]}],gap:[{gap:[f]}],"gap-x":[{"gap-x":[f]}],"gap-y":[{"gap-y":[f]}],"justify-content":[{justify:["normal"].concat(D())}],"justify-items":[{"justify-items":["start","end","center","stretch"]}],"justify-self":[{"justify-self":["auto","start","end","center","stretch"]}],"align-content":[{content:["normal"].concat(D(),["baseline"])}],"align-items":[{items:["start","end","center","baseline","stretch"]}],"align-self":[{self:["auto","start","end","center","stretch","baseline"]}],"place-content":[{"place-content":[].concat(D(),["baseline"])}],"place-items":[{"place-items":["start","end","center","baseline","stretch"]}],"place-self":[{"place-self":["auto","start","end","center","stretch"]}],p:[{p:[b]}],px:[{px:[b]}],py:[{py:[b]}],ps:[{ps:[b]}],pe:[{pe:[b]}],pt:[{pt:[b]}],pr:[{pr:[b]}],pb:[{pb:[b]}],pl:[{pl:[b]}],m:[{m:[v]}],mx:[{mx:[v]}],my:[{my:[v]}],ms:[{ms:[v]}],me:[{me:[v]}],mt:[{mt:[v]}],mr:[{mr:[v]}],mb:[{mb:[v]}],ml:[{ml:[v]}],"space-x":[{"space-x":[C]}],"space-x-reverse":["space-x-reverse"],"space-y":[{"space-y":[C]}],"space-y-reverse":["space-y-reverse"],w:[{w:["auto","min","max","fit",tJ,t]}],"min-w":[{"min-w":["min","max","fit",tJ,tV]}],"max-w":[{"max-w":["0","none","full","min","max","fit","prose",{screen:[t0]},t0,tJ]}],h:[{h:[tJ,t,"auto","min","max","fit"]}],"min-h":[{"min-h":["min","max","fit",tJ,tV]}],"max-h":[{"max-h":[tJ,t,"min","max","fit"]}],"font-size":[{text:["base",t0,tB]}],"font-smoothing":["antialiased","subpixel-antialiased"],"font-style":["italic","not-italic"],"font-weight":[{font:["thin","extralight","light","normal","medium","semibold","bold","extrabold","black",tq]}],"font-family":[{font:[tQ]}],"fvn-normal":["normal-nums"],"fvn-ordinal":["ordinal"],"fvn-slashed-zero":["slashed-zero"],"fvn-figure":["lining-nums","oldstyle-nums"],"fvn-spacing":["proportional-nums","tabular-nums"],"fvn-fraction":["diagonal-fractions","stacked-fractons"],tracking:[{tracking:["tighter","tight","normal","wide","wider","widest",tJ]}],"line-clamp":[{"line-clamp":["none",tK,tq]}],leading:[{leading:["none","tight","snug","normal","relaxed","loose",tJ,tV]}],"list-image":[{"list-image":["none",tJ]}],"list-style-type":[{list:["none","disc","decimal",tJ]}],"list-style-position":[{list:["inside","outside"]}],"placeholder-color":[{placeholder:[e]}],"placeholder-opacity":[{"placeholder-opacity":[g]}],"text-alignment":[{text:["left","center","right","justify","start","end"]}],"text-color":[{text:[e]}],"text-opacity":[{"text-opacity":[g]}],"text-decoration":["underline","overline","line-through","no-underline"],"text-decoration-style":[{decoration:[].concat(A(),["wavy"])}],"text-decoration-thickness":[{decoration:["auto","from-font",tV]}],"underline-offset":[{"underline-offset":["auto",tJ,tV]}],"text-decoration-color":[{decoration:[e]}],"text-transform":["uppercase","lowercase","capitalize","normal-case"],"text-overflow":["truncate","text-ellipsis","text-clip"],indent:[{indent:P()}],"vertical-align":[{align:["baseline","top","middle","bottom","text-top","text-bottom","sub","super",tJ]}],whitespace:[{whitespace:["normal","nowrap","pre","pre-line","pre-wrap","break-spaces"]}],break:[{break:["normal","words","all","keep"]}],hyphens:[{hyphens:["none","manual","auto"]}],content:[{content:["none",tJ]}],"bg-attachment":[{bg:["fixed","local","scroll"]}],"bg-clip":[{"bg-clip":["border","padding","content","text"]}],"bg-opacity":[{"bg-opacity":[g]}],"bg-origin":[{"bg-origin":["border","padding","content"]}],"bg-position":[{bg:[].concat(j(),[tY])}],"bg-repeat":[{bg:["no-repeat",{repeat:["","x","y","round","space"]}]}],"bg-size":[{bg:["auto","cover","contain",tX]}],"bg-image":[{bg:["none",{"gradient-to":["t","tr","r","br","b","bl","l","tl"]},tU]}],"bg-color":[{bg:[e]}],"gradient-from-pos":[{from:[m]}],"gradient-via-pos":[{via:[m]}],"gradient-to-pos":[{to:[m]}],"gradient-from":[{from:[p]}],"gradient-via":[{via:[p]}],"gradient-to":[{to:[p]}],rounded:[{rounded:[i]}],"rounded-s":[{"rounded-s":[i]}],"rounded-e":[{"rounded-e":[i]}],"rounded-t":[{"rounded-t":[i]}],"rounded-r":[{"rounded-r":[i]}],"rounded-b":[{"rounded-b":[i]}],"rounded-l":[{"rounded-l":[i]}],"rounded-ss":[{"rounded-ss":[i]}],"rounded-se":[{"rounded-se":[i]}],"rounded-ee":[{"rounded-ee":[i]}],"rounded-es":[{"rounded-es":[i]}],"rounded-tl":[{"rounded-tl":[i]}],"rounded-tr":[{"rounded-tr":[i]}],"rounded-br":[{"rounded-br":[i]}],"rounded-bl":[{"rounded-bl":[i]}],"border-w":[{border:[l]}],"border-w-x":[{"border-x":[l]}],"border-w-y":[{"border-y":[l]}],"border-w-s":[{"border-s":[l]}],"border-w-e":[{"border-e":[l]}],"border-w-t":[{"border-t":[l]}],"border-w-r":[{"border-r":[l]}],"border-w-b":[{"border-b":[l]}],"border-w-l":[{"border-l":[l]}],"border-opacity":[{"border-opacity":[g]}],"border-style":[{border:[].concat(A(),["hidden"])}],"divide-x":[{"divide-x":[l]}],"divide-x-reverse":["divide-x-reverse"],"divide-y":[{"divide-y":[l]}],"divide-y-reverse":["divide-y-reverse"],"divide-opacity":[{"divide-opacity":[g]}],"divide-style":[{divide:A()}],"border-color":[{border:[o]}],"border-color-x":[{"border-x":[o]}],"border-color-y":[{"border-y":[o]}],"border-color-t":[{"border-t":[o]}],"border-color-r":[{"border-r":[o]}],"border-color-b":[{"border-b":[o]}],"border-color-l":[{"border-l":[o]}],"divide-color":[{divide:[o]}],"outline-style":[{outline:[""].concat(A())}],"outline-offset":[{"outline-offset":[tJ,tV]}],"outline-w":[{outline:[tV]}],"outline-color":[{outline:[e]}],"ring-w":[{ring:R()}],"ring-w-inset":["ring-inset"],"ring-color":[{ring:[e]}],"ring-opacity":[{"ring-opacity":[g]}],"ring-offset-w":[{"ring-offset":[tV]}],"ring-offset-color":[{"ring-offset":[e]}],shadow:[{shadow:["","inner","none",t0,t1]}],"shadow-color":[{shadow:[tQ]}],opacity:[{opacity:[g]}],"mix-blend":[{"mix-blend":O()}],"bg-blend":[{"bg-blend":O()}],filter:[{filter:["","none"]}],blur:[{blur:[n]}],brightness:[{brightness:[r]}],contrast:[{contrast:[u]}],"drop-shadow":[{"drop-shadow":["","none",t0,tJ]}],grayscale:[{grayscale:[s]}],"hue-rotate":[{"hue-rotate":[c]}],invert:[{invert:[d]}],saturate:[{saturate:[y]}],sepia:[{sepia:[x]}],"backdrop-filter":[{"backdrop-filter":["","none"]}],"backdrop-blur":[{"backdrop-blur":[n]}],"backdrop-brightness":[{"backdrop-brightness":[r]}],"backdrop-contrast":[{"backdrop-contrast":[u]}],"backdrop-grayscale":[{"backdrop-grayscale":[s]}],"backdrop-hue-rotate":[{"backdrop-hue-rotate":[c]}],"backdrop-invert":[{"backdrop-invert":[d]}],"backdrop-opacity":[{"backdrop-opacity":[g]}],"backdrop-saturate":[{"backdrop-saturate":[y]}],"backdrop-sepia":[{"backdrop-sepia":[x]}],"border-collapse":[{border:["collapse","separate"]}],"border-spacing":[{"border-spacing":[a]}],"border-spacing-x":[{"border-spacing-x":[a]}],"border-spacing-y":[{"border-spacing-y":[a]}],"table-layout":[{table:["auto","fixed"]}],caption:[{caption:["top","bottom"]}],transition:[{transition:["none","all","","colors","opacity","shadow","transform",tJ]}],duration:[{duration:_()}],ease:[{ease:["linear","in","out","in-out",tJ]}],delay:[{delay:_()}],animate:[{animate:["none","spin","ping","pulse","bounce",tJ]}],transform:[{transform:["","gpu","none"]}],scale:[{scale:[w]}],"scale-x":[{"scale-x":[w]}],"scale-y":[{"scale-y":[w]}],rotate:[{rotate:[tG,tJ]}],"translate-x":[{"translate-x":[S]}],"translate-y":[{"translate-y":[S]}],"skew-x":[{"skew-x":[E]}],"skew-y":[{"skew-y":[E]}],"transform-origin":[{origin:["center","top","top-right","right","bottom-right","bottom","bottom-left","left","top-left",tJ]}],accent:[{accent:["auto",e]}],appearance:["appearance-none"],cursor:[{cursor:["auto","default","pointer","wait","text","move","help","not-allowed","none","context-menu","progress","cell","crosshair","vertical-text","alias","copy","no-drop","grab","grabbing","all-scroll","col-resize","row-resize","n-resize","e-resize","s-resize","w-resize","ne-resize","nw-resize","se-resize","sw-resize","ew-resize","ns-resize","nesw-resize","nwse-resize","zoom-in","zoom-out",tJ]}],"caret-color":[{caret:[e]}],"pointer-events":[{"pointer-events":["none","auto"]}],resize:[{resize:["none","y","x",""]}],"scroll-behavior":[{scroll:["auto","smooth"]}],"scroll-m":[{"scroll-m":P()}],"scroll-mx":[{"scroll-mx":P()}],"scroll-my":[{"scroll-my":P()}],"scroll-ms":[{"scroll-ms":P()}],"scroll-me":[{"scroll-me":P()}],"scroll-mt":[{"scroll-mt":P()}],"scroll-mr":[{"scroll-mr":P()}],"scroll-mb":[{"scroll-mb":P()}],"scroll-ml":[{"scroll-ml":P()}],"scroll-p":[{"scroll-p":P()}],"scroll-px":[{"scroll-px":P()}],"scroll-py":[{"scroll-py":P()}],"scroll-ps":[{"scroll-ps":P()}],"scroll-pe":[{"scroll-pe":P()}],"scroll-pt":[{"scroll-pt":P()}],"scroll-pr":[{"scroll-pr":P()}],"scroll-pb":[{"scroll-pb":P()}],"scroll-pl":[{"scroll-pl":P()}],"snap-align":[{snap:["start","end","center","align-none"]}],"snap-stop":[{snap:["normal","always"]}],"snap-type":[{snap:["none","x","y","both"]}],"snap-strictness":[{snap:["mandatory","proximity"]}],touch:[{touch:["auto","none","pinch-zoom","manipulation",{pan:["x","left","right","y","up","down"]}]}],select:[{select:["none","text","all","auto"]}],"will-change":[{"will-change":["auto","scroll","contents","transform",tJ]}],fill:[{fill:[e,"none"]}],"stroke-w":[{stroke:[tV,tq]}],stroke:[{stroke:[e,"none"]}],sr:["sr-only","not-sr-only"]},conflictingClassGroups:{overflow:["overflow-x","overflow-y"],overscroll:["overscroll-x","overscroll-y"],inset:["inset-x","inset-y","start","end","top","right","bottom","left"],"inset-x":["right","left"],"inset-y":["top","bottom"],flex:["basis","grow","shrink"],gap:["gap-x","gap-y"],p:["px","py","ps","pe","pt","pr","pb","pl"],px:["pr","pl"],py:["pt","pb"],m:["mx","my","ms","me","mt","mr","mb","ml"],mx:["mr","ml"],my:["mt","mb"],"font-size":["leading"],"fvn-normal":["fvn-ordinal","fvn-slashed-zero","fvn-figure","fvn-spacing","fvn-fraction"],"fvn-ordinal":["fvn-normal"],"fvn-slashed-zero":["fvn-normal"],"fvn-figure":["fvn-normal"],"fvn-spacing":["fvn-normal"],"fvn-fraction":["fvn-normal"],rounded:["rounded-s","rounded-e","rounded-t","rounded-r","rounded-b","rounded-l","rounded-ss","rounded-se","rounded-ee","rounded-es","rounded-tl","rounded-tr","rounded-br","rounded-bl"],"rounded-s":["rounded-ss","rounded-es"],"rounded-e":["rounded-se","rounded-ee"],"rounded-t":["rounded-tl","rounded-tr"],"rounded-r":["rounded-tr","rounded-br"],"rounded-b":["rounded-br","rounded-bl"],"rounded-l":["rounded-tl","rounded-bl"],"border-spacing":["border-spacing-x","border-spacing-y"],"border-w":["border-w-s","border-w-e","border-w-t","border-w-r","border-w-b","border-w-l"],"border-w-x":["border-w-r","border-w-l"],"border-w-y":["border-w-t","border-w-b"],"border-color":["border-color-t","border-color-r","border-color-b","border-color-l"],"border-color-x":["border-color-r","border-color-l"],"border-color-y":["border-color-t","border-color-b"],"scroll-m":["scroll-mx","scroll-my","scroll-ms","scroll-me","scroll-mt","scroll-mr","scroll-mb","scroll-ml"],"scroll-mx":["scroll-mr","scroll-ml"],"scroll-my":["scroll-mt","scroll-mb"],"scroll-p":["scroll-px","scroll-py","scroll-ps","scroll-pe","scroll-pt","scroll-pr","scroll-pb","scroll-pl"],"scroll-px":["scroll-pr","scroll-pl"],"scroll-py":["scroll-pt","scroll-pb"]},conflictingClassGroupModifiers:{"font-size":["leading"]}}}var t8=tW(t6),ne=Object.prototype.hasOwnProperty,nt=new Set(["string","number","boolean"]),nn={twMerge:!0,twMergeConfig:{},responsiveVariants:!1},nr=e=>e||void 0,no=(...e)=>nr(tT(e).filter(Boolean).join(" ")),ni=null,na={},nl=!1,nu=(...e)=>t=>t.twMerge?((!ni||nl)&&(nl=!1,ni=tM(na)?t8:function(e){for(var t=arguments.length,n=Array(t>1?t-1:0),r=1;r<t;r++)n[r-1]=arguments[r];return"function"==typeof e?tW.apply(void 0,[t6,e].concat(n)):tW.apply(void 0,[function(){return function(e,t){for(var n in t)(function e(t,n,r){if(!ne.call(t,n)||nt.has(typeof r)||null===r){t[n]=r;return}if(Array.isArray(r)&&Array.isArray(t[n])){t[n]=t[n].concat(r);return}if("object"==typeof r&&"object"==typeof t[n]){if(null===t[n]){t[n]=r;return}for(var o in r)e(t[n],o,r[o])}})(e,n,t[n]);return e}(t6(),e)}].concat(n))}(na)),nr(ni(no(e)))):no(e),ns=(e,t)=>{for(let n in t)e.hasOwnProperty(n)?e[n]=no(e[n],t[n]):e[n]=t[n];return e},nc=((e,t)=>{let{extend:n=null,slots:r={},variants:o={},compoundVariants:i=[],compoundSlots:a=[],defaultVariants:l={}}=e,u={...nn,...t},s=null!=n&&n.base?no(n.base,null==e?void 0:e.base):null==e?void 0:e.base,c=null!=n&&n.variants&&!tM(n.variants)?tR(o,n.variants):o,d=null!=n&&n.defaultVariants&&!tM(n.defaultVariants)?{...n.defaultVariants,...l}:l;tM(u.twMergeConfig)||tk(u.twMergeConfig,na)||(nl=!0,na=u.twMergeConfig);let f=tM(null==n?void 0:n.slots),p=tM(r)?{}:{base:no(null==e?void 0:e.base,f&&(null==n?void 0:n.base)),...r},m=f?p:ns({...null==n?void 0:n.slots},tM(p)?{base:null==e?void 0:e.base}:p),h=e=>{if(tM(c)&&tM(r)&&f)return nu(s,null==e?void 0:e.class,null==e?void 0:e.className)(u);if(i&&!Array.isArray(i))throw TypeError(`The "compoundVariants" prop must be an array. Received: ${typeof i}`);if(a&&!Array.isArray(a))throw TypeError(`The "compoundSlots" prop must be an array. Received: ${typeof a}`);let t=(e,t,n=[],r)=>{let o=n;if("string"==typeof t)o=o.concat(tL(t).split(" ").map(t=>`${e}:${t}`));else if(Array.isArray(t))o=o.concat(t.reduce((t,n)=>t.concat(`${e}:${n}`),[]));else if("object"==typeof t&&"string"==typeof r){for(let n in t)if(t.hasOwnProperty(n)&&n===r){let i=t[n];if(i&&"string"==typeof i){let t=tL(i);o[r]?o[r]=o[r].concat(t.split(" ").map(t=>`${e}:${t}`)):o[r]=t.split(" ").map(t=>`${e}:${t}`)}else Array.isArray(i)&&i.length>0&&(o[r]=i.reduce((t,n)=>t.concat(`${e}:${n}`),[]))}}return o},o=(n,r=c,o=null,i=null)=>{var a;let l=r[n];if(!l||tM(l))return null;let s=null!=(a=null==i?void 0:i[n])?a:null==e?void 0:e[n];if(null===s)return null;let f=tS(s),p=Array.isArray(u.responsiveVariants)&&u.responsiveVariants.length>0||!0===u.responsiveVariants,m=null==d?void 0:d[n],h=[];if("object"==typeof f&&p)for(let[e,n]of Object.entries(f)){let r=l[n];if("initial"===e){m=n;continue}Array.isArray(u.responsiveVariants)&&!u.responsiveVariants.includes(e)||(h=t(e,r,h,o))}let v=l[f]||l[tS(m)];return"object"==typeof h&&"string"==typeof o&&h[o]?ns(h,v):h.length>0?(h.push(v),h):v},l=(e,t)=>{if(!c||"object"!=typeof c)return null;let n=[];for(let r in c){let i=o(r,c,e,t),a="base"===e&&"string"==typeof i?i:i&&i[e];a&&(n[n.length]=a)}return n},p={};for(let t in e)void 0!==e[t]&&(p[t]=e[t]);let h=(t,n)=>{var r;let o="object"==typeof(null==e?void 0:e[t])?{[t]:null==(r=e[t])?void 0:r.initial}:{};return{...d,...p,...o,...n}},v=(e=[],t)=>{let n=[];for(let{class:r,className:o,...i}of e){let e=!0;for(let[n,r]of Object.entries(i)){let o=h(n,t);if(Array.isArray(r)){if(!r.includes(o[n])){e=!1;break}}else if(o[n]!==r){e=!1;break}}e&&(r&&n.push(r),o&&n.push(o))}return n},g=e=>{let t=v(i,e);return tP(v(null==n?void 0:n.compoundVariants,e),t)},b=e=>{let t=g(e);if(!Array.isArray(t))return t;let n={};for(let e of t)if("string"==typeof e&&(n.base=nu(n.base,e)(u)),"object"==typeof e)for(let[t,r]of Object.entries(e))n[t]=nu(n[t],r)(u);return n},y=e=>{if(a.length<1)return null;let t={};for(let{slots:n=[],class:r,className:o,...i}of a){if(!tM(i)){let t=!0;for(let n of Object.keys(i)){let r=h(n,e)[n];if(void 0===r||(Array.isArray(i[n])?!i[n].includes(r):i[n]!==r)){t=!1;break}}if(!t)continue}for(let e of n)t[e]=t[e]||[],t[e].push([r,o])}return t};if(!tM(r)||!f){let e={};if("object"==typeof m&&!tM(m))for(let t of Object.keys(m))e[t]=e=>{var n,r;return nu(m[t],l(t,e),(null!=(n=b(e))?n:[])[t],(null!=(r=y(e))?r:[])[t],null==e?void 0:e.class,null==e?void 0:e.className)(u)};return e}return nu(s,c?Object.keys(c).map(e=>o(e,c)):null,g(),null==e?void 0:e.class,null==e?void 0:e.className)(u)};return h.variantKeys=(()=>{if(!(!c||"object"!=typeof c))return Object.keys(c)})(),h.extend=n,h.base=s,h.slots=m,h.variants=c,h.defaultVariants=d,h.compoundSlots=a,h.compoundVariants=i,h})({slots:{base:["z-0","relative","bg-transparent","before:content-['']","before:hidden","before:z-[-1]","before:absolute","before:rotate-45","before:w-2.5","before:h-2.5","before:rounded-sm","data-[arrow=true]:before:block","data-[placement=top]:before:-bottom-[calc(theme(spacing.5)/4_-_1.5px)]","data-[placement=top]:before:left-1/2","data-[placement=top]:before:-translate-x-1/2","data-[placement=top-start]:before:-bottom-[calc(theme(spacing.5)/4_-_1.5px)]","data-[placement=top-start]:before:left-3","data-[placement=top-end]:before:-bottom-[calc(theme(spacing.5)/4_-_1.5px)]","data-[placement=top-end]:before:right-3","data-[placement=bottom]:before:-top-[calc(theme(spacing.5)/4_-_1.5px)]","data-[placement=bottom]:before:left-1/2","data-[placement=bottom]:before:-translate-x-1/2","data-[placement=bottom-start]:before:-top-[calc(theme(spacing.5)/4_-_1.5px)]","data-[placement=bottom-start]:before:left-3","data-[placement=bottom-end]:before:-top-[calc(theme(spacing.5)/4_-_1.5px)]","data-[placement=bottom-end]:before:right-3","data-[placement=left]:before:-right-[calc(theme(spacing.5)/4_-_2px)]","data-[placement=left]:before:top-1/2","data-[placement=left]:before:-translate-y-1/2","data-[placement=left-start]:before:-right-[calc(theme(spacing.5)/4_-_3px)]","data-[placement=left-start]:before:top-1/4","data-[placement=left-end]:before:-right-[calc(theme(spacing.5)/4_-_3px)]","data-[placement=left-end]:before:bottom-1/4","data-[placement=right]:before:-left-[calc(theme(spacing.5)/4_-_2px)]","data-[placement=right]:before:top-1/2","data-[placement=right]:before:-translate-y-1/2","data-[placement=right-start]:before:-left-[calc(theme(spacing.5)/4_-_3px)]","data-[placement=right-start]:before:top-1/4","data-[placement=right-end]:before:-left-[calc(theme(spacing.5)/4_-_3px)]","data-[placement=right-end]:before:bottom-1/4","outline-none","data-[focus-visible=true]:z-10","data-[focus-visible=true]:outline-2","data-[focus-visible=true]:outline-focus","data-[focus-visible=true]:outline-offset-2"],content:["z-10","px-2.5","py-1","w-full","inline-flex","flex-col","items-center","justify-center","box-border","subpixel-antialiased","outline-none","box-border"],trigger:["z-10"],backdrop:["hidden"],arrow:[]},variants:{size:{sm:{content:"text-tiny"},md:{content:"text-small"},lg:{content:"text-medium"}},color:{default:{base:"before:bg-content1 before:shadow-small",content:"bg-content1"},foreground:{base:"before:bg-foreground",content:"bg-foreground text-background"},primary:{base:"before:bg-primary",content:"bg-primary text-primary-foreground"},secondary:{base:"before:bg-secondary",content:"bg-secondary text-secondary-foreground"},success:{base:"before:bg-success",content:"bg-success text-success-foreground"},warning:{base:"before:bg-warning",content:"bg-warning text-warning-foreground"},danger:{base:"before:bg-danger",content:"bg-danger text-danger-foreground"}},radius:{none:{content:"rounded-none"},sm:{content:"rounded-small"},md:{content:"rounded-medium"},lg:{content:"rounded-large"},full:{content:"rounded-full"}},shadow:{sm:{content:"shadow-small"},md:{content:"shadow-medium"},lg:{content:"shadow-large"}},backdrop:{transparent:{},opaque:{backdrop:"bg-overlay/50 backdrop-opacity-disabled"},blur:{backdrop:"backdrop-blur-sm backdrop-saturate-150 bg-overlay/30"}},triggerScaleOnOpen:{true:{trigger:["aria-expanded:scale-[0.97]","aria-expanded:opacity-70","subpixel-antialiased"]},false:{}},disableAnimation:{true:{base:"animate-none"}},isTriggerDisabled:{true:{trigger:"opacity-disabled pointer-events-none"},false:{}}},defaultVariants:{color:"default",radius:"lg",size:"md",shadow:"md",backdrop:"transparent",triggerScaleOnOpen:!0},compoundVariants:[{backdrop:["opaque","blur"],class:{backdrop:"block w-full h-full fixed inset-0 -z-30"}}]},{...a,twMerge:null==(l=null==a?void 0:a.twMerge)||l,twMergeConfig:{...null==a?void 0:a.twMergeConfig,theme:{...null==(u=null==a?void 0:a.twMergeConfig)?void 0:u.theme,...tC.theme},classGroups:{...null==(s=null==a?void 0:a.twMergeConfig)?void 0:s.classGroups,...tC.classGroups}}}),nd=Object.create,nf=Object.defineProperty,np=Object.getOwnPropertyDescriptor,nm=Object.getOwnPropertyNames,nh=Object.getPrototypeOf,nv=Object.prototype.hasOwnProperty,ng=(e,t)=>function(){return t||(0,e[nm(e)[0]])((t={exports:{}}).exports,t),t.exports},nb=ng({"../../../node_modules/.pnpm/react@18.2.0/node_modules/react/cjs/react.production.min.js"(e){var t=Symbol.for("react.element"),n=Symbol.for("react.portal"),r=Symbol.for("react.fragment"),o=Symbol.for("react.strict_mode"),i=Symbol.for("react.profiler"),a=Symbol.for("react.provider"),l=Symbol.for("react.context"),u=Symbol.for("react.forward_ref"),s=Symbol.for("react.suspense"),c=Symbol.for("react.memo"),d=Symbol.for("react.lazy"),f=Symbol.iterator,p={isMounted:function(){return!1},enqueueForceUpdate:function(){},enqueueReplaceState:function(){},enqueueSetState:function(){}},m=Object.assign,h={};function v(e,t,n){this.props=e,this.context=t,this.refs=h,this.updater=n||p}function g(){}function b(e,t,n){this.props=e,this.context=t,this.refs=h,this.updater=n||p}v.prototype.isReactComponent={},v.prototype.setState=function(e,t){if("object"!=typeof e&&"function"!=typeof e&&null!=e)throw Error("setState(...): takes an object of state variables to update or a function which returns an object of state variables.");this.updater.enqueueSetState(this,e,t,"setState")},v.prototype.forceUpdate=function(e){this.updater.enqueueForceUpdate(this,e,"forceUpdate")},g.prototype=v.prototype;var y=b.prototype=new g;y.constructor=b,m(y,v.prototype),y.isPureReactComponent=!0;var w=Array.isArray,x=Object.prototype.hasOwnProperty,E={current:null},C={key:!0,ref:!0,__self:!0,__source:!0};function S(e,n,r){var o,i={},a=null,l=null;if(null!=n)for(o in void 0!==n.ref&&(l=n.ref),void 0!==n.key&&(a=""+n.key),n)x.call(n,o)&&!C.hasOwnProperty(o)&&(i[o]=n[o]);var u=arguments.length-2;if(1===u)i.children=r;else if(1<u){for(var s=Array(u),c=0;c<u;c++)s[c]=arguments[c+2];i.children=s}if(e&&e.defaultProps)for(o in u=e.defaultProps)void 0===i[o]&&(i[o]=u[o]);return{$$typeof:t,type:e,key:a,ref:l,props:i,_owner:E.current}}function M(e){return"object"==typeof e&&null!==e&&e.$$typeof===t}var k=/\/+/g;function T(e,t){var n,r;return"object"==typeof e&&null!==e&&null!=e.key?(n=""+e.key,r={"=":"=0",":":"=2"},"$"+n.replace(/[=:]/g,function(e){return r[e]})):t.toString(36)}function P(e,r,o){if(null==e)return e;var i=[],a=0;return!function e(r,o,i,a,l){var u,s,c,d=typeof r;("undefined"===d||"boolean"===d)&&(r=null);var p=!1;if(null===r)p=!0;else switch(d){case"string":case"number":p=!0;break;case"object":switch(r.$$typeof){case t:case n:p=!0}}if(p)return l=l(p=r),r=""===a?"."+T(p,0):a,w(l)?(i="",null!=r&&(i=r.replace(k,"$&/")+"/"),e(l,o,i,"",function(e){return e})):null!=l&&(M(l)&&(u=l,s=i+(!l.key||p&&p.key===l.key?"":(""+l.key).replace(k,"$&/")+"/")+r,l={$$typeof:t,type:u.type,key:s,ref:u.ref,props:u.props,_owner:u._owner}),o.push(l)),1;if(p=0,a=""===a?".":a+":",w(r))for(var m=0;m<r.length;m++){var h=a+T(d=r[m],m);p+=e(d,o,i,h,l)}else if("function"==typeof(h=null===(c=r)||"object"!=typeof c?null:"function"==typeof(c=f&&c[f]||c["@@iterator"])?c:null))for(r=h.call(r),m=0;!(d=r.next()).done;)h=a+T(d=d.value,m++),p+=e(d,o,i,h,l);else if("object"===d)throw Error("Objects are not valid as a React child (found: "+("[object Object]"===(o=String(r))?"object with keys {"+Object.keys(r).join(", ")+"}":o)+"). If you meant to render a collection of children, use an array instead.");return p}(e,i,"","",function(e){return r.call(o,e,a++)}),i}function R(e){if(-1===e._status){var t=e._result;(t=t()).then(function(t){(0===e._status||-1===e._status)&&(e._status=1,e._result=t)},function(t){(0===e._status||-1===e._status)&&(e._status=2,e._result=t)}),-1===e._status&&(e._status=0,e._result=t)}if(1===e._status)return e._result.default;throw e._result}var L={current:null},j={transition:null};e.Children={map:P,forEach:function(e,t,n){P(e,function(){t.apply(this,arguments)},n)},count:function(e){var t=0;return P(e,function(){t++}),t},toArray:function(e){return P(e,function(e){return e})||[]},only:function(e){if(!M(e))throw Error("React.Children.only expected to receive a single React element child.");return e}},e.Component=v,e.Fragment=r,e.Profiler=i,e.PureComponent=b,e.StrictMode=o,e.Suspense=s,e.__SECRET_INTERNALS_DO_NOT_USE_OR_YOU_WILL_BE_FIRED={ReactCurrentDispatcher:L,ReactCurrentBatchConfig:j,ReactCurrentOwner:E},e.cloneElement=function(e,n,r){if(null==e)throw Error("React.cloneElement(...): The argument must be a React element, but you passed "+e+".");var o=m({},e.props),i=e.key,a=e.ref,l=e._owner;if(null!=n){if(void 0!==n.ref&&(a=n.ref,l=E.current),void 0!==n.key&&(i=""+n.key),e.type&&e.type.defaultProps)var u=e.type.defaultProps;for(s in n)x.call(n,s)&&!C.hasOwnProperty(s)&&(o[s]=void 0===n[s]&&void 0!==u?u[s]:n[s])}var s=arguments.length-2;if(1===s)o.children=r;else if(1<s){u=Array(s);for(var c=0;c<s;c++)u[c]=arguments[c+2];o.children=u}return{$$typeof:t,type:e.type,key:i,ref:a,props:o,_owner:l}},e.createContext=function(e){return(e={$$typeof:l,_currentValue:e,_currentValue2:e,_threadCount:0,Provider:null,Consumer:null,_defaultValue:null,_globalName:null}).Provider={$$typeof:a,_context:e},e.Consumer=e},e.createElement=S,e.createFactory=function(e){var t=S.bind(null,e);return t.type=e,t},e.createRef=function(){return{current:null}},e.forwardRef=function(e){return{$$typeof:u,render:e}},e.isValidElement=M,e.lazy=function(e){return{$$typeof:d,_payload:{_status:-1,_result:e},_init:R}},e.memo=function(e,t){return{$$typeof:c,type:e,compare:void 0===t?null:t}},e.startTransition=function(e){var t=j.transition;j.transition={};try{e()}finally{j.transition=t}},e.unstable_act=function(){throw Error("act(...) is not supported in production builds of React.")},e.useCallback=function(e,t){return L.current.useCallback(e,t)},e.useContext=function(e){return L.current.useContext(e)},e.useDebugValue=function(){},e.useDeferredValue=function(e){return L.current.useDeferredValue(e)},e.useEffect=function(e,t){return L.current.useEffect(e,t)},e.useId=function(){return L.current.useId()},e.useImperativeHandle=function(e,t,n){return L.current.useImperativeHandle(e,t,n)},e.useInsertionEffect=function(e,t){return L.current.useInsertionEffect(e,t)},e.useLayoutEffect=function(e,t){return L.current.useLayoutEffect(e,t)},e.useMemo=function(e,t){return L.current.useMemo(e,t)},e.useReducer=function(e,t,n){return L.current.useReducer(e,t,n)},e.useRef=function(e){return L.current.useRef(e)},e.useState=function(e){return L.current.useState(e)},e.useSyncExternalStore=function(e,t,n){return L.current.useSyncExternalStore(e,t,n)},e.useTransition=function(){return L.current.useTransition()},e.version="18.2.0"}});ng({"../../../node_modules/.pnpm/react@18.2.0/node_modules/react/cjs/react.development.js"(e,t){}}),i=null!=(r=ng({"../../../node_modules/.pnpm/react@18.2.0/node_modules/react/index.js"(e,t){t.exports=nb()}})())?nd(nh(r)):{},((e,t,n,r)=>{if(t&&"object"==typeof t||"function"==typeof t)for(let o of nm(t))nv.call(e,o)||o===n||nf(e,o,{get:()=>t[o],enumerable:!(r=np(t,o))||r.enumerable})})(!o&&r&&r.__esModule?i:nf(i,"default",{value:r,enumerable:!0}),r);var ny=e=>e?"true":void 0;"undefined"!=typeof window&&window.document&&window.document.createElement;var nw=e=>{let t={top:{originY:1},bottom:{originY:0},left:{originX:1},right:{originX:0},"top-start":{originX:0,originY:1},"top-end":{originX:1,originY:1},"bottom-start":{originX:0,originY:0},"bottom-end":{originX:1,originY:0},"right-start":{originX:0,originY:0},"right-end":{originX:0,originY:1},"left-start":{originX:1,originY:0},"left-end":{originX:1,originY:1}};return(null==t?void 0:t[e])||{}},nx=e=>({top:"top",bottom:"bottom",left:"left",right:"right","top-start":"top start","top-end":"top end","bottom-start":"bottom start","bottom-end":"bottom end","left-start":"left top","left-end":"left bottom","right-start":"right top","right-end":"right bottom"})[e],nE=(e,t)=>{if(t.includes("-")){let[,n]=t.split("-");return`${e}-${n}`}return e},nC=(null==globalThis?void 0:globalThis.document)?f.useLayoutEffect:f.useEffect,nS=n(73935);let nM=f.createContext(null);function nk(e){let{children:t}=e,n=(0,f.useContext)(nM),[r,o]=(0,f.useState)(0),i=(0,f.useMemo)(()=>({parent:n,modalCount:r,addModal(){o(e=>e+1),n&&n.addModal()},removeModal(){o(e=>e-1),n&&n.removeModal()}}),[n,r]);return f.createElement(nM.Provider,{value:i},t)}function nT(e){let t;let{modalProviderProps:n}={modalProviderProps:{"aria-hidden":!!(t=(0,f.useContext)(nM))&&t.modalCount>0||void 0}};return f.createElement("div",{"data-overlay-container":!0,...e,...n})}function nP(e){return f.createElement(nk,null,f.createElement(nT,e))}function nR(e){let t=T(),{portalContainer:n=t?null:document.body,...r}=e;if(f.useEffect(()=>{if(null==n?void 0:n.closest("[data-overlay-container]"))throw Error("An OverlayContainer must not be inside another container. Please change the portalContainer prop.")},[n]),!n)return null;let o=f.createElement(nP,r);return nS.createPortal(o,n)}var nL=n(85893);let nj=(0,f.createContext)({strict:!1});var nA=n(9442);function nO(e){for(let t in e)nA.featureDefinitions[t]={...nA.featureDefinitions[t],...e[t]}}function nD({children:e,features:t,strict:n=!1}){let[,r]=(0,f.useState)(!nW(t)),o=(0,f.useRef)(void 0);if(!nW(t)){let{renderer:e,...n}=t;o.current=e,nO(n)}return(0,f.useEffect)(()=>{nW(t)&&t().then(({renderer:e,...t})=>{nO(t),o.current=e,r(!0)})},[]),(0,nL.jsx)(nj.Provider,{value:{renderer:o.current,strict:n},children:e})}function nW(e){return"function"==typeof e}let nN=(0,f.createContext)({}),nI=(0,f.createContext)({transformPagePoint:e=>e,isStatic:!1,reducedMotion:"never"}),n_=(0,f.createContext)({});var nz=n(7504),nF=n(97732);function nH(e){return Array.isArray(e)?e.join(" "):e}var n$=n(11741);let nV=Symbol.for("motionComponentSymbol");function nB(e){return e&&"object"==typeof e&&Object.prototype.hasOwnProperty.call(e,"current")}let{schedule:nX,cancel:nY}=(0,n(93674).Z)(queueMicrotask,!1);var nU=n(68588);let nq=(0,f.createContext)(null),nK=(0,f.createContext)({}),nZ=n$.j?f.useLayoutEffect:f.useEffect;var nG=n(32558),nJ=n(96728),nQ=n(41069);let n0=()=>({style:{},transform:{},transformOrigin:{},vars:{}});function n1(e,t,n){for(let r in t)(0,nG.i)(t[r])||(0,nJ.j)(r,n)||(e[r]=t[r])}var n2=n(42617);let n5=()=>({...n0(),attrs:{}});var n9=n(79854);let n4=new Set(["animate","exit","variants","initial","style","values","variants","transition","transformTemplate","custom","inherit","onBeforeLayoutMeasure","onAnimationStart","onAnimationComplete","onUpdate","onDragStart","onDrag","onDragEnd","onMeasureDragConstraints","onDirectionLock","onDragTransitionEnd","_dragX","_dragY","onHoverStart","onHoverEnd","onViewportEnter","onViewportLeave","globalTapTarget","ignoreStrict","viewport"]);function n3(e){return e.startsWith("while")||e.startsWith("drag")&&"draggable"!==e||e.startsWith("layout")||e.startsWith("onTap")||e.startsWith("onPan")||e.startsWith("onLayout")||n4.has(e)}let n7=e=>!n3(e);try{c=require("@emotion/is-prop-valid").default,"function"==typeof c&&(n7=e=>e.startsWith("on")?!n3(e):c(e))}catch{}var n6=n(62627),n8=n(2445),re=n(79432);function rt(e){let t=(0,f.useRef)(null);return null===t.current&&(t.current=e()),t.current}let rn=e=>(t,n)=>{let r=(0,f.useContext)(n_),o=(0,f.useContext)(nq),i=()=>(function({scrapeMotionValuesFromProps:e,createRenderState:t},n,r,o){return{latestValues:function(e,t,n,r){let o={},i=r(e,{});for(let e in i){var a;o[e]=(a=i[e],(0,nG.i)(a)?a.get():a)}let{initial:l,animate:u}=e,s=(0,nz.G)(e),c=(0,nz.M)(e);t&&c&&!s&&!1!==e.inherit&&(void 0===l&&(l=t.initial),void 0===u&&(u=t.animate));let d=!!n&&!1===n.initial,f=(d=d||!1===l)?u:l;if(f&&"boolean"!=typeof f&&!(0,n8.H)(f)){let t=Array.isArray(f)?f:[f];for(let n=0;n<t.length;n++){let r=(0,re.o)(e,t[n]);if(r){let{transitionEnd:e,transition:t,...n}=r;for(let e in n){let t=n[e];if(Array.isArray(t)){let e=d?t.length-1:0;t=t[e]}null!==t&&(o[e]=t)}for(let t in e)o[t]=e[t]}}}return o}(n,r,o,e),renderState:t()}})(e,t,r,o);return n?i():rt(i)},rr={useVisualState:rn({scrapeMotionValuesFromProps:n(50189).U,createRenderState:n0})},ro={useVisualState:rn({scrapeMotionValuesFromProps:n(16832).U,createRenderState:n5})},ri=function(e){if("undefined"==typeof Proxy)return e;let t=new Map;return new Proxy((...t)=>e(...t),{get:(n,r)=>"create"===r?e:(t.has(r)||t.set(r,e(r)),t.get(r))})}(function(e,{forwardMotionProps:t}={forwardMotionProps:!1}){return function({preloadedFeatures:e,createVisualElement:t,useRender:n,useVisualState:r,Component:o}){function i(e,i){var a;let l;let u={...(0,f.useContext)(nI),...e,layoutId:function({layoutId:e}){let t=(0,f.useContext)(nN).id;return t&&void 0!==e?t+"-"+e:e}(e)},{isStatic:s}=u,c=function(e){let{initial:t,animate:n}=function(e,t){if((0,nz.G)(e)){let{initial:t,animate:n}=e;return{initial:!1===t||(0,nF.$)(t)?t:void 0,animate:(0,nF.$)(n)?n:void 0}}return!1!==e.inherit?t:{}}(e,(0,f.useContext)(n_));return(0,f.useMemo)(()=>({initial:t,animate:n}),[nH(t),nH(n)])}(e),d=r(e,s);if(!s&&n$.j){(0,f.useContext)(nj).strict;let e=function(e){let{drag:t,layout:n}=nA.featureDefinitions;if(!t&&!n)return{};let r={...t,...n};return{MeasureLayout:t?.isEnabled(e)||n?.isEnabled(e)?r.MeasureLayout:void 0,ProjectionNode:r.ProjectionNode}}(u);l=e.MeasureLayout,c.visualElement=function(e,t,n,r,o){let{visualElement:i}=(0,f.useContext)(n_),a=(0,f.useContext)(nj),l=(0,f.useContext)(nq),u=(0,f.useContext)(nI).reducedMotion,s=(0,f.useRef)(null);r=r||a.renderer,!s.current&&r&&(s.current=r(e,{visualState:t,parent:i,props:n,presenceContext:l,blockInitialAnimation:!!l&&!1===l.initial,reducedMotionConfig:u}));let c=s.current,d=(0,f.useContext)(nK);c&&!c.projection&&o&&("html"===c.type||"svg"===c.type)&&function(e,t,n,r){let{layoutId:o,layout:i,drag:a,dragConstraints:l,layoutScroll:u,layoutRoot:s,layoutCrossfade:c}=t;e.projection=new n(e.latestValues,t["data-framer-portal-id"]?void 0:function e(t){if(t)return!1!==t.options.allowProjection?t.projection:e(t.parent)}(e.parent)),e.projection.setOptions({layoutId:o,layout:i,alwaysMeasureLayout:!!a||l&&nB(l),visualElement:e,animationType:"string"==typeof i?i:"both",initialPromotionConfig:r,crossfade:c,layoutScroll:u,layoutRoot:s})}(s.current,n,o,d);let p=(0,f.useRef)(!1);(0,f.useInsertionEffect)(()=>{c&&p.current&&c.update(n,l)});let m=n[nU.M],h=(0,f.useRef)(!!m&&!window.MotionHandoffIsComplete?.(m)&&window.MotionHasOptimisedAnimation?.(m));return nZ(()=>{c&&(p.current=!0,window.MotionIsMounted=!0,c.updateFeatures(),nX.render(c.render),h.current&&c.animationState&&c.animationState.animateChanges())}),(0,f.useEffect)(()=>{c&&(!h.current&&c.animationState&&c.animationState.animateChanges(),h.current&&(queueMicrotask(()=>{window.MotionHandoffMarkAsComplete?.(m)}),h.current=!1))}),c}(o,d,u,t,e.ProjectionNode)}return(0,nL.jsxs)(n_.Provider,{value:c,children:[l&&c.visualElement?(0,nL.jsx)(l,{visualElement:c.visualElement,...u}):null,n(o,e,(a=c.visualElement,(0,f.useCallback)(e=>{e&&d.onMount&&d.onMount(e),a&&(e?a.mount(e):a.unmount()),i&&("function"==typeof i?i(e):nB(i)&&(i.current=e))},[a])),d,s,c.visualElement)]})}e&&nO(e),i.displayName=`motion.${"string"==typeof o?o:`create(${o.displayName??o.name??""})`}`;let a=(0,f.forwardRef)(i);return a[nV]=o,a}({...(0,n6.q)(e)?ro:rr,preloadedFeatures:void 0,useRender:function(e=!1){return(t,n,r,{latestValues:o},i)=>{let a=((0,n6.q)(t)?function(e,t,n,r){let o=(0,f.useMemo)(()=>{let n=n5();return(0,n2.i)(n,t,(0,n9.a)(r),e.transformTemplate,e.style),{...n.attrs,style:{...n.style}}},[t]);if(e.style){let t={};n1(t,e.style,e),o.style={...t,...o.style}}return o}:function(e,t){let n={},r=function(e,t){let n=e.style||{},r={};return n1(r,n,e),Object.assign(r,function({transformTemplate:e},t){return(0,f.useMemo)(()=>{let n=n0();return(0,nQ.r)(n,t,e),Object.assign({},n.vars,n.style)},[t])}(e,t)),r}(e,t);return e.drag&&!1!==e.dragListener&&(n.draggable=!1,r.userSelect=r.WebkitUserSelect=r.WebkitTouchCallout="none",r.touchAction=!0===e.drag?"none":`pan-${"x"===e.drag?"y":"x"}`),void 0===e.tabIndex&&(e.onTap||e.onTapStart||e.whileTap)&&(n.tabIndex=0),n.style=r,n})(n,o,i,t),l=function(e,t,n){let r={};for(let o in e)("values"!==o||"object"!=typeof e.values)&&(n7(o)||!0===n&&n3(o)||!t&&!n3(o)||e.draggable&&o.startsWith("onDrag"))&&(r[o]=e[o]);return r}(n,"string"==typeof t,e),u=t!==f.Fragment?{...l,...a,ref:r}:{},{children:s}=n,c=(0,f.useMemo)(()=>(0,nG.i)(s)?s.get():s,[s]);return(0,f.createElement)(t,{...u,children:c})}}(t),createVisualElement:void 0,Component:e})});var ra=n(77596);class rl extends f.Component{getSnapshotBeforeUpdate(e){let t=this.props.childRef.current;if(t&&e.isPresent&&!this.props.isPresent){let e=t.offsetParent,n=(0,ra.R)(e)&&e.offsetWidth||0,r=this.props.sizeRef.current;r.height=t.offsetHeight||0,r.width=t.offsetWidth||0,r.top=t.offsetTop,r.left=t.offsetLeft,r.right=n-r.width-r.left}return null}componentDidUpdate(){}render(){return this.props.children}}function ru({children:e,isPresent:t,anchorX:n}){let r=(0,f.useId)(),o=(0,f.useRef)(null),i=(0,f.useRef)({width:0,height:0,top:0,left:0,right:0}),{nonce:a}=(0,f.useContext)(nI);return(0,f.useInsertionEffect)(()=>{let{width:e,height:l,top:u,left:s,right:c}=i.current;if(t||!o.current||!e||!l)return;let d="left"===n?`left: ${s}`:`right: ${c}`;o.current.dataset.motionPopId=r;let f=document.createElement("style");return a&&(f.nonce=a),document.head.appendChild(f),f.sheet&&f.sheet.insertRule(`
          [data-motion-pop-id="${r}"] {
            position: absolute !important;
            width: ${e}px !important;
            height: ${l}px !important;
            ${d}px !important;
            top: ${u}px !important;
          }
        `),()=>{document.head.contains(f)&&document.head.removeChild(f)}},[t]),(0,nL.jsx)(rl,{isPresent:t,childRef:o,sizeRef:i,children:f.cloneElement(e,{ref:o})})}let rs=({children:e,initial:t,isPresent:n,onExitComplete:r,custom:o,presenceAffectsLayout:i,mode:a,anchorX:l})=>{let u=rt(rc),s=(0,f.useId)(),c=!0,d=(0,f.useMemo)(()=>(c=!1,{id:s,initial:t,isPresent:n,custom:o,onExitComplete:e=>{for(let t of(u.set(e,!0),u.values()))if(!t)return;r&&r()},register:e=>(u.set(e,!1),()=>u.delete(e))}),[n,u,r]);return i&&c&&(d={...d}),(0,f.useMemo)(()=>{u.forEach((e,t)=>u.set(t,!1))},[n]),f.useEffect(()=>{n||u.size||!r||r()},[n]),"popLayout"===a&&(e=(0,nL.jsx)(ru,{isPresent:n,anchorX:l,children:e})),(0,nL.jsx)(nq.Provider,{value:d,children:e})};function rc(){return new Map}let rd=e=>e.key||"";function rf(e){let t=[];return f.Children.forEach(e,e=>{(0,f.isValidElement)(e)&&t.push(e)}),t}let rp=({children:e,custom:t,initial:n=!0,onExitComplete:r,presenceAffectsLayout:o=!0,mode:i="sync",propagate:a=!1,anchorX:l="left"})=>{let[u,s]=function(e=!0){let t=(0,f.useContext)(nq);if(null===t)return[!0,null];let{isPresent:n,onExitComplete:r,register:o}=t,i=(0,f.useId)();(0,f.useEffect)(()=>{if(e)return o(i)},[e]);let a=(0,f.useCallback)(()=>e&&r&&r(i),[i,r,e]);return!n&&r?[!1,a]:[!0]}(a),c=(0,f.useMemo)(()=>rf(e),[e]),d=a&&!u?[]:c.map(rd),p=(0,f.useRef)(!0),m=(0,f.useRef)(c),h=rt(()=>new Map),[v,g]=(0,f.useState)(c),[b,y]=(0,f.useState)(c);nZ(()=>{p.current=!1,m.current=c;for(let e=0;e<b.length;e++){let t=rd(b[e]);d.includes(t)?h.delete(t):!0!==h.get(t)&&h.set(t,!1)}},[b,d.length,d.join("-")]);let w=[];if(c!==v){let e=[...c];for(let t=0;t<b.length;t++){let n=b[t],r=rd(n);d.includes(r)||(e.splice(t,0,n),w.push(n))}return"wait"===i&&w.length&&(e=w),y(rf(e)),g(c),null}let{forceRender:x}=(0,f.useContext)(nN);return(0,nL.jsx)(nL.Fragment,{children:b.map(e=>{let f=rd(e),v=(!a||!!u)&&(c===b||d.includes(f));return(0,nL.jsx)(rs,{isPresent:v,initial:(!p.current||!!n)&&void 0,custom:t,presenceAffectsLayout:o,mode:i,onExitComplete:v?void 0:()=>{if(!h.has(f))return;h.set(f,!0);let e=!0;h.forEach(t=>{t||(e=!1)}),e&&(x?.(),y(m.current),a&&s?.(),r&&r())},anchorX:l,children:e},f)})})};var rm={enter:{transform:"scale(1)",opacity:1,transition:{type:"spring",bounce:0,duration:.2}},exit:{transform:"scale(0.85)",opacity:0,transition:{type:"easeOut",duration:.15}}},rh={},rv=()=>n.e(3937).then(n.bind(n,83937)).then(e=>e.default),rg=(d=(e,t)=>{let n;let{Component:r,children:o,content:i,isOpen:a,portalContainer:l,placement:u,disableAnimation:s,motionProps:c,getTriggerProps:d,getTooltipProps:y,getTooltipContentProps:w}=function(e){var t,n;let r=tw(),[o,i]=tx(e,nc.variantKeys),{ref:a,as:l,isOpen:u,content:s,children:c,defaultOpen:d,onOpenChange:y,isDisabled:w,trigger:x,shouldFlip:E=!0,containerPadding:S=12,placement:M="top",delay:k=0,closeDelay:L=500,showArrow:A=!1,offset:O=7,crossOffset:D=0,isDismissable:W,shouldCloseOnBlur:N=!0,portalContainer:I,isKeyboardDismissDisabled:_=!1,updatePositionDeps:z=[],shouldCloseOnInteractOutside:F,className:H,onClose:V,motionProps:X,classNames:Y,...U}=o,q=null!=(n=null!=(t=null==e?void 0:e.disableAnimation)?t:null==r?void 0:r.disableAnimation)&&n,K=function(e={}){let{delay:t=1500,closeDelay:n=500}=e,{isOpen:r,open:o,close:i}=function(e){let[t,n]=function(e,t,n){let[r,o]=(0,f.useState)(e||t),i=(0,f.useRef)(void 0!==e),a=void 0!==e;(0,f.useEffect)(()=>{let e=i.current;e!==a&&console.warn(`WARN: A component changed from ${e?"controlled":"uncontrolled"} to ${a?"controlled":"uncontrolled"}.`),i.current=a},[a]);let l=a?e:r,u=(0,f.useCallback)((e,...t)=>{let r=(e,...t)=>{n&&!Object.is(l,e)&&n(e,...t),a||(l=e)};"function"==typeof e?(console.warn("We can not support a function callback. See Github Issues for details https://github.com/adobe/react-spectrum/issues/2320"),o((n,...o)=>{let i=e(a?l:n,...o);return(r(i,...t),a)?n:i})):(a||o(e),r(e,...t))},[a,l,n]);return[l,u]}(e.isOpen,e.defaultOpen||!1,e.onOpenChange),r=(0,f.useCallback)(()=>{n(!0)},[n]),o=(0,f.useCallback)(()=>{n(!1)},[n]),i=(0,f.useCallback)(()=>{n(!t)},[n,t]);return{isOpen:t,setOpen:n,open:r,close:o,toggle:i}}(e),a=(0,f.useMemo)(()=>`${++m}`,[]),l=(0,f.useRef)(null),u=(0,f.useRef)(i),s=()=>{p[a]=b},c=()=>{for(let e in p)e!==a&&(p[e](!0),delete p[e])},d=()=>{l.current&&clearTimeout(l.current),l.current=null,c(),s(),h=!0,o(),v&&(clearTimeout(v),v=null),g&&(clearTimeout(g),g=null)},b=e=>{e||n<=0?(l.current&&clearTimeout(l.current),l.current=null,u.current()):l.current||(l.current=setTimeout(()=>{l.current=null,u.current()},n)),v&&(clearTimeout(v),v=null),h&&(g&&clearTimeout(g),g=setTimeout(()=>{delete p[a],g=null,h=!1},Math.max(500,n)))},y=()=>{c(),s(),r||v||h?r||d():v=setTimeout(()=>{v=null,h=!0,d()},t)};return(0,f.useEffect)(()=>{u.current=i},[i]),(0,f.useEffect)(()=>()=>{l.current&&clearTimeout(l.current),p[a]&&delete p[a]},[a]),{isOpen:r,open:e=>{e||!(t>0)||l.current?d():y()},close:b}}({delay:k,closeDelay:L,isDisabled:w,defaultOpen:d,isOpen:u,onOpenChange:e=>{null==y||y(e),e||null==V||V()}}),Z=(0,f.useRef)(null),G=(0,f.useRef)(null),J=(0,f.useId)(),Q=K.isOpen&&!w;(0,f.useImperativeHandle)(a,()=>({UNSAFE_getDOMNode:()=>G.current}));let{triggerProps:ee,tooltipProps:et}=function(e,t,n){let{isDisabled:r,trigger:o}=e,i=function(e){let[t,n]=(0,f.useState)(void 0),r=(0,f.useRef)(null),o=C(t),i=(0,f.useCallback)(e=>{r.current=e},[]);return P&&(R.has(o)&&!R.get(o).includes(i)?R.set(o,[...R.get(o),i]):R.set(o,[i])),b(()=>()=>{R.delete(o)},[o]),(0,f.useEffect)(()=>{let e=r.current;e&&(r.current=null,n(e))}),o}(),a=(0,f.useRef)(!1),l=(0,f.useRef)(!1),u=()=>{(a.current||l.current)&&t.open(l.current)},s=e=>{a.current||l.current||t.close(e)};(0,f.useEffect)(()=>{let e=e=>{n&&n.current&&"Escape"===e.key&&(e.stopPropagation(),t.close(!0))};if(t.isOpen)return document.addEventListener("keydown",e,!0),()=>{document.removeEventListener("keydown",e,!0)}},[n,t]);let c=()=>{l.current=!1,a.current=!1,s(!0)},{hoverProps:d}=eu({isDisabled:r,onHoverStart:()=>{"focus"!==o&&("pointer"===B?a.current=!0:a.current=!1,u())},onHoverEnd:()=>{"focus"!==o&&(l.current=!1,a.current=!1,s())}}),{focusableProps:p}=function(e,t){let{focusProps:n}=function(e){let t,n,{isDisabled:r,onFocus:o,onBlur:i,onFocusChange:a}=e,l=(0,f.useCallback)(e=>{if(e.target===e.currentTarget)return i&&i(e),a&&a(!1),!0},[i,a]),u=(t=(0,f.useRef)({isFocused:!1,observer:null}),es(()=>{let e=t.current;return()=>{e.observer&&(e.observer.disconnect(),e.observer=null)}},[]),n=function(e){let t=(0,f.useRef)(null);return es(()=>{t.current=e},[e]),(0,f.useCallback)((...e)=>{let n=t.current;return null==n?void 0:n(...e)},[])}(e=>{null==l||l(e)}),(0,f.useCallback)(e=>{if(e.target instanceof HTMLButtonElement||e.target instanceof HTMLInputElement||e.target instanceof HTMLTextAreaElement||e.target instanceof HTMLSelectElement){t.current.isFocused=!0;let r=e.target;r.addEventListener("focusout",e=>{t.current.isFocused=!1,r.disabled&&n((e.nativeEvent=e,e.isDefaultPrevented=()=>e.defaultPrevented,e.isPropagationStopped=()=>e.cancelBubble,e.persist=()=>{},e)),t.current.observer&&(t.current.observer.disconnect(),t.current.observer=null)},{once:!0}),t.current.observer=new MutationObserver(()=>{if(t.current.isFocused&&r.disabled){var e;null===(e=t.current.observer)||void 0===e||e.disconnect();let n=r===document.activeElement?null:document.activeElement;r.dispatchEvent(new FocusEvent("blur",{relatedTarget:n})),r.dispatchEvent(new FocusEvent("focusout",{bubbles:!0,relatedTarget:n}))}}),t.current.observer.observe(r,{attributes:!0,attributeFilter:["disabled"]})}},[n])),s=(0,f.useCallback)(e=>{let t=ey(e.target),n=t?eD(t):eD();e.target===e.currentTarget&&n===e.nativeEvent.target&&(o&&o(e),a&&a(!0),u(e))},[a,o,u]);return{focusProps:{onFocus:!r&&(o||a||i)?s:void 0,onBlur:!r&&(i||a)?l:void 0}}}(e),{keyboardProps:r}={keyboardProps:e.isDisabled?{}:{onKeyDown:eF(e.onKeyDown),onKeyUp:eF(e.onKeyUp)}},o=e$(n,r),i=function(e){let t=(0,f.useContext)(eV)||{};es(()=>{if(t&&t.ref&&e)return t.ref.current=e.current,()=>{t.ref&&(t.ref.current=null)}});let{ref:n,...r}=t;return r}(t),a=e.isDisabled?{}:i,l=(0,f.useRef)(e.autoFocus);(0,f.useEffect)(()=>{l.current&&t.current&&function(e){let t=ey(e),n=eD(t);if("virtual"===ex){var r;r=()=>{eD(t)===n&&e.isConnected&&e_(e)},requestAnimationFrame(()=>{(function(){for(let[e]of eW)"isConnected"in e&&!e.isConnected&&eW.delete(e)})(),0===eW.size?r():eN.add(r)})}else e_(e)}(t.current),l.current=!1},[t]);let u=e.excludeFromTabOrder?-1:0;return e.isDisabled&&(u=void 0),{focusableProps:e$({...o,tabIndex:u},a)}}({isDisabled:r,onFocus:()=>{"pointer"!==B&&(l.current=!0,u())},onBlur:()=>{l.current=!1,a.current=!1,s(!0)}},n);return{triggerProps:{"aria-describedby":t.isOpen?i:void 0,...j(p,d,{onPointerDown:c,onKeyDown:c})},tooltipProps:{id:i}}}({isDisabled:w,trigger:x},K,Z),{tooltipProps:en}=function(e,t){let n=function(e,t={}){let{labelable:n,isLink:r,propNames:o}=t,i={};for(let t in e)Object.prototype.hasOwnProperty.call(e,t)&&(eB.has(t)||n&&eX.has(t)||r&&eY.has(t)||(null==o?void 0:o.has(t))||eU.test(t))&&(i[t]=e[t]);return i}(e,{labelable:!0}),{hoverProps:r}=eu({onHoverStart:()=>null==t?void 0:t.open(!0),onHoverEnd:()=>null==t?void 0:t.close()});return{tooltipProps:j(n,r,{role:"tooltip"})}}({isOpen:Q,...j(o,et)},K),{overlayProps:er,placement:eo,updatePosition:ei}=function(e){var t,n,r;let o;let{direction:i}=(o=function(){let e=T(),[t,n]=(0,f.useState)(ta);return((0,f.useEffect)(()=>(0===tl.size&&window.addEventListener("languagechange",tu),tl.add(n),()=>{tl.delete(n),0===tl.size&&window.removeEventListener("languagechange",tu)}),[]),e)?{locale:"en-US",direction:"ltr"}:t}(),(0,f.useContext)(ts)||o),{arrowSize:a=0,targetRef:l,overlayRef:u,scrollRef:s=u,placement:c="bottom",containerPadding:d=12,shouldFlip:p=!0,boundaryElement:m="undefined"!=typeof document?document.body:null,offset:h=0,crossOffset:v=0,shouldUpdatePosition:g=!0,isOpen:y=!0,onClose:w,maxHeight:x,arrowBoundaryOffset:E=0}=e,[C,S]=(0,f.useState)(null),M=[g,c,u.current,l.current,s.current,d,p,m,h,v,y,i,x,E,a],k=(0,f.useRef)(null==tc?void 0:tc.scale);(0,f.useEffect)(()=>{y&&(k.current=null==tc?void 0:tc.scale)},[y]);let P=(0,f.useCallback)(()=>{var e,t,n,r,o;if(!1===g||!y||!u.current||!l.current||!m||(null==tc?void 0:tc.scale)!==k.current)return;let f=null;if(s.current&&s.current.contains(document.activeElement)){let r=null===(e=document.activeElement)||void 0===e?void 0:e.getBoundingClientRect(),o=s.current.getBoundingClientRect();(f={type:"top",offset:(null!==(t=null==r?void 0:r.top)&&void 0!==t?t:0)-o.top}).offset>o.height/2&&(f.type="bottom",f.offset=(null!==(n=null==r?void 0:r.bottom)&&void 0!==n?n:0)-o.bottom)}let b=u.current;!x&&u.current&&(b.style.top="0px",b.style.bottom="",b.style.maxHeight=(null!==(o=null===(r=window.visualViewport)||void 0===r?void 0:r.height)&&void 0!==o?o:window.innerHeight)+"px");let w=function(e){var t,n,r,o;let i;let{placement:a,targetNode:l,overlayNode:u,scrollNode:s,padding:c,shouldFlip:d,boundaryElement:f,offset:p,crossOffset:m,maxHeight:h,arrowSize:v=0,arrowBoundaryOffset:g=0}=e,b=u instanceof HTMLElement?function(e){let t=e.offsetParent;if(t&&t===document.body&&"static"===window.getComputedStyle(t).position&&!e8(t)&&(t=document.documentElement),null==t)for(t=e.parentElement;t&&!e8(t);)t=t.parentElement;return t||document.documentElement}(u):document.documentElement,y=b===document.documentElement,w=window.getComputedStyle(b).position,x=y?e7(l):e6(l,b);if(!y){let{marginTop:e,marginLeft:t}=window.getComputedStyle(l);x.top+=parseInt(e,10)||0,x.left+=parseInt(t,10)||0}let E=e7(u),C={top:parseInt((i=window.getComputedStyle(u)).marginTop,10)||0,bottom:parseInt(i.marginBottom,10)||0,left:parseInt(i.marginLeft,10)||0,right:parseInt(i.marginRight,10)||0};E.width+=(null!==(t=C.left)&&void 0!==t?t:0)+(null!==(n=C.right)&&void 0!==n?n:0),E.height+=(null!==(r=C.top)&&void 0!==r?r:0)+(null!==(o=C.bottom)&&void 0!==o?o:0);let S={top:s.scrollTop,left:s.scrollLeft,width:s.scrollWidth,height:s.scrollHeight},M=e2(f),k=e2(b),T="BODY"===f.tagName?e7(b):e6(b,f);return"HTML"===b.tagName&&"BODY"===f.tagName&&(k.scroll.top=0,k.scroll.left=0),function(e,t,n,r,o,i,a,l,u,s,c,d,f,p,m,h){var v,g,b,y;let w=e9(e),{size:x,crossAxis:E,crossSize:C,placement:S,crossPlacement:M}=w,k=e4(t,l,n,w,c,d,s,f,m,h),T=c,P=e3(l,s,t,o,i+c,w);if(a&&r[x]>P){let e=e9(`${eZ[S]} ${M}`),r=e4(t,l,n,e,c,d,s,f,m,h);e3(l,s,t,o,i+c,e)>P&&(w=e,k=r,T=c)}let R="bottom";"top"===w.axis?"top"===w.placement?R="top":"bottom"===w.placement&&(R="bottom"):"top"===w.crossAxis&&("top"===w.crossPlacement?R="bottom":"bottom"===w.crossPlacement&&(R="top"));let L=e5(E,k[E],n[C],l,u,i,s);k[E]+=L;let j=function(e,t,n,r,o,i,a,l){var u,s,c,d,f,p,m;let h=r?n.height:t[eQ.height],v=null!=e.top?n.top+e.top:n.top+(h-(null!==(u=e.bottom)&&void 0!==u?u:0)-a),g="top"!==l?Math.max(0,t.height+t.top+(null!==(s=t.scroll.top)&&void 0!==s?s:0)-v-((null!==(c=o.top)&&void 0!==c?c:0)+(null!==(d=o.bottom)&&void 0!==d?d:0)+i)):Math.max(0,v+a-(t.top+(null!==(f=t.scroll.top)&&void 0!==f?f:0))-((null!==(p=o.top)&&void 0!==p?p:0)+(null!==(m=o.bottom)&&void 0!==m?m:0)+i));return Math.min(t.height-2*i,g)}(k,l,s,f,o,i,n.height,R);p&&p<j&&(j=p),n.height=Math.min(n.height,j),L=e5(E,(k=e4(t,l,n,w,T,d,s,f,m,h))[E],n[C],l,u,i,s),k[E]+=L;let A={},O=t[E]+.5*t[C]-k[E]-o[eK[E]],D=m/2+h,W="left"===eK[E]?(null!==(v=o.left)&&void 0!==v?v:0)+(null!==(g=o.right)&&void 0!==g?g:0):(null!==(b=o.top)&&void 0!==b?b:0)+(null!==(y=o.bottom)&&void 0!==y?y:0),N=n[C]-W-m/2-h,I=eq(O,t[E]+m/2-(k[E]+o[eK[E]]),t[E]+t[C]-m/2-(k[E]+o[eK[E]]));return A[E]=eq(I,D,N),{position:k,maxHeight:j,arrowOffsetLeft:A.left,arrowOffsetTop:A.top,placement:w.placement}}(a,x,E,S,C,c,d,M,k,T,p,m,!!w&&"static"!==w,h,v,g)}({placement:"rtl"===i?c.replace("start","right").replace("end","left"):c.replace("start","left").replace("end","right"),overlayNode:u.current,targetNode:l.current,scrollNode:s.current||u.current,padding:d,shouldFlip:p,boundaryElement:m,offset:h,crossOffset:v,maxHeight:x,arrowSize:a,arrowBoundaryOffset:E});if(w.position){if(b.style.top="",b.style.bottom="",b.style.left="",b.style.right="",Object.keys(w.position).forEach(e=>b.style[e]=w.position[e]+"px"),b.style.maxHeight=null!=w.maxHeight?w.maxHeight+"px":"",f&&document.activeElement&&s.current){let e=document.activeElement.getBoundingClientRect(),t=s.current.getBoundingClientRect(),n=e[f.type]-t[f.type];s.current.scrollTop+=n-f.offset}S(w)}},M);b(P,M),b(()=>(window.addEventListener("resize",r,!1),()=>{window.removeEventListener("resize",r,!1)}),[r=P]),tt({ref:u,onResize:P}),tt({ref:l,onResize:P});let R=(0,f.useRef)(!1);b(()=>{let e;let t=()=>{R.current=!0,clearTimeout(e),e=setTimeout(()=>{R.current=!1},500),P()},n=()=>{R.current&&t()};return null==tc||tc.addEventListener("resize",t),null==tc||tc.addEventListener("scroll",n),()=>{null==tc||tc.removeEventListener("resize",t),null==tc||tc.removeEventListener("scroll",n)}},[P]);let L=(0,f.useCallback)(()=>{R.current||null==w||w()},[w,R]);return function(e){let{triggerRef:t,isOpen:n,onClose:r}=e;(0,f.useEffect)(()=>{if(!n||null===r)return;let e=e=>{let n=e.target;if(!t.current||n instanceof Node&&!n.contains(t.current)||e.target instanceof HTMLInputElement||e.target instanceof HTMLTextAreaElement)return;let o=r||te.get(t.current);o&&o()};return window.addEventListener("scroll",e,!0),()=>{window.removeEventListener("scroll",e,!0)}},[n,r,t])}({triggerRef:l,isOpen:y,onClose:w&&L}),{overlayProps:{style:{position:"absolute",zIndex:1e5,...null==C?void 0:C.position,maxHeight:null!==(t=null==C?void 0:C.maxHeight)&&void 0!==t?t:"100vh"}},placement:null!==(n=null==C?void 0:C.placement)&&void 0!==n?n:null,arrowProps:{"aria-hidden":"true",role:"presentation",style:{left:null==C?void 0:C.arrowOffsetLeft,top:null==C?void 0:C.arrowOffsetTop}},updatePosition:P}}({isOpen:Q,targetRef:Z,placement:nx(M),overlayRef:G,offset:A?O+3:O,crossOffset:D,shouldFlip:E,containerPadding:S});nC(()=>{z.length&&ei()},z);let{overlayProps:ea}=function(e,t){let{onClose:n,shouldCloseOnBlur:r,isOpen:o,isDismissable:i=!1,isKeyboardDismissDisabled:a=!1,shouldCloseOnInteractOutside:l}=e;(0,f.useEffect)(()=>(o&&tb.push(t),()=>{let e=tb.indexOf(t);e>=0&&tb.splice(e,1)}),[o,t]);let u=()=>{tb[tb.length-1]===t&&n&&n()};!function(e){let{ref:t,onInteractOutside:n,isDisabled:r,onInteractOutsideStart:o}=e,i=(0,f.useRef)({isPointerDown:!1,ignoreEmulatedMouseEvents:!1}),a=th(e=>{n&&tv(e,t)&&(o&&o(e),i.current.isPointerDown=!0)}),l=th(e=>{n&&n(e)});(0,f.useEffect)(()=>{let e=i.current;if(r)return;let n=$(t.current);if("undefined"!=typeof PointerEvent){let r=n=>{e.isPointerDown&&tv(n,t)&&l(n),e.isPointerDown=!1};return n.addEventListener("pointerdown",a,!0),n.addEventListener("pointerup",r,!0),()=>{n.removeEventListener("pointerdown",a,!0),n.removeEventListener("pointerup",r,!0)}}{let r=n=>{e.ignoreEmulatedMouseEvents?e.ignoreEmulatedMouseEvents=!1:e.isPointerDown&&tv(n,t)&&l(n),e.isPointerDown=!1},o=n=>{e.ignoreEmulatedMouseEvents=!0,e.isPointerDown&&tv(n,t)&&l(n),e.isPointerDown=!1};return n.addEventListener("mousedown",a,!0),n.addEventListener("mouseup",r,!0),n.addEventListener("touchstart",a,!0),n.addEventListener("touchend",o,!0),()=>{n.removeEventListener("mousedown",a,!0),n.removeEventListener("mouseup",r,!0),n.removeEventListener("touchstart",a,!0),n.removeEventListener("touchend",o,!0)}}},[t,r,a,l])}({ref:t,onInteractOutside:i&&o?e=>{(!l||l(e.target))&&(tb[tb.length-1]===t&&(e.stopPropagation(),e.preventDefault()),u())}:void 0,onInteractOutsideStart:e=>{(!l||l(e.target))&&tb[tb.length-1]===t&&(e.stopPropagation(),e.preventDefault())}});let{focusWithinProps:s}=function(e){let t,n,{isDisabled:r,onBlurWithin:o,onFocusWithin:i,onFocusWithinChange:a}=e,l=(0,f.useRef)({isFocusWithin:!1}),u=(0,f.useCallback)(e=>{l.current.isFocusWithin&&!e.currentTarget.contains(e.relatedTarget)&&(l.current.isFocusWithin=!1,o&&o(e),a&&a(!1))},[o,a,l]),s=(t=(0,f.useRef)({isFocused:!1,observer:null}),b(()=>{let e=t.current;return()=>{e.observer&&(e.observer.disconnect(),e.observer=null)}},[]),n=th(e=>{null==u||u(e)}),(0,f.useCallback)(e=>{if(e.target instanceof HTMLButtonElement||e.target instanceof HTMLInputElement||e.target instanceof HTMLTextAreaElement||e.target instanceof HTMLSelectElement){t.current.isFocused=!0;let r=e.target;r.addEventListener("focusout",e=>{t.current.isFocused=!1,r.disabled&&n(new tg("blur",e)),t.current.observer&&(t.current.observer.disconnect(),t.current.observer=null)},{once:!0}),t.current.observer=new MutationObserver(()=>{if(t.current.isFocused&&r.disabled){var e;null===(e=t.current.observer)||void 0===e||e.disconnect();let n=r===document.activeElement?null:document.activeElement;r.dispatchEvent(new FocusEvent("blur",{relatedTarget:n})),r.dispatchEvent(new FocusEvent("focusout",{bubbles:!0,relatedTarget:n}))}}),t.current.observer.observe(r,{attributes:!0,attributeFilter:["disabled"]})}},[n])),c=(0,f.useCallback)(e=>{l.current.isFocusWithin||document.activeElement!==e.target||(i&&i(e),a&&a(!0),l.current.isFocusWithin=!0,s(e))},[i,a,s]);return r?{focusWithinProps:{onFocus:void 0,onBlur:void 0}}:{focusWithinProps:{onFocus:c,onBlur:u}}}({isDisabled:!r,onBlurWithin:e=>{!(!e.relatedTarget||function(e,t=null){if(e instanceof Element&&e.closest("[data-react-aria-top-layer]"))return!0;for(let{scopeRef:n}of tm.traverse(tm.getTreeNode(t)))if(n&&td(e,n.current))return!0;return!1}(e.relatedTarget,null))&&(!l||l(e.relatedTarget))&&(null==n||n())}});return{overlayProps:{onKeyDown:e=>{"Escape"!==e.key||a||e.nativeEvent.isComposing||(e.stopPropagation(),e.preventDefault(),u())},...s},underlayProps:{onPointerDown:e=>{e.target===e.currentTarget&&e.preventDefault()}}}}({isOpen:Q,onClose:K.close,isDismissable:W,shouldCloseOnBlur:N,isKeyboardDismissDisabled:_,shouldCloseOnInteractOutside:F},G),el=(0,f.useMemo)(()=>{var t,n,r;return nc({...i,disableAnimation:q,radius:null!=(t=null==e?void 0:e.radius)?t:"md",size:null!=(n=null==e?void 0:e.size)?n:"md",shadow:null!=(r=null==e?void 0:e.shadow)?r:"sm"})},[function(e){if(!e||"object"!=typeof e)return"";try{return JSON.stringify(e)}catch(e){return""}}(i),q,null==e?void 0:e.radius,null==e?void 0:e.size,null==e?void 0:e.shadow]),ec=(0,f.useCallback)((e={},t=null)=>({...j(ee,e),ref:function(...e){return t=>{e.forEach(e=>(function(e,t){if(null!=e){if("function"==typeof e){e(t);return}try{e.current=t}catch(n){throw Error(`Cannot assign value '${t}' to ref '${e}'`)}}})(e,t))}}(t,Z),"aria-describedby":Q?J:void 0}),[ee,Q,J,K]),ed=(0,f.useCallback)(()=>({ref:G,"data-slot":"base","data-open":ny(Q),"data-arrow":ny(A),"data-disabled":ny(w),"data-placement":nE(eo||"top",M),...j(en,ea,U),style:j(er.style,U.style,o.style),className:el.base({class:null==Y?void 0:Y.base}),id:J}),[el,Q,A,w,eo,M,en,ea,U,er,o,J]),ef=(0,f.useCallback)(()=>({"data-slot":"content","data-open":ny(Q),"data-arrow":ny(A),"data-disabled":ny(w),"data-placement":nE(eo||"top",M),className:el.content({class:function(...e){for(var t,n,r=0,o="";r<e.length;)(t=e[r++])&&(n=function e(t){var n,r,o="";if("string"==typeof t||"number"==typeof t)o+=t;else if("object"==typeof t){if(Array.isArray(t))for(n=0;n<t.length;n++)t[n]&&(r=e(t[n]))&&(o&&(o+=" "),o+=r);else for(n in t)t[n]&&(o&&(o+=" "),o+=n)}return o}(t))&&(o&&(o+=" "),o+=n);return o}(null==Y?void 0:Y.content,H)})}),[el,Q,A,w,eo,M,Y]);return{Component:l||"div",content:s,children:c,isOpen:Q,triggerRef:Z,showArrow:A,portalContainer:I,placement:M,disableAnimation:q,isDisabled:w,motionProps:X,getTooltipContentProps:ef,getTriggerProps:ec,getTooltipProps:ed}}({...e,ref:t});try{let e=f.Children.count(o);if(1!==e)throw Error();n=(0,f.isValidElement)(o)?(0,f.cloneElement)(o,d(o.props,o.ref)):(0,nL.jsx)("p",{...d(),children:o})}catch(e){n=(0,nL.jsx)("span",{}),function(e,t,...n){let r=`[Next UI] : ${e}`;"undefined"!=typeof console&&(rh[r]||(rh[r]=!0))}("Tooltip must have only one child node. Please, check your code.")}let{ref:x,id:E,style:S,...M}=y(),k=(0,nL.jsx)("div",{ref:x,id:E,style:S,children:(0,nL.jsx)(nD,{features:rv,children:(0,nL.jsx)(ri.div,{animate:"enter",exit:"exit",initial:"exit",variants:rm,...j(c,M),style:{...nw(u)},children:(0,nL.jsx)(r,{...w(),children:i})})})});return(0,nL.jsxs)(nL.Fragment,{children:[n,s&&a?(0,nL.jsx)(nR,{portalContainer:l,children:(0,nL.jsx)("div",{ref:x,id:E,style:S,...M,children:(0,nL.jsx)(r,{...w(),children:i})})}):(0,nL.jsx)(rp,{children:a?(0,nL.jsx)(nR,{portalContainer:l,children:k}):null})]})},(0,f.forwardRef)(d));rg.displayName="NextUI.Tooltip";var rb=rg},36206:function(e,t,n){n.d(t,{M:function(){return r}});function r(e,t,{checkForDefaultPrevented:n=!0}={}){return function(r){if(e?.(r),!1===n||!r.defaultPrevented)return t?.(r)}}},25360:function(e,t,n){n.d(t,{b:function(){return a},k:function(){return i}});var r=n(67294),o=n(85893);function i(e,t){let n=r.createContext(t),i=e=>{let{children:t,...i}=e,a=r.useMemo(()=>i,Object.values(i));return(0,o.jsx)(n.Provider,{value:a,children:t})};return i.displayName=e+"Provider",[i,function(o){let i=r.useContext(n);if(i)return i;if(void 0!==t)return t;throw Error(`\`${o}\` must be used within \`${e}\``)}]}function a(e,t=[]){let n=[],i=()=>{let t=n.map(e=>r.createContext(e));return function(n){let o=n?.[e]||t;return r.useMemo(()=>({[`__scope${e}`]:{...n,[e]:o}}),[n,o])}};return i.scopeName=e,[function(t,i){let a=r.createContext(i),l=n.length;n=[...n,i];let u=t=>{let{scope:n,children:i,...u}=t,s=n?.[e]?.[l]||a,c=r.useMemo(()=>u,Object.values(u));return(0,o.jsx)(s.Provider,{value:c,children:i})};return u.displayName=t+"Provider",[u,function(n,o){let u=o?.[e]?.[l]||a,s=r.useContext(u);if(s)return s;if(void 0!==i)return i;throw Error(`\`${n}\` must be used within \`${t}\``)}]},function(...e){let t=e[0];if(1===e.length)return t;let n=()=>{let n=e.map(e=>({useScope:e(),scopeName:e.scopeName}));return function(e){let o=n.reduce((t,{useScope:n,scopeName:r})=>{let o=n(e)[`__scope${r}`];return{...t,...o}},{});return r.useMemo(()=>({[`__scope${t.scopeName}`]:o}),[o])}};return n.scopeName=t.scopeName,n}(i,...t)]}},46063:function(e,t,n){n.d(t,{XB:function(){return f}});var r,o=n(67294),i=n(36206),a=n(75320),l=n(28771),u=n(79698),s=n(85893),c="dismissableLayer.update",d=o.createContext({layers:new Set,layersWithOutsidePointerEventsDisabled:new Set,branches:new Set}),f=o.forwardRef((e,t)=>{let{disableOutsidePointerEvents:n=!1,onEscapeKeyDown:f,onPointerDownOutside:h,onFocusOutside:v,onInteractOutside:g,onDismiss:b,...y}=e,w=o.useContext(d),[x,E]=o.useState(null),C=x?.ownerDocument??globalThis?.document,[,S]=o.useState({}),M=(0,l.e)(t,e=>E(e)),k=Array.from(w.layers),[T]=[...w.layersWithOutsidePointerEventsDisabled].slice(-1),P=k.indexOf(T),R=x?k.indexOf(x):-1,L=w.layersWithOutsidePointerEventsDisabled.size>0,j=R>=P,A=function(e,t=globalThis?.document){let n=(0,u.W)(e),r=o.useRef(!1),i=o.useRef(()=>{});return o.useEffect(()=>{let e=e=>{if(e.target&&!r.current){let r=function(){m("dismissableLayer.pointerDownOutside",n,o,{discrete:!0})},o={originalEvent:e};"touch"===e.pointerType?(t.removeEventListener("click",i.current),i.current=r,t.addEventListener("click",i.current,{once:!0})):r()}else t.removeEventListener("click",i.current);r.current=!1},o=window.setTimeout(()=>{t.addEventListener("pointerdown",e)},0);return()=>{window.clearTimeout(o),t.removeEventListener("pointerdown",e),t.removeEventListener("click",i.current)}},[t,n]),{onPointerDownCapture:()=>r.current=!0}}(e=>{let t=e.target,n=[...w.branches].some(e=>e.contains(t));!j||n||(h?.(e),g?.(e),e.defaultPrevented||b?.())},C),O=function(e,t=globalThis?.document){let n=(0,u.W)(e),r=o.useRef(!1);return o.useEffect(()=>{let e=e=>{e.target&&!r.current&&m("dismissableLayer.focusOutside",n,{originalEvent:e},{discrete:!1})};return t.addEventListener("focusin",e),()=>t.removeEventListener("focusin",e)},[t,n]),{onFocusCapture:()=>r.current=!0,onBlurCapture:()=>r.current=!1}}(e=>{let t=e.target;[...w.branches].some(e=>e.contains(t))||(v?.(e),g?.(e),e.defaultPrevented||b?.())},C);return!function(e,t=globalThis?.document){let n=(0,u.W)(e);o.useEffect(()=>{let e=e=>{"Escape"===e.key&&n(e)};return t.addEventListener("keydown",e,{capture:!0}),()=>t.removeEventListener("keydown",e,{capture:!0})},[n,t])}(e=>{R!==w.layers.size-1||(f?.(e),!e.defaultPrevented&&b&&(e.preventDefault(),b()))},C),o.useEffect(()=>{if(x)return n&&(0===w.layersWithOutsidePointerEventsDisabled.size&&(r=C.body.style.pointerEvents,C.body.style.pointerEvents="none"),w.layersWithOutsidePointerEventsDisabled.add(x)),w.layers.add(x),p(),()=>{n&&1===w.layersWithOutsidePointerEventsDisabled.size&&(C.body.style.pointerEvents=r)}},[x,C,n,w]),o.useEffect(()=>()=>{x&&(w.layers.delete(x),w.layersWithOutsidePointerEventsDisabled.delete(x),p())},[x,w]),o.useEffect(()=>{let e=()=>S({});return document.addEventListener(c,e),()=>document.removeEventListener(c,e)},[]),(0,s.jsx)(a.WV.div,{...y,ref:M,style:{pointerEvents:L?j?"auto":"none":void 0,...e.style},onFocusCapture:(0,i.M)(e.onFocusCapture,O.onFocusCapture),onBlurCapture:(0,i.M)(e.onBlurCapture,O.onBlurCapture),onPointerDownCapture:(0,i.M)(e.onPointerDownCapture,A.onPointerDownCapture)})});function p(){let e=new CustomEvent(c);document.dispatchEvent(e)}function m(e,t,n,{discrete:r}){let o=n.originalEvent.target,i=new CustomEvent(e,{bubbles:!1,cancelable:!0,detail:n});t&&o.addEventListener(e,t,{once:!0}),r?(0,a.jH)(o,i):o.dispatchEvent(i)}f.displayName="DismissableLayer",o.forwardRef((e,t)=>{let n=o.useContext(d),r=o.useRef(null),i=(0,l.e)(t,r);return o.useEffect(()=>{let e=r.current;if(e)return n.branches.add(e),()=>{n.branches.delete(e)}},[n.branches]),(0,s.jsx)(a.WV.div,{...e,ref:i})}).displayName="DismissableLayerBranch"},27552:function(e,t,n){n.d(t,{EW:function(){return i}});var r=n(67294),o=0;function i(){r.useEffect(()=>{let e=document.querySelectorAll("[data-radix-focus-guard]");return document.body.insertAdjacentElement("afterbegin",e[0]??a()),document.body.insertAdjacentElement("beforeend",e[1]??a()),o++,()=>{1===o&&document.querySelectorAll("[data-radix-focus-guard]").forEach(e=>e.remove()),o--}},[])}function a(){let e=document.createElement("span");return e.setAttribute("data-radix-focus-guard",""),e.tabIndex=0,e.style.outline="none",e.style.opacity="0",e.style.position="fixed",e.style.pointerEvents="none",e}},95420:function(e,t,n){let r;n.d(t,{M:function(){return f}});var o=n(67294),i=n(28771),a=n(75320),l=n(79698),u=n(85893),s="focusScope.autoFocusOnMount",c="focusScope.autoFocusOnUnmount",d={bubbles:!1,cancelable:!0},f=o.forwardRef((e,t)=>{let{loop:n=!1,trapped:r=!1,onMountAutoFocus:f,onUnmountAutoFocus:g,...b}=e,[y,w]=o.useState(null),x=(0,l.W)(f),E=(0,l.W)(g),C=o.useRef(null),S=(0,i.e)(t,e=>w(e)),M=o.useRef({paused:!1,pause(){this.paused=!0},resume(){this.paused=!1}}).current;o.useEffect(()=>{if(r){let e=function(e){if(M.paused||!y)return;let t=e.target;y.contains(t)?C.current=t:h(C.current,{select:!0})},t=function(e){if(M.paused||!y)return;let t=e.relatedTarget;null===t||y.contains(t)||h(C.current,{select:!0})};document.addEventListener("focusin",e),document.addEventListener("focusout",t);let n=new MutationObserver(function(e){if(document.activeElement===document.body)for(let t of e)t.removedNodes.length>0&&h(y)});return y&&n.observe(y,{childList:!0,subtree:!0}),()=>{document.removeEventListener("focusin",e),document.removeEventListener("focusout",t),n.disconnect()}}},[r,y,M.paused]),o.useEffect(()=>{if(y){v.add(M);let e=document.activeElement;if(!y.contains(e)){let t=new CustomEvent(s,d);y.addEventListener(s,x),y.dispatchEvent(t),t.defaultPrevented||(function(e,{select:t=!1}={}){let n=document.activeElement;for(let r of e)if(h(r,{select:t}),document.activeElement!==n)return}(p(y).filter(e=>"A"!==e.tagName),{select:!0}),document.activeElement===e&&h(y))}return()=>{y.removeEventListener(s,x),setTimeout(()=>{let t=new CustomEvent(c,d);y.addEventListener(c,E),y.dispatchEvent(t),t.defaultPrevented||h(e??document.body,{select:!0}),y.removeEventListener(c,E),v.remove(M)},0)}}},[y,x,E,M]);let k=o.useCallback(e=>{if(!n&&!r||M.paused)return;let t="Tab"===e.key&&!e.altKey&&!e.ctrlKey&&!e.metaKey,o=document.activeElement;if(t&&o){let t=e.currentTarget,[r,i]=function(e){let t=p(e);return[m(t,e),m(t.reverse(),e)]}(t);r&&i?e.shiftKey||o!==i?e.shiftKey&&o===r&&(e.preventDefault(),n&&h(i,{select:!0})):(e.preventDefault(),n&&h(r,{select:!0})):o===t&&e.preventDefault()}},[n,r,M.paused]);return(0,u.jsx)(a.WV.div,{tabIndex:-1,...b,ref:S,onKeyDown:k})});function p(e){let t=[],n=document.createTreeWalker(e,NodeFilter.SHOW_ELEMENT,{acceptNode:e=>{let t="INPUT"===e.tagName&&"hidden"===e.type;return e.disabled||e.hidden||t?NodeFilter.FILTER_SKIP:e.tabIndex>=0?NodeFilter.FILTER_ACCEPT:NodeFilter.FILTER_SKIP}});for(;n.nextNode();)t.push(n.currentNode);return t}function m(e,t){for(let n of e)if(!function(e,{upTo:t}){if("hidden"===getComputedStyle(e).visibility)return!0;for(;e&&(void 0===t||e!==t);){if("none"===getComputedStyle(e).display)return!0;e=e.parentElement}return!1}(n,{upTo:t}))return n}function h(e,{select:t=!1}={}){if(e&&e.focus){var n;let r=document.activeElement;e.focus({preventScroll:!0}),e!==r&&(n=e)instanceof HTMLInputElement&&"select"in n&&t&&e.select()}}f.displayName="FocusScope";var v=(r=[],{add(e){let t=r[0];e!==t&&t?.pause(),(r=g(r,e)).unshift(e)},remove(e){r=g(r,e),r[0]?.resume()}});function g(e,t){let n=[...e],r=n.indexOf(t);return -1!==r&&n.splice(r,1),n}},91276:function(e,t,n){n.d(t,{M:function(){return u}});var r,o=n(67294),i=n(9981),a=(r||(r=n.t(o,2)))[" useId ".trim().toString()]||(()=>void 0),l=0;function u(e){let[t,n]=o.useState(a());return(0,i.b)(()=>{e||n(e=>e??String(l++))},[e]),e||(t?`radix-${t}`:"")}},42651:function(e,t,n){n.d(t,{h:function(){return u}});var r=n(67294),o=n(73935),i=n(75320),a=n(9981),l=n(85893),u=r.forwardRef((e,t)=>{let{container:n,...u}=e,[s,c]=r.useState(!1);(0,a.b)(()=>c(!0),[]);let d=n||s&&globalThis?.document?.body;return d?o.createPortal((0,l.jsx)(i.WV.div,{...u,ref:t}),d):null});u.displayName="Portal"},2067:function(e,t,n){n.d(t,{VY:function(){return t4},ZA:function(){return t7},JO:function(){return t5},ck:function(){return t8},wU:function(){return nt},eT:function(){return ne},__:function(){return t6},h_:function(){return t9},fC:function(){return t0},$G:function(){return nr},u_:function(){return nn},Z0:function(){return no},xz:function(){return t1},B4:function(){return t2},l_:function(){return t3}});var r=n(67294),o=n(73935);function i(e,[t,n]){return Math.min(n,Math.max(t,e))}var a=n(36206),l=n(25360),u=n(28771),s=n(88426),c=n(85893),d=r.createContext(void 0),f=n(46063),p=n(27552),m=n(95420),h=n(91276);let v=["top","right","bottom","left"],g=Math.min,b=Math.max,y=Math.round,w=Math.floor,x=e=>({x:e,y:e}),E={left:"right",right:"left",bottom:"top",top:"bottom"},C={start:"end",end:"start"};function S(e,t){return"function"==typeof e?e(t):e}function M(e){return e.split("-")[0]}function k(e){return e.split("-")[1]}function T(e){return"x"===e?"y":"x"}function P(e){return"y"===e?"height":"width"}function R(e){return["top","bottom"].includes(M(e))?"y":"x"}function L(e){return e.replace(/start|end/g,e=>C[e])}function j(e){return e.replace(/left|right|bottom|top/g,e=>E[e])}function A(e){return"number"!=typeof e?{top:0,right:0,bottom:0,left:0,...e}:{top:e,right:e,bottom:e,left:e}}function O(e){let{x:t,y:n,width:r,height:o}=e;return{width:r,height:o,top:n,left:t,right:t+r,bottom:n+o,x:t,y:n}}function D(e,t,n){let r,{reference:o,floating:i}=e,a=R(t),l=T(R(t)),u=P(l),s=M(t),c="y"===a,d=o.x+o.width/2-i.width/2,f=o.y+o.height/2-i.height/2,p=o[u]/2-i[u]/2;switch(s){case"top":r={x:d,y:o.y-i.height};break;case"bottom":r={x:d,y:o.y+o.height};break;case"right":r={x:o.x+o.width,y:f};break;case"left":r={x:o.x-i.width,y:f};break;default:r={x:o.x,y:o.y}}switch(k(t)){case"start":r[l]-=p*(n&&c?-1:1);break;case"end":r[l]+=p*(n&&c?-1:1)}return r}let W=async(e,t,n)=>{let{placement:r="bottom",strategy:o="absolute",middleware:i=[],platform:a}=n,l=i.filter(Boolean),u=await (null==a.isRTL?void 0:a.isRTL(t)),s=await a.getElementRects({reference:e,floating:t,strategy:o}),{x:c,y:d}=D(s,r,u),f=r,p={},m=0;for(let n=0;n<l.length;n++){let{name:i,fn:h}=l[n],{x:v,y:g,data:b,reset:y}=await h({x:c,y:d,initialPlacement:r,placement:f,strategy:o,middlewareData:p,rects:s,platform:a,elements:{reference:e,floating:t}});c=null!=v?v:c,d=null!=g?g:d,p={...p,[i]:{...p[i],...b}},y&&m<=50&&(m++,"object"==typeof y&&(y.placement&&(f=y.placement),y.rects&&(s=!0===y.rects?await a.getElementRects({reference:e,floating:t,strategy:o}):y.rects),{x:c,y:d}=D(s,f,u)),n=-1)}return{x:c,y:d,placement:f,strategy:o,middlewareData:p}};async function N(e,t){var n;void 0===t&&(t={});let{x:r,y:o,platform:i,rects:a,elements:l,strategy:u}=e,{boundary:s="clippingAncestors",rootBoundary:c="viewport",elementContext:d="floating",altBoundary:f=!1,padding:p=0}=S(t,e),m=A(p),h=l[f?"floating"===d?"reference":"floating":d],v=O(await i.getClippingRect({element:null==(n=await (null==i.isElement?void 0:i.isElement(h)))||n?h:h.contextElement||await (null==i.getDocumentElement?void 0:i.getDocumentElement(l.floating)),boundary:s,rootBoundary:c,strategy:u})),g="floating"===d?{x:r,y:o,width:a.floating.width,height:a.floating.height}:a.reference,b=await (null==i.getOffsetParent?void 0:i.getOffsetParent(l.floating)),y=await (null==i.isElement?void 0:i.isElement(b))&&await (null==i.getScale?void 0:i.getScale(b))||{x:1,y:1},w=O(i.convertOffsetParentRelativeRectToViewportRelativeRect?await i.convertOffsetParentRelativeRectToViewportRelativeRect({elements:l,rect:g,offsetParent:b,strategy:u}):g);return{top:(v.top-w.top+m.top)/y.y,bottom:(w.bottom-v.bottom+m.bottom)/y.y,left:(v.left-w.left+m.left)/y.x,right:(w.right-v.right+m.right)/y.x}}function I(e,t){return{top:e.top-t.height,right:e.right-t.width,bottom:e.bottom-t.height,left:e.left-t.width}}function _(e){return v.some(t=>e[t]>=0)}async function z(e,t){let{placement:n,platform:r,elements:o}=e,i=await (null==r.isRTL?void 0:r.isRTL(o.floating)),a=M(n),l=k(n),u="y"===R(n),s=["left","top"].includes(a)?-1:1,c=i&&u?-1:1,d=S(t,e),{mainAxis:f,crossAxis:p,alignmentAxis:m}="number"==typeof d?{mainAxis:d,crossAxis:0,alignmentAxis:null}:{mainAxis:d.mainAxis||0,crossAxis:d.crossAxis||0,alignmentAxis:d.alignmentAxis};return l&&"number"==typeof m&&(p="end"===l?-1*m:m),u?{x:p*c,y:f*s}:{x:f*s,y:p*c}}function F(){return"undefined"!=typeof window}function H(e){return B(e)?(e.nodeName||"").toLowerCase():"#document"}function $(e){var t;return(null==e||null==(t=e.ownerDocument)?void 0:t.defaultView)||window}function V(e){var t;return null==(t=(B(e)?e.ownerDocument:e.document)||window.document)?void 0:t.documentElement}function B(e){return!!F()&&(e instanceof Node||e instanceof $(e).Node)}function X(e){return!!F()&&(e instanceof Element||e instanceof $(e).Element)}function Y(e){return!!F()&&(e instanceof HTMLElement||e instanceof $(e).HTMLElement)}function U(e){return!!F()&&"undefined"!=typeof ShadowRoot&&(e instanceof ShadowRoot||e instanceof $(e).ShadowRoot)}function q(e){let{overflow:t,overflowX:n,overflowY:r,display:o}=Q(e);return/auto|scroll|overlay|hidden|clip/.test(t+r+n)&&!["inline","contents"].includes(o)}function K(e){return[":popover-open",":modal"].some(t=>{try{return e.matches(t)}catch(e){return!1}})}function Z(e){let t=G(),n=X(e)?Q(e):e;return["transform","translate","scale","rotate","perspective"].some(e=>!!n[e]&&"none"!==n[e])||!!n.containerType&&"normal"!==n.containerType||!t&&!!n.backdropFilter&&"none"!==n.backdropFilter||!t&&!!n.filter&&"none"!==n.filter||["transform","translate","scale","rotate","perspective","filter"].some(e=>(n.willChange||"").includes(e))||["paint","layout","strict","content"].some(e=>(n.contain||"").includes(e))}function G(){return"undefined"!=typeof CSS&&!!CSS.supports&&CSS.supports("-webkit-backdrop-filter","none")}function J(e){return["html","body","#document"].includes(H(e))}function Q(e){return $(e).getComputedStyle(e)}function ee(e){return X(e)?{scrollLeft:e.scrollLeft,scrollTop:e.scrollTop}:{scrollLeft:e.scrollX,scrollTop:e.scrollY}}function et(e){if("html"===H(e))return e;let t=e.assignedSlot||e.parentNode||U(e)&&e.host||V(e);return U(t)?t.host:t}function en(e,t,n){var r;void 0===t&&(t=[]),void 0===n&&(n=!0);let o=function e(t){let n=et(t);return J(n)?t.ownerDocument?t.ownerDocument.body:t.body:Y(n)&&q(n)?n:e(n)}(e),i=o===(null==(r=e.ownerDocument)?void 0:r.body),a=$(o);if(i){let e=er(a);return t.concat(a,a.visualViewport||[],q(o)?o:[],e&&n?en(e):[])}return t.concat(o,en(o,[],n))}function er(e){return e.parent&&Object.getPrototypeOf(e.parent)?e.frameElement:null}function eo(e){let t=Q(e),n=parseFloat(t.width)||0,r=parseFloat(t.height)||0,o=Y(e),i=o?e.offsetWidth:n,a=o?e.offsetHeight:r,l=y(n)!==i||y(r)!==a;return l&&(n=i,r=a),{width:n,height:r,$:l}}function ei(e){return X(e)?e:e.contextElement}function ea(e){let t=ei(e);if(!Y(t))return x(1);let n=t.getBoundingClientRect(),{width:r,height:o,$:i}=eo(t),a=(i?y(n.width):n.width)/r,l=(i?y(n.height):n.height)/o;return a&&Number.isFinite(a)||(a=1),l&&Number.isFinite(l)||(l=1),{x:a,y:l}}let el=x(0);function eu(e){let t=$(e);return G()&&t.visualViewport?{x:t.visualViewport.offsetLeft,y:t.visualViewport.offsetTop}:el}function es(e,t,n,r){var o;void 0===t&&(t=!1),void 0===n&&(n=!1);let i=e.getBoundingClientRect(),a=ei(e),l=x(1);t&&(r?X(r)&&(l=ea(r)):l=ea(e));let u=(void 0===(o=n)&&(o=!1),r&&(!o||r===$(a))&&o)?eu(a):x(0),s=(i.left+u.x)/l.x,c=(i.top+u.y)/l.y,d=i.width/l.x,f=i.height/l.y;if(a){let e=$(a),t=r&&X(r)?$(r):r,n=e,o=er(n);for(;o&&r&&t!==n;){let e=ea(o),t=o.getBoundingClientRect(),r=Q(o),i=t.left+(o.clientLeft+parseFloat(r.paddingLeft))*e.x,a=t.top+(o.clientTop+parseFloat(r.paddingTop))*e.y;s*=e.x,c*=e.y,d*=e.x,f*=e.y,s+=i,c+=a,o=er(n=$(o))}}return O({width:d,height:f,x:s,y:c})}function ec(e,t){let n=ee(e).scrollLeft;return t?t.left+n:es(V(e)).left+n}function ed(e,t,n){void 0===n&&(n=!1);let r=e.getBoundingClientRect();return{x:r.left+t.scrollLeft-(n?0:ec(e,r)),y:r.top+t.scrollTop}}function ef(e,t,n){let r;if("viewport"===t)r=function(e,t){let n=$(e),r=V(e),o=n.visualViewport,i=r.clientWidth,a=r.clientHeight,l=0,u=0;if(o){i=o.width,a=o.height;let e=G();(!e||e&&"fixed"===t)&&(l=o.offsetLeft,u=o.offsetTop)}return{width:i,height:a,x:l,y:u}}(e,n);else if("document"===t)r=function(e){let t=V(e),n=ee(e),r=e.ownerDocument.body,o=b(t.scrollWidth,t.clientWidth,r.scrollWidth,r.clientWidth),i=b(t.scrollHeight,t.clientHeight,r.scrollHeight,r.clientHeight),a=-n.scrollLeft+ec(e),l=-n.scrollTop;return"rtl"===Q(r).direction&&(a+=b(t.clientWidth,r.clientWidth)-o),{width:o,height:i,x:a,y:l}}(V(e));else if(X(t))r=function(e,t){let n=es(e,!0,"fixed"===t),r=n.top+e.clientTop,o=n.left+e.clientLeft,i=Y(e)?ea(e):x(1),a=e.clientWidth*i.x;return{width:a,height:e.clientHeight*i.y,x:o*i.x,y:r*i.y}}(t,n);else{let n=eu(e);r={x:t.x-n.x,y:t.y-n.y,width:t.width,height:t.height}}return O(r)}function ep(e){return"static"===Q(e).position}function em(e,t){if(!Y(e)||"fixed"===Q(e).position)return null;if(t)return t(e);let n=e.offsetParent;return V(e)===n&&(n=n.ownerDocument.body),n}function eh(e,t){let n=$(e);if(K(e))return n;if(!Y(e)){let t=et(e);for(;t&&!J(t);){if(X(t)&&!ep(t))return t;t=et(t)}return n}let r=em(e,t);for(;r&&["table","td","th"].includes(H(r))&&ep(r);)r=em(r,t);return r&&J(r)&&ep(r)&&!Z(r)?n:r||function(e){let t=et(e);for(;Y(t)&&!J(t);){if(Z(t))return t;if(K(t))break;t=et(t)}return null}(e)||n}let ev=async function(e){let t=this.getOffsetParent||eh,n=this.getDimensions,r=await n(e.floating);return{reference:function(e,t,n){let r=Y(t),o=V(t),i="fixed"===n,a=es(e,!0,i,t),l={scrollLeft:0,scrollTop:0},u=x(0);if(r||!r&&!i){if(("body"!==H(t)||q(o))&&(l=ee(t)),r){let e=es(t,!0,i,t);u.x=e.x+t.clientLeft,u.y=e.y+t.clientTop}else o&&(u.x=ec(o))}i&&!r&&o&&(u.x=ec(o));let s=!o||r||i?x(0):ed(o,l);return{x:a.left+l.scrollLeft-u.x-s.x,y:a.top+l.scrollTop-u.y-s.y,width:a.width,height:a.height}}(e.reference,await t(e.floating),e.strategy),floating:{x:0,y:0,width:r.width,height:r.height}}},eg={convertOffsetParentRelativeRectToViewportRelativeRect:function(e){let{elements:t,rect:n,offsetParent:r,strategy:o}=e,i="fixed"===o,a=V(r),l=!!t&&K(t.floating);if(r===a||l&&i)return n;let u={scrollLeft:0,scrollTop:0},s=x(1),c=x(0),d=Y(r);if((d||!d&&!i)&&(("body"!==H(r)||q(a))&&(u=ee(r)),Y(r))){let e=es(r);s=ea(r),c.x=e.x+r.clientLeft,c.y=e.y+r.clientTop}let f=!a||d||i?x(0):ed(a,u,!0);return{width:n.width*s.x,height:n.height*s.y,x:n.x*s.x-u.scrollLeft*s.x+c.x+f.x,y:n.y*s.y-u.scrollTop*s.y+c.y+f.y}},getDocumentElement:V,getClippingRect:function(e){let{element:t,boundary:n,rootBoundary:r,strategy:o}=e,i=[..."clippingAncestors"===n?K(t)?[]:function(e,t){let n=t.get(e);if(n)return n;let r=en(e,[],!1).filter(e=>X(e)&&"body"!==H(e)),o=null,i="fixed"===Q(e).position,a=i?et(e):e;for(;X(a)&&!J(a);){let t=Q(a),n=Z(a);n||"fixed"!==t.position||(o=null),(i?!n&&!o:!n&&"static"===t.position&&!!o&&["absolute","fixed"].includes(o.position)||q(a)&&!n&&function e(t,n){let r=et(t);return!(r===n||!X(r)||J(r))&&("fixed"===Q(r).position||e(r,n))}(e,a))?r=r.filter(e=>e!==a):o=t,a=et(a)}return t.set(e,r),r}(t,this._c):[].concat(n),r],a=i[0],l=i.reduce((e,n)=>{let r=ef(t,n,o);return e.top=b(r.top,e.top),e.right=g(r.right,e.right),e.bottom=g(r.bottom,e.bottom),e.left=b(r.left,e.left),e},ef(t,a,o));return{width:l.right-l.left,height:l.bottom-l.top,x:l.left,y:l.top}},getOffsetParent:eh,getElementRects:ev,getClientRects:function(e){return Array.from(e.getClientRects())},getDimensions:function(e){let{width:t,height:n}=eo(e);return{width:t,height:n}},getScale:ea,isElement:X,isRTL:function(e){return"rtl"===Q(e).direction}};function eb(e,t){return e.x===t.x&&e.y===t.y&&e.width===t.width&&e.height===t.height}let ey=e=>({name:"arrow",options:e,async fn(t){let{x:n,y:r,placement:o,rects:i,platform:a,elements:l,middlewareData:u}=t,{element:s,padding:c=0}=S(e,t)||{};if(null==s)return{};let d=A(c),f={x:n,y:r},p=T(R(o)),m=P(p),h=await a.getDimensions(s),v="y"===p,y=v?"clientHeight":"clientWidth",w=i.reference[m]+i.reference[p]-f[p]-i.floating[m],x=f[p]-i.reference[p],E=await (null==a.getOffsetParent?void 0:a.getOffsetParent(s)),C=E?E[y]:0;C&&await (null==a.isElement?void 0:a.isElement(E))||(C=l.floating[y]||i.floating[m]);let M=C/2-h[m]/2-1,L=g(d[v?"top":"left"],M),j=g(d[v?"bottom":"right"],M),O=C-h[m]-j,D=C/2-h[m]/2+(w/2-x/2),W=b(L,g(D,O)),N=!u.arrow&&null!=k(o)&&D!==W&&i.reference[m]/2-(D<L?L:j)-h[m]/2<0,I=N?D<L?D-L:D-O:0;return{[p]:f[p]+I,data:{[p]:W,centerOffset:D-W-I,...N&&{alignmentOffset:I}},reset:N}}}),ew=(e,t,n)=>{let r=new Map,o={platform:eg,...n},i={...o.platform,_c:r};return W(e,t,{...o,platform:i})};var ex="undefined"!=typeof document?r.useLayoutEffect:function(){};function eE(e,t){let n,r,o;if(e===t)return!0;if(typeof e!=typeof t)return!1;if("function"==typeof e&&e.toString()===t.toString())return!0;if(e&&t&&"object"==typeof e){if(Array.isArray(e)){if((n=e.length)!==t.length)return!1;for(r=n;0!=r--;)if(!eE(e[r],t[r]))return!1;return!0}if((n=(o=Object.keys(e)).length)!==Object.keys(t).length)return!1;for(r=n;0!=r--;)if(!({}).hasOwnProperty.call(t,o[r]))return!1;for(r=n;0!=r--;){let n=o[r];if(("_owner"!==n||!e.$$typeof)&&!eE(e[n],t[n]))return!1}return!0}return e!=e&&t!=t}function eC(e){return"undefined"==typeof window?1:(e.ownerDocument.defaultView||window).devicePixelRatio||1}function eS(e,t){let n=eC(e);return Math.round(t*n)/n}function eM(e){let t=r.useRef(e);return ex(()=>{t.current=e}),t}let ek=e=>({name:"arrow",options:e,fn(t){let{element:n,padding:r}="function"==typeof e?e(t):e;return n&&({}).hasOwnProperty.call(n,"current")?null!=n.current?ey({element:n.current,padding:r}).fn(t):{}:n?ey({element:n,padding:r}).fn(t):{}}}),eT=(e,t)=>{var n;return{...(void 0===(n=e)&&(n=0),{name:"offset",options:n,async fn(e){var t,r;let{x:o,y:i,placement:a,middlewareData:l}=e,u=await z(e,n);return a===(null==(t=l.offset)?void 0:t.placement)&&null!=(r=l.arrow)&&r.alignmentOffset?{}:{x:o+u.x,y:i+u.y,data:{...u,placement:a}}}}),options:[e,t]}},eP=(e,t)=>{var n;return{...(void 0===(n=e)&&(n={}),{name:"shift",options:n,async fn(e){let{x:t,y:r,placement:o}=e,{mainAxis:i=!0,crossAxis:a=!1,limiter:l={fn:e=>{let{x:t,y:n}=e;return{x:t,y:n}}},...u}=S(n,e),s={x:t,y:r},c=await N(e,u),d=R(M(o)),f=T(d),p=s[f],m=s[d];if(i){let e="y"===f?"top":"left",t="y"===f?"bottom":"right",n=p+c[e],r=p-c[t];p=b(n,g(p,r))}if(a){let e="y"===d?"top":"left",t="y"===d?"bottom":"right",n=m+c[e],r=m-c[t];m=b(n,g(m,r))}let h=l.fn({...e,[f]:p,[d]:m});return{...h,data:{x:h.x-t,y:h.y-r,enabled:{[f]:i,[d]:a}}}}}),options:[e,t]}},eR=(e,t)=>{var n;return{...(void 0===(n=e)&&(n={}),{options:n,fn(e){let{x:t,y:r,placement:o,rects:i,middlewareData:a}=e,{offset:l=0,mainAxis:u=!0,crossAxis:s=!0}=S(n,e),c={x:t,y:r},d=R(o),f=T(d),p=c[f],m=c[d],h=S(l,e),v="number"==typeof h?{mainAxis:h,crossAxis:0}:{mainAxis:0,crossAxis:0,...h};if(u){let e="y"===f?"height":"width",t=i.reference[f]-i.floating[e]+v.mainAxis,n=i.reference[f]+i.reference[e]-v.mainAxis;p<t?p=t:p>n&&(p=n)}if(s){var g,b;let e="y"===f?"width":"height",t=["top","left"].includes(M(o)),n=i.reference[d]-i.floating[e]+(t&&(null==(g=a.offset)?void 0:g[d])||0)+(t?0:v.crossAxis),r=i.reference[d]+i.reference[e]+(t?0:(null==(b=a.offset)?void 0:b[d])||0)-(t?v.crossAxis:0);m<n?m=n:m>r&&(m=r)}return{[f]:p,[d]:m}}}),options:[e,t]}},eL=(e,t)=>{var n;return{...(void 0===(n=e)&&(n={}),{name:"flip",options:n,async fn(e){var t,r,o,i,a;let{placement:l,middlewareData:u,rects:s,initialPlacement:c,platform:d,elements:f}=e,{mainAxis:p=!0,crossAxis:m=!0,fallbackPlacements:h,fallbackStrategy:v="bestFit",fallbackAxisSideDirection:g="none",flipAlignment:b=!0,...y}=S(n,e);if(null!=(t=u.arrow)&&t.alignmentOffset)return{};let w=M(l),x=R(c),E=M(c)===c,C=await (null==d.isRTL?void 0:d.isRTL(f.floating)),A=h||(E||!b?[j(c)]:function(e){let t=j(e);return[L(e),t,L(t)]}(c)),O="none"!==g;!h&&O&&A.push(...function(e,t,n,r){let o=k(e),i=function(e,t,n){let r=["left","right"],o=["right","left"];switch(e){case"top":case"bottom":if(n)return t?o:r;return t?r:o;case"left":case"right":return t?["top","bottom"]:["bottom","top"];default:return[]}}(M(e),"start"===n,r);return o&&(i=i.map(e=>e+"-"+o),t&&(i=i.concat(i.map(L)))),i}(c,b,g,C));let D=[c,...A],W=await N(e,y),I=[],_=(null==(r=u.flip)?void 0:r.overflows)||[];if(p&&I.push(W[w]),m){let e=function(e,t,n){void 0===n&&(n=!1);let r=k(e),o=T(R(e)),i=P(o),a="x"===o?r===(n?"end":"start")?"right":"left":"start"===r?"bottom":"top";return t.reference[i]>t.floating[i]&&(a=j(a)),[a,j(a)]}(l,s,C);I.push(W[e[0]],W[e[1]])}if(_=[..._,{placement:l,overflows:I}],!I.every(e=>e<=0)){let e=((null==(o=u.flip)?void 0:o.index)||0)+1,t=D[e];if(t&&(!("alignment"===m&&x!==R(t))||_.every(e=>e.overflows[0]>0&&R(e.placement)===x)))return{data:{index:e,overflows:_},reset:{placement:t}};let n=null==(i=_.filter(e=>e.overflows[0]<=0).sort((e,t)=>e.overflows[1]-t.overflows[1])[0])?void 0:i.placement;if(!n)switch(v){case"bestFit":{let e=null==(a=_.filter(e=>{if(O){let t=R(e.placement);return t===x||"y"===t}return!0}).map(e=>[e.placement,e.overflows.filter(e=>e>0).reduce((e,t)=>e+t,0)]).sort((e,t)=>e[1]-t[1])[0])?void 0:a[0];e&&(n=e);break}case"initialPlacement":n=c}if(l!==n)return{reset:{placement:n}}}return{}}}),options:[e,t]}},ej=(e,t)=>{var n;return{...(void 0===(n=e)&&(n={}),{name:"size",options:n,async fn(e){var t,r;let o,i;let{placement:a,rects:l,platform:u,elements:s}=e,{apply:c=()=>{},...d}=S(n,e),f=await N(e,d),p=M(a),m=k(a),h="y"===R(a),{width:v,height:y}=l.floating;"top"===p||"bottom"===p?(o=p,i=m===(await (null==u.isRTL?void 0:u.isRTL(s.floating))?"start":"end")?"left":"right"):(i=p,o="end"===m?"top":"bottom");let w=y-f.top-f.bottom,x=v-f.left-f.right,E=g(y-f[o],w),C=g(v-f[i],x),T=!e.middlewareData.shift,P=E,L=C;if(null!=(t=e.middlewareData.shift)&&t.enabled.x&&(L=x),null!=(r=e.middlewareData.shift)&&r.enabled.y&&(P=w),T&&!m){let e=b(f.left,0),t=b(f.right,0),n=b(f.top,0),r=b(f.bottom,0);h?L=v-2*(0!==e||0!==t?e+t:b(f.left,f.right)):P=y-2*(0!==n||0!==r?n+r:b(f.top,f.bottom))}await c({...e,availableWidth:L,availableHeight:P});let j=await u.getDimensions(s.floating);return v!==j.width||y!==j.height?{reset:{rects:!0}}:{}}}),options:[e,t]}},eA=(e,t)=>{var n;return{...(void 0===(n=e)&&(n={}),{name:"hide",options:n,async fn(e){let{rects:t}=e,{strategy:r="referenceHidden",...o}=S(n,e);switch(r){case"referenceHidden":{let n=I(await N(e,{...o,elementContext:"reference"}),t.reference);return{data:{referenceHiddenOffsets:n,referenceHidden:_(n)}}}case"escaped":{let n=I(await N(e,{...o,altBoundary:!0}),t.floating);return{data:{escapedOffsets:n,escaped:_(n)}}}default:return{}}}}),options:[e,t]}},eO=(e,t)=>({...ek(e),options:[e,t]});var eD=n(75320),eW=r.forwardRef((e,t)=>{let{children:n,width:r=10,height:o=5,...i}=e;return(0,c.jsx)(eD.WV.svg,{...i,ref:t,width:r,height:o,viewBox:"0 0 30 10",preserveAspectRatio:"none",children:e.asChild?n:(0,c.jsx)("polygon",{points:"0,0 30,0 15,10"})})});eW.displayName="Arrow";var eN=n(79698),eI=n(9981),e_="Popper",[ez,eF]=(0,l.b)(e_),[eH,e$]=ez(e_),eV=e=>{let{__scopePopper:t,children:n}=e,[o,i]=r.useState(null);return(0,c.jsx)(eH,{scope:t,anchor:o,onAnchorChange:i,children:n})};eV.displayName=e_;var eB="PopperAnchor",eX=r.forwardRef((e,t)=>{let{__scopePopper:n,virtualRef:o,...i}=e,a=e$(eB,n),l=r.useRef(null),s=(0,u.e)(t,l);return r.useEffect(()=>{a.onAnchorChange(o?.current||l.current)}),o?null:(0,c.jsx)(eD.WV.div,{...i,ref:s})});eX.displayName=eB;var eY="PopperContent",[eU,eq]=ez(eY),eK=r.forwardRef((e,t)=>{let{__scopePopper:n,side:i="bottom",sideOffset:a=0,align:l="center",alignOffset:s=0,arrowPadding:d=0,avoidCollisions:f=!0,collisionBoundary:p=[],collisionPadding:m=0,sticky:h="partial",hideWhenDetached:v=!1,updatePositionStrategy:y="optimized",onPlaced:x,...E}=e,C=e$(eY,n),[S,M]=r.useState(null),k=(0,u.e)(t,e=>M(e)),[T,P]=r.useState(null),R=function(e){let[t,n]=r.useState(void 0);return(0,eI.b)(()=>{if(e){n({width:e.offsetWidth,height:e.offsetHeight});let t=new ResizeObserver(t=>{let r,o;if(!Array.isArray(t)||!t.length)return;let i=t[0];if("borderBoxSize"in i){let e=i.borderBoxSize,t=Array.isArray(e)?e[0]:e;r=t.inlineSize,o=t.blockSize}else r=e.offsetWidth,o=e.offsetHeight;n({width:r,height:o})});return t.observe(e,{box:"border-box"}),()=>t.unobserve(e)}n(void 0)},[e]),t}(T),L=R?.width??0,j=R?.height??0,A="number"==typeof m?m:{top:0,right:0,bottom:0,left:0,...m},O=Array.isArray(p)?p:[p],D=O.length>0,W={padding:A,boundary:O.filter(eQ),altBoundary:D},{refs:N,floatingStyles:I,placement:_,isPositioned:z,middlewareData:F}=function(e){void 0===e&&(e={});let{placement:t="bottom",strategy:n="absolute",middleware:i=[],platform:a,elements:{reference:l,floating:u}={},transform:s=!0,whileElementsMounted:c,open:d}=e,[f,p]=r.useState({x:0,y:0,strategy:n,placement:t,middlewareData:{},isPositioned:!1}),[m,h]=r.useState(i);eE(m,i)||h(i);let[v,g]=r.useState(null),[b,y]=r.useState(null),w=r.useCallback(e=>{e!==S.current&&(S.current=e,g(e))},[]),x=r.useCallback(e=>{e!==M.current&&(M.current=e,y(e))},[]),E=l||v,C=u||b,S=r.useRef(null),M=r.useRef(null),k=r.useRef(f),T=null!=c,P=eM(c),R=eM(a),L=eM(d),j=r.useCallback(()=>{if(!S.current||!M.current)return;let e={placement:t,strategy:n,middleware:m};R.current&&(e.platform=R.current),ew(S.current,M.current,e).then(e=>{let t={...e,isPositioned:!1!==L.current};A.current&&!eE(k.current,t)&&(k.current=t,o.flushSync(()=>{p(t)}))})},[m,t,n,R,L]);ex(()=>{!1===d&&k.current.isPositioned&&(k.current.isPositioned=!1,p(e=>({...e,isPositioned:!1})))},[d]);let A=r.useRef(!1);ex(()=>(A.current=!0,()=>{A.current=!1}),[]),ex(()=>{if(E&&(S.current=E),C&&(M.current=C),E&&C){if(P.current)return P.current(E,C,j);j()}},[E,C,j,P,T]);let O=r.useMemo(()=>({reference:S,floating:M,setReference:w,setFloating:x}),[w,x]),D=r.useMemo(()=>({reference:E,floating:C}),[E,C]),W=r.useMemo(()=>{let e={position:n,left:0,top:0};if(!D.floating)return e;let t=eS(D.floating,f.x),r=eS(D.floating,f.y);return s?{...e,transform:"translate("+t+"px, "+r+"px)",...eC(D.floating)>=1.5&&{willChange:"transform"}}:{position:n,left:t,top:r}},[n,s,D.floating,f.x,f.y]);return r.useMemo(()=>({...f,update:j,refs:O,elements:D,floatingStyles:W}),[f,j,O,D,W])}({strategy:"fixed",placement:i+("center"!==l?"-"+l:""),whileElementsMounted:(...e)=>(function(e,t,n,r){let o;void 0===r&&(r={});let{ancestorScroll:i=!0,ancestorResize:a=!0,elementResize:l="function"==typeof ResizeObserver,layoutShift:u="function"==typeof IntersectionObserver,animationFrame:s=!1}=r,c=ei(e),d=i||a?[...c?en(c):[],...en(t)]:[];d.forEach(e=>{i&&e.addEventListener("scroll",n,{passive:!0}),a&&e.addEventListener("resize",n)});let f=c&&u?function(e,t){let n,r=null,o=V(e);function i(){var e;clearTimeout(n),null==(e=r)||e.disconnect(),r=null}return!function a(l,u){void 0===l&&(l=!1),void 0===u&&(u=1),i();let s=e.getBoundingClientRect(),{left:c,top:d,width:f,height:p}=s;if(l||t(),!f||!p)return;let m=w(d),h=w(o.clientWidth-(c+f)),v={rootMargin:-m+"px "+-h+"px "+-w(o.clientHeight-(d+p))+"px "+-w(c)+"px",threshold:b(0,g(1,u))||1},y=!0;function x(t){let r=t[0].intersectionRatio;if(r!==u){if(!y)return a();r?a(!1,r):n=setTimeout(()=>{a(!1,1e-7)},1e3)}1!==r||eb(s,e.getBoundingClientRect())||a(),y=!1}try{r=new IntersectionObserver(x,{...v,root:o.ownerDocument})}catch(e){r=new IntersectionObserver(x,v)}r.observe(e)}(!0),i}(c,n):null,p=-1,m=null;l&&(m=new ResizeObserver(e=>{let[r]=e;r&&r.target===c&&m&&(m.unobserve(t),cancelAnimationFrame(p),p=requestAnimationFrame(()=>{var e;null==(e=m)||e.observe(t)})),n()}),c&&!s&&m.observe(c),m.observe(t));let h=s?es(e):null;return s&&function t(){let r=es(e);h&&!eb(h,r)&&n(),h=r,o=requestAnimationFrame(t)}(),n(),()=>{var e;d.forEach(e=>{i&&e.removeEventListener("scroll",n),a&&e.removeEventListener("resize",n)}),null==f||f(),null==(e=m)||e.disconnect(),m=null,s&&cancelAnimationFrame(o)}})(...e,{animationFrame:"always"===y}),elements:{reference:C.anchor},middleware:[eT({mainAxis:a+j,alignmentAxis:s}),f&&eP({mainAxis:!0,crossAxis:!1,limiter:"partial"===h?eR():void 0,...W}),f&&eL({...W}),ej({...W,apply:({elements:e,rects:t,availableWidth:n,availableHeight:r})=>{let{width:o,height:i}=t.reference,a=e.floating.style;a.setProperty("--radix-popper-available-width",`${n}px`),a.setProperty("--radix-popper-available-height",`${r}px`),a.setProperty("--radix-popper-anchor-width",`${o}px`),a.setProperty("--radix-popper-anchor-height",`${i}px`)}}),T&&eO({element:T,padding:d}),e0({arrowWidth:L,arrowHeight:j}),v&&eA({strategy:"referenceHidden",...W})]}),[H,$]=e1(_),B=(0,eN.W)(x);(0,eI.b)(()=>{z&&B?.()},[z,B]);let X=F.arrow?.x,Y=F.arrow?.y,U=F.arrow?.centerOffset!==0,[q,K]=r.useState();return(0,eI.b)(()=>{S&&K(window.getComputedStyle(S).zIndex)},[S]),(0,c.jsx)("div",{ref:N.setFloating,"data-radix-popper-content-wrapper":"",style:{...I,transform:z?I.transform:"translate(0, -200%)",minWidth:"max-content",zIndex:q,"--radix-popper-transform-origin":[F.transformOrigin?.x,F.transformOrigin?.y].join(" "),...F.hide?.referenceHidden&&{visibility:"hidden",pointerEvents:"none"}},dir:e.dir,children:(0,c.jsx)(eU,{scope:n,placedSide:H,onArrowChange:P,arrowX:X,arrowY:Y,shouldHideArrow:U,children:(0,c.jsx)(eD.WV.div,{"data-side":H,"data-align":$,...E,ref:k,style:{...E.style,animation:z?void 0:"none"}})})})});eK.displayName=eY;var eZ="PopperArrow",eG={top:"bottom",right:"left",bottom:"top",left:"right"},eJ=r.forwardRef(function(e,t){let{__scopePopper:n,...r}=e,o=eq(eZ,n),i=eG[o.placedSide];return(0,c.jsx)("span",{ref:o.onArrowChange,style:{position:"absolute",left:o.arrowX,top:o.arrowY,[i]:0,transformOrigin:{top:"",right:"0 0",bottom:"center 0",left:"100% 0"}[o.placedSide],transform:{top:"translateY(100%)",right:"translateY(50%) rotate(90deg) translateX(-50%)",bottom:"rotate(180deg)",left:"translateY(50%) rotate(-90deg) translateX(50%)"}[o.placedSide],visibility:o.shouldHideArrow?"hidden":void 0},children:(0,c.jsx)(eW,{...r,ref:t,style:{...r.style,display:"block"}})})});function eQ(e){return null!==e}eJ.displayName=eZ;var e0=e=>({name:"transformOrigin",options:e,fn(t){let{placement:n,rects:r,middlewareData:o}=t,i=o.arrow?.centerOffset!==0,a=i?0:e.arrowWidth,l=i?0:e.arrowHeight,[u,s]=e1(n),c={start:"0%",center:"50%",end:"100%"}[s],d=(o.arrow?.x??0)+a/2,f=(o.arrow?.y??0)+l/2,p="",m="";return"bottom"===u?(p=i?c:`${d}px`,m=`${-l}px`):"top"===u?(p=i?c:`${d}px`,m=`${r.floating.height+l}px`):"right"===u?(p=`${-l}px`,m=i?c:`${f}px`):"left"===u&&(p=`${r.floating.width+l}px`,m=i?c:`${f}px`),{data:{x:p,y:m}}}});function e1(e){let[t,n="center"]=e.split("-");return[t,n]}var e2=n(42651),e5=n(77342),e9=Object.freeze({position:"absolute",border:0,width:1,height:1,padding:0,margin:-1,overflow:"hidden",clip:"rect(0, 0, 0, 0)",whiteSpace:"nowrap",wordWrap:"normal"});r.forwardRef((e,t)=>(0,c.jsx)(eD.WV.span,{...e,ref:t,style:{...e9,...e.style}})).displayName="VisuallyHidden";var e4=n(23541),e3=n(6223),e7=[" ","Enter","ArrowUp","ArrowDown"],e6=[" ","Enter"],e8="Select",[te,tt,tn]=function(e){let t=e+"CollectionProvider",[n,o]=(0,l.b)(t),[i,a]=n(t,{collectionRef:{current:null},itemMap:new Map}),d=e=>{let{scope:t,children:n}=e,o=r.useRef(null),a=r.useRef(new Map).current;return(0,c.jsx)(i,{scope:t,itemMap:a,collectionRef:o,children:n})};d.displayName=t;let f=e+"CollectionSlot",p=(0,s.Z8)(f),m=r.forwardRef((e,t)=>{let{scope:n,children:r}=e,o=a(f,n),i=(0,u.e)(t,o.collectionRef);return(0,c.jsx)(p,{ref:i,children:r})});m.displayName=f;let h=e+"CollectionItemSlot",v="data-radix-collection-item",g=(0,s.Z8)(h),b=r.forwardRef((e,t)=>{let{scope:n,children:o,...i}=e,l=r.useRef(null),s=(0,u.e)(t,l),d=a(h,n);return r.useEffect(()=>(d.itemMap.set(l,{ref:l,...i}),()=>void d.itemMap.delete(l))),(0,c.jsx)(g,{[v]:"",ref:s,children:o})});return b.displayName=h,[{Provider:d,Slot:m,ItemSlot:b},function(t){let n=a(e+"CollectionConsumer",t);return r.useCallback(()=>{let e=n.collectionRef.current;if(!e)return[];let t=Array.from(e.querySelectorAll(`[${v}]`));return Array.from(n.itemMap.values()).sort((e,n)=>t.indexOf(e.ref.current)-t.indexOf(n.ref.current))},[n.collectionRef,n.itemMap])},o]}(e8),[tr,to]=(0,l.b)(e8,[tn,eF]),ti=eF(),[ta,tl]=tr(e8),[tu,ts]=tr(e8),tc=e=>{let{__scopeSelect:t,children:n,open:o,defaultOpen:i,onOpenChange:a,value:l,defaultValue:u,onValueChange:s,dir:f,name:p,autoComplete:m,disabled:v,required:g,form:b}=e,y=ti(t),[w,x]=r.useState(null),[E,C]=r.useState(null),[S,M]=r.useState(!1),k=function(e){let t=r.useContext(d);return e||t||"ltr"}(f),[T,P]=(0,e5.T)({prop:o,defaultProp:i??!1,onChange:a,caller:e8}),[R,L]=(0,e5.T)({prop:l,defaultProp:u,onChange:s,caller:e8}),j=r.useRef(null),A=!w||b||!!w.closest("form"),[O,D]=r.useState(new Set),W=Array.from(O).map(e=>e.props.value).join(";");return(0,c.jsx)(eV,{...y,children:(0,c.jsxs)(ta,{required:g,scope:t,trigger:w,onTriggerChange:x,valueNode:E,onValueNodeChange:C,valueNodeHasChildren:S,onValueNodeHasChildrenChange:M,contentId:(0,h.M)(),value:R,onValueChange:L,open:T,onOpenChange:P,dir:k,triggerPointerDownPosRef:j,disabled:v,children:[(0,c.jsx)(te.Provider,{scope:t,children:(0,c.jsx)(tu,{scope:e.__scopeSelect,onNativeOptionAdd:r.useCallback(e=>{D(t=>new Set(t).add(e))},[]),onNativeOptionRemove:r.useCallback(e=>{D(t=>{let n=new Set(t);return n.delete(e),n})},[]),children:n})}),A?(0,c.jsxs)(tZ,{"aria-hidden":!0,required:g,tabIndex:-1,name:p,autoComplete:m,value:R,onChange:e=>L(e.target.value),disabled:v,form:b,children:[void 0===R?(0,c.jsx)("option",{value:""}):null,Array.from(O)]},W):null]})})};tc.displayName=e8;var td="SelectTrigger",tf=r.forwardRef((e,t)=>{let{__scopeSelect:n,disabled:o=!1,...i}=e,l=ti(n),s=tl(td,n),d=s.disabled||o,f=(0,u.e)(t,s.onTriggerChange),p=tt(n),m=r.useRef("touch"),[h,v,g]=tJ(e=>{let t=p().filter(e=>!e.disabled),n=t.find(e=>e.value===s.value),r=tQ(t,e,n);void 0!==r&&s.onValueChange(r.value)}),b=e=>{d||(s.onOpenChange(!0),g()),e&&(s.triggerPointerDownPosRef.current={x:Math.round(e.pageX),y:Math.round(e.pageY)})};return(0,c.jsx)(eX,{asChild:!0,...l,children:(0,c.jsx)(eD.WV.button,{type:"button",role:"combobox","aria-controls":s.contentId,"aria-expanded":s.open,"aria-required":s.required,"aria-autocomplete":"none",dir:s.dir,"data-state":s.open?"open":"closed",disabled:d,"data-disabled":d?"":void 0,"data-placeholder":tG(s.value)?"":void 0,...i,ref:f,onClick:(0,a.M)(i.onClick,e=>{e.currentTarget.focus(),"mouse"!==m.current&&b(e)}),onPointerDown:(0,a.M)(i.onPointerDown,e=>{m.current=e.pointerType;let t=e.target;t.hasPointerCapture(e.pointerId)&&t.releasePointerCapture(e.pointerId),0===e.button&&!1===e.ctrlKey&&"mouse"===e.pointerType&&(b(e),e.preventDefault())}),onKeyDown:(0,a.M)(i.onKeyDown,e=>{let t=""!==h.current;e.ctrlKey||e.altKey||e.metaKey||1!==e.key.length||v(e.key),(!t||" "!==e.key)&&e7.includes(e.key)&&(b(),e.preventDefault())})})})});tf.displayName=td;var tp="SelectValue",tm=r.forwardRef((e,t)=>{let{__scopeSelect:n,className:r,style:o,children:i,placeholder:a="",...l}=e,s=tl(tp,n),{onValueNodeHasChildrenChange:d}=s,f=void 0!==i,p=(0,u.e)(t,s.onValueNodeChange);return(0,eI.b)(()=>{d(f)},[d,f]),(0,c.jsx)(eD.WV.span,{...l,ref:p,style:{pointerEvents:"none"},children:tG(s.value)?(0,c.jsx)(c.Fragment,{children:a}):i})});tm.displayName=tp;var th=r.forwardRef((e,t)=>{let{__scopeSelect:n,children:r,...o}=e;return(0,c.jsx)(eD.WV.span,{"aria-hidden":!0,...o,ref:t,children:r||"▼"})});th.displayName="SelectIcon";var tv=e=>(0,c.jsx)(e2.h,{asChild:!0,...e});tv.displayName="SelectPortal";var tg="SelectContent",tb=r.forwardRef((e,t)=>{let n=tl(tg,e.__scopeSelect),[i,a]=r.useState();return((0,eI.b)(()=>{a(new DocumentFragment)},[]),n.open)?(0,c.jsx)(tE,{...e,ref:t}):i?o.createPortal((0,c.jsx)(ty,{scope:e.__scopeSelect,children:(0,c.jsx)(te.Slot,{scope:e.__scopeSelect,children:(0,c.jsx)("div",{children:e.children})})}),i):null});tb.displayName=tg;var[ty,tw]=tr(tg),tx=(0,s.Z8)("SelectContent.RemoveScroll"),tE=r.forwardRef((e,t)=>{let{__scopeSelect:n,position:o="item-aligned",onCloseAutoFocus:i,onEscapeKeyDown:l,onPointerDownOutside:s,side:d,sideOffset:h,align:v,alignOffset:g,arrowPadding:b,collisionBoundary:y,collisionPadding:w,sticky:x,hideWhenDetached:E,avoidCollisions:C,...S}=e,M=tl(tg,n),[k,T]=r.useState(null),[P,R]=r.useState(null),L=(0,u.e)(t,e=>T(e)),[j,A]=r.useState(null),[O,D]=r.useState(null),W=tt(n),[N,I]=r.useState(!1),_=r.useRef(!1);r.useEffect(()=>{if(k)return(0,e4.Ry)(k)},[k]),(0,p.EW)();let z=r.useCallback(e=>{let[t,...n]=W().map(e=>e.ref.current),[r]=n.slice(-1),o=document.activeElement;for(let n of e)if(n===o||(n?.scrollIntoView({block:"nearest"}),n===t&&P&&(P.scrollTop=0),n===r&&P&&(P.scrollTop=P.scrollHeight),n?.focus(),document.activeElement!==o))return},[W,P]),F=r.useCallback(()=>z([j,k]),[z,j,k]);r.useEffect(()=>{N&&F()},[N,F]);let{onOpenChange:H,triggerPointerDownPosRef:$}=M;r.useEffect(()=>{if(k){let e={x:0,y:0},t=t=>{e={x:Math.abs(Math.round(t.pageX)-($.current?.x??0)),y:Math.abs(Math.round(t.pageY)-($.current?.y??0))}},n=n=>{e.x<=10&&e.y<=10?n.preventDefault():k.contains(n.target)||H(!1),document.removeEventListener("pointermove",t),$.current=null};return null!==$.current&&(document.addEventListener("pointermove",t),document.addEventListener("pointerup",n,{capture:!0,once:!0})),()=>{document.removeEventListener("pointermove",t),document.removeEventListener("pointerup",n,{capture:!0})}}},[k,H,$]),r.useEffect(()=>{let e=()=>H(!1);return window.addEventListener("blur",e),window.addEventListener("resize",e),()=>{window.removeEventListener("blur",e),window.removeEventListener("resize",e)}},[H]);let[V,B]=tJ(e=>{let t=W().filter(e=>!e.disabled),n=t.find(e=>e.ref.current===document.activeElement),r=tQ(t,e,n);r&&setTimeout(()=>r.ref.current.focus())}),X=r.useCallback((e,t,n)=>{let r=!_.current&&!n;(void 0!==M.value&&M.value===t||r)&&(A(e),r&&(_.current=!0))},[M.value]),Y=r.useCallback(()=>k?.focus(),[k]),U=r.useCallback((e,t,n)=>{let r=!_.current&&!n;(void 0!==M.value&&M.value===t||r)&&D(e)},[M.value]),q="popper"===o?tS:tC,K=q===tS?{side:d,sideOffset:h,align:v,alignOffset:g,arrowPadding:b,collisionBoundary:y,collisionPadding:w,sticky:x,hideWhenDetached:E,avoidCollisions:C}:{};return(0,c.jsx)(ty,{scope:n,content:k,viewport:P,onViewportChange:R,itemRefCallback:X,selectedItem:j,onItemLeave:Y,itemTextRefCallback:U,focusSelectedItem:F,selectedItemText:O,position:o,isPositioned:N,searchRef:V,children:(0,c.jsx)(e3.Z,{as:tx,allowPinchZoom:!0,children:(0,c.jsx)(m.M,{asChild:!0,trapped:M.open,onMountAutoFocus:e=>{e.preventDefault()},onUnmountAutoFocus:(0,a.M)(i,e=>{M.trigger?.focus({preventScroll:!0}),e.preventDefault()}),children:(0,c.jsx)(f.XB,{asChild:!0,disableOutsidePointerEvents:!0,onEscapeKeyDown:l,onPointerDownOutside:s,onFocusOutside:e=>e.preventDefault(),onDismiss:()=>M.onOpenChange(!1),children:(0,c.jsx)(q,{role:"listbox",id:M.contentId,"data-state":M.open?"open":"closed",dir:M.dir,onContextMenu:e=>e.preventDefault(),...S,...K,onPlaced:()=>I(!0),ref:L,style:{display:"flex",flexDirection:"column",outline:"none",...S.style},onKeyDown:(0,a.M)(S.onKeyDown,e=>{let t=e.ctrlKey||e.altKey||e.metaKey;if("Tab"===e.key&&e.preventDefault(),t||1!==e.key.length||B(e.key),["ArrowUp","ArrowDown","Home","End"].includes(e.key)){let t=W().filter(e=>!e.disabled).map(e=>e.ref.current);if(["ArrowUp","End"].includes(e.key)&&(t=t.slice().reverse()),["ArrowUp","ArrowDown"].includes(e.key)){let n=e.target,r=t.indexOf(n);t=t.slice(r+1)}setTimeout(()=>z(t)),e.preventDefault()}})})})})})})});tE.displayName="SelectContentImpl";var tC=r.forwardRef((e,t)=>{let{__scopeSelect:n,onPlaced:o,...a}=e,l=tl(tg,n),s=tw(tg,n),[d,f]=r.useState(null),[p,m]=r.useState(null),h=(0,u.e)(t,e=>m(e)),v=tt(n),g=r.useRef(!1),b=r.useRef(!0),{viewport:y,selectedItem:w,selectedItemText:x,focusSelectedItem:E}=s,C=r.useCallback(()=>{if(l.trigger&&l.valueNode&&d&&p&&y&&w&&x){let e=l.trigger.getBoundingClientRect(),t=p.getBoundingClientRect(),n=l.valueNode.getBoundingClientRect(),r=x.getBoundingClientRect();if("rtl"!==l.dir){let o=r.left-t.left,a=n.left-o,l=e.left-a,u=e.width+l,s=Math.max(u,t.width),c=i(a,[10,Math.max(10,window.innerWidth-10-s)]);d.style.minWidth=u+"px",d.style.left=c+"px"}else{let o=t.right-r.right,a=window.innerWidth-n.right-o,l=window.innerWidth-e.right-a,u=e.width+l,s=Math.max(u,t.width),c=i(a,[10,Math.max(10,window.innerWidth-10-s)]);d.style.minWidth=u+"px",d.style.right=c+"px"}let a=v(),u=window.innerHeight-20,s=y.scrollHeight,c=window.getComputedStyle(p),f=parseInt(c.borderTopWidth,10),m=parseInt(c.paddingTop,10),h=parseInt(c.borderBottomWidth,10),b=f+m+s+parseInt(c.paddingBottom,10)+h,E=Math.min(5*w.offsetHeight,b),C=window.getComputedStyle(y),S=parseInt(C.paddingTop,10),M=parseInt(C.paddingBottom,10),k=e.top+e.height/2-10,T=w.offsetHeight/2,P=f+m+(w.offsetTop+T);if(P<=k){let e=a.length>0&&w===a[a.length-1].ref.current;d.style.bottom="0px";let t=p.clientHeight-y.offsetTop-y.offsetHeight;d.style.height=P+Math.max(u-k,T+(e?M:0)+t+h)+"px"}else{let e=a.length>0&&w===a[0].ref.current;d.style.top="0px";let t=Math.max(k,f+y.offsetTop+(e?S:0)+T);d.style.height=t+(b-P)+"px",y.scrollTop=P-k+y.offsetTop}d.style.margin="10px 0",d.style.minHeight=E+"px",d.style.maxHeight=u+"px",o?.(),requestAnimationFrame(()=>g.current=!0)}},[v,l.trigger,l.valueNode,d,p,y,w,x,l.dir,o]);(0,eI.b)(()=>C(),[C]);let[S,M]=r.useState();(0,eI.b)(()=>{p&&M(window.getComputedStyle(p).zIndex)},[p]);let k=r.useCallback(e=>{e&&!0===b.current&&(C(),E?.(),b.current=!1)},[C,E]);return(0,c.jsx)(tM,{scope:n,contentWrapper:d,shouldExpandOnScrollRef:g,onScrollButtonChange:k,children:(0,c.jsx)("div",{ref:f,style:{display:"flex",flexDirection:"column",position:"fixed",zIndex:S},children:(0,c.jsx)(eD.WV.div,{...a,ref:h,style:{boxSizing:"border-box",maxHeight:"100%",...a.style}})})})});tC.displayName="SelectItemAlignedPosition";var tS=r.forwardRef((e,t)=>{let{__scopeSelect:n,align:r="start",collisionPadding:o=10,...i}=e,a=ti(n);return(0,c.jsx)(eK,{...a,...i,ref:t,align:r,collisionPadding:o,style:{boxSizing:"border-box",...i.style,"--radix-select-content-transform-origin":"var(--radix-popper-transform-origin)","--radix-select-content-available-width":"var(--radix-popper-available-width)","--radix-select-content-available-height":"var(--radix-popper-available-height)","--radix-select-trigger-width":"var(--radix-popper-anchor-width)","--radix-select-trigger-height":"var(--radix-popper-anchor-height)"}})});tS.displayName="SelectPopperPosition";var[tM,tk]=tr(tg,{}),tT="SelectViewport",tP=r.forwardRef((e,t)=>{let{__scopeSelect:n,nonce:o,...i}=e,l=tw(tT,n),s=tk(tT,n),d=(0,u.e)(t,l.onViewportChange),f=r.useRef(0);return(0,c.jsxs)(c.Fragment,{children:[(0,c.jsx)("style",{dangerouslySetInnerHTML:{__html:"[data-radix-select-viewport]{scrollbar-width:none;-ms-overflow-style:none;-webkit-overflow-scrolling:touch;}[data-radix-select-viewport]::-webkit-scrollbar{display:none}"},nonce:o}),(0,c.jsx)(te.Slot,{scope:n,children:(0,c.jsx)(eD.WV.div,{"data-radix-select-viewport":"",role:"presentation",...i,ref:d,style:{position:"relative",flex:1,overflow:"hidden auto",...i.style},onScroll:(0,a.M)(i.onScroll,e=>{let t=e.currentTarget,{contentWrapper:n,shouldExpandOnScrollRef:r}=s;if(r?.current&&n){let e=Math.abs(f.current-t.scrollTop);if(e>0){let r=window.innerHeight-20,o=Math.max(parseFloat(n.style.minHeight),parseFloat(n.style.height));if(o<r){let i=o+e,a=Math.min(r,i),l=i-a;n.style.height=a+"px","0px"===n.style.bottom&&(t.scrollTop=l>0?l:0,n.style.justifyContent="flex-end")}}}f.current=t.scrollTop})})})]})});tP.displayName=tT;var tR="SelectGroup",[tL,tj]=tr(tR),tA=r.forwardRef((e,t)=>{let{__scopeSelect:n,...r}=e,o=(0,h.M)();return(0,c.jsx)(tL,{scope:n,id:o,children:(0,c.jsx)(eD.WV.div,{role:"group","aria-labelledby":o,...r,ref:t})})});tA.displayName=tR;var tO="SelectLabel",tD=r.forwardRef((e,t)=>{let{__scopeSelect:n,...r}=e,o=tj(tO,n);return(0,c.jsx)(eD.WV.div,{id:o.id,...r,ref:t})});tD.displayName=tO;var tW="SelectItem",[tN,tI]=tr(tW),t_=r.forwardRef((e,t)=>{let{__scopeSelect:n,value:o,disabled:i=!1,textValue:l,...s}=e,d=tl(tW,n),f=tw(tW,n),p=d.value===o,[m,v]=r.useState(l??""),[g,b]=r.useState(!1),y=(0,u.e)(t,e=>f.itemRefCallback?.(e,o,i)),w=(0,h.M)(),x=r.useRef("touch"),E=()=>{i||(d.onValueChange(o),d.onOpenChange(!1))};if(""===o)throw Error("A <Select.Item /> must have a value prop that is not an empty string. This is because the Select value can be set to an empty string to clear the selection and show the placeholder.");return(0,c.jsx)(tN,{scope:n,value:o,disabled:i,textId:w,isSelected:p,onItemTextChange:r.useCallback(e=>{v(t=>t||(e?.textContent??"").trim())},[]),children:(0,c.jsx)(te.ItemSlot,{scope:n,value:o,disabled:i,textValue:m,children:(0,c.jsx)(eD.WV.div,{role:"option","aria-labelledby":w,"data-highlighted":g?"":void 0,"aria-selected":p&&g,"data-state":p?"checked":"unchecked","aria-disabled":i||void 0,"data-disabled":i?"":void 0,tabIndex:i?void 0:-1,...s,ref:y,onFocus:(0,a.M)(s.onFocus,()=>b(!0)),onBlur:(0,a.M)(s.onBlur,()=>b(!1)),onClick:(0,a.M)(s.onClick,()=>{"mouse"!==x.current&&E()}),onPointerUp:(0,a.M)(s.onPointerUp,()=>{"mouse"===x.current&&E()}),onPointerDown:(0,a.M)(s.onPointerDown,e=>{x.current=e.pointerType}),onPointerMove:(0,a.M)(s.onPointerMove,e=>{x.current=e.pointerType,i?f.onItemLeave?.():"mouse"===x.current&&e.currentTarget.focus({preventScroll:!0})}),onPointerLeave:(0,a.M)(s.onPointerLeave,e=>{e.currentTarget===document.activeElement&&f.onItemLeave?.()}),onKeyDown:(0,a.M)(s.onKeyDown,e=>{f.searchRef?.current!==""&&" "===e.key||(e6.includes(e.key)&&E()," "===e.key&&e.preventDefault())})})})})});t_.displayName=tW;var tz="SelectItemText",tF=r.forwardRef((e,t)=>{let{__scopeSelect:n,className:i,style:a,...l}=e,s=tl(tz,n),d=tw(tz,n),f=tI(tz,n),p=ts(tz,n),[m,h]=r.useState(null),v=(0,u.e)(t,e=>h(e),f.onItemTextChange,e=>d.itemTextRefCallback?.(e,f.value,f.disabled)),g=m?.textContent,b=r.useMemo(()=>(0,c.jsx)("option",{value:f.value,disabled:f.disabled,children:g},f.value),[f.disabled,f.value,g]),{onNativeOptionAdd:y,onNativeOptionRemove:w}=p;return(0,eI.b)(()=>(y(b),()=>w(b)),[y,w,b]),(0,c.jsxs)(c.Fragment,{children:[(0,c.jsx)(eD.WV.span,{id:f.textId,...l,ref:v}),f.isSelected&&s.valueNode&&!s.valueNodeHasChildren?o.createPortal(l.children,s.valueNode):null]})});tF.displayName=tz;var tH="SelectItemIndicator",t$=r.forwardRef((e,t)=>{let{__scopeSelect:n,...r}=e;return tI(tH,n).isSelected?(0,c.jsx)(eD.WV.span,{"aria-hidden":!0,...r,ref:t}):null});t$.displayName=tH;var tV="SelectScrollUpButton",tB=r.forwardRef((e,t)=>{let n=tw(tV,e.__scopeSelect),o=tk(tV,e.__scopeSelect),[i,a]=r.useState(!1),l=(0,u.e)(t,o.onScrollButtonChange);return(0,eI.b)(()=>{if(n.viewport&&n.isPositioned){let e=function(){a(t.scrollTop>0)},t=n.viewport;return e(),t.addEventListener("scroll",e),()=>t.removeEventListener("scroll",e)}},[n.viewport,n.isPositioned]),i?(0,c.jsx)(tU,{...e,ref:l,onAutoScroll:()=>{let{viewport:e,selectedItem:t}=n;e&&t&&(e.scrollTop=e.scrollTop-t.offsetHeight)}}):null});tB.displayName=tV;var tX="SelectScrollDownButton",tY=r.forwardRef((e,t)=>{let n=tw(tX,e.__scopeSelect),o=tk(tX,e.__scopeSelect),[i,a]=r.useState(!1),l=(0,u.e)(t,o.onScrollButtonChange);return(0,eI.b)(()=>{if(n.viewport&&n.isPositioned){let e=function(){let e=t.scrollHeight-t.clientHeight;a(Math.ceil(t.scrollTop)<e)},t=n.viewport;return e(),t.addEventListener("scroll",e),()=>t.removeEventListener("scroll",e)}},[n.viewport,n.isPositioned]),i?(0,c.jsx)(tU,{...e,ref:l,onAutoScroll:()=>{let{viewport:e,selectedItem:t}=n;e&&t&&(e.scrollTop=e.scrollTop+t.offsetHeight)}}):null});tY.displayName=tX;var tU=r.forwardRef((e,t)=>{let{__scopeSelect:n,onAutoScroll:o,...i}=e,l=tw("SelectScrollButton",n),u=r.useRef(null),s=tt(n),d=r.useCallback(()=>{null!==u.current&&(window.clearInterval(u.current),u.current=null)},[]);return r.useEffect(()=>()=>d(),[d]),(0,eI.b)(()=>{let e=s().find(e=>e.ref.current===document.activeElement);e?.ref.current?.scrollIntoView({block:"nearest"})},[s]),(0,c.jsx)(eD.WV.div,{"aria-hidden":!0,...i,ref:t,style:{flexShrink:0,...i.style},onPointerDown:(0,a.M)(i.onPointerDown,()=>{null===u.current&&(u.current=window.setInterval(o,50))}),onPointerMove:(0,a.M)(i.onPointerMove,()=>{l.onItemLeave?.(),null===u.current&&(u.current=window.setInterval(o,50))}),onPointerLeave:(0,a.M)(i.onPointerLeave,()=>{d()})})}),tq=r.forwardRef((e,t)=>{let{__scopeSelect:n,...r}=e;return(0,c.jsx)(eD.WV.div,{"aria-hidden":!0,...r,ref:t})});tq.displayName="SelectSeparator";var tK="SelectArrow";r.forwardRef((e,t)=>{let{__scopeSelect:n,...r}=e,o=ti(n),i=tl(tK,n),a=tw(tK,n);return i.open&&"popper"===a.position?(0,c.jsx)(eJ,{...o,...r,ref:t}):null}).displayName=tK;var tZ=r.forwardRef(({__scopeSelect:e,value:t,...n},o)=>{let i=r.useRef(null),a=(0,u.e)(o,i),l=function(e){let t=r.useRef({value:e,previous:e});return r.useMemo(()=>(t.current.value!==e&&(t.current.previous=t.current.value,t.current.value=e),t.current.previous),[e])}(t);return r.useEffect(()=>{let e=i.current;if(!e)return;let n=Object.getOwnPropertyDescriptor(window.HTMLSelectElement.prototype,"value").set;if(l!==t&&n){let r=new Event("change",{bubbles:!0});n.call(e,t),e.dispatchEvent(r)}},[l,t]),(0,c.jsx)(eD.WV.select,{...n,style:{...e9,...n.style},ref:a,defaultValue:t})});function tG(e){return""===e||void 0===e}function tJ(e){let t=(0,eN.W)(e),n=r.useRef(""),o=r.useRef(0),i=r.useCallback(e=>{let r=n.current+e;t(r),function e(t){n.current=t,window.clearTimeout(o.current),""!==t&&(o.current=window.setTimeout(()=>e(""),1e3))}(r)},[t]),a=r.useCallback(()=>{n.current="",window.clearTimeout(o.current)},[]);return r.useEffect(()=>()=>window.clearTimeout(o.current),[]),[n,i,a]}function tQ(e,t,n){var r;let o=t.length>1&&Array.from(t).every(e=>e===t[0])?t[0]:t,i=(r=Math.max(n?e.indexOf(n):-1,0),e.map((t,n)=>e[(r+n)%e.length]));1===o.length&&(i=i.filter(e=>e!==n));let a=i.find(e=>e.textValue.toLowerCase().startsWith(o.toLowerCase()));return a!==n?a:void 0}tZ.displayName="SelectBubbleInput";var t0=tc,t1=tf,t2=tm,t5=th,t9=tv,t4=tb,t3=tP,t7=tA,t6=tD,t8=t_,ne=tF,nt=t$,nn=tB,nr=tY,no=tq},79698:function(e,t,n){n.d(t,{W:function(){return o}});var r=n(67294);function o(e){let t=r.useRef(e);return r.useEffect(()=>{t.current=e}),r.useMemo(()=>(...e)=>t.current?.(...e),[])}},77342:function(e,t,n){n.d(t,{T:function(){return l}});var r,o=n(67294),i=n(9981),a=(r||(r=n.t(o,2)))[" useInsertionEffect ".trim().toString()]||i.b;function l({prop:e,defaultProp:t,onChange:n=()=>{},caller:r}){let[i,l,u]=function({defaultProp:e,onChange:t}){let[n,r]=o.useState(e),i=o.useRef(n),l=o.useRef(t);return a(()=>{l.current=t},[t]),o.useEffect(()=>{i.current!==n&&(l.current?.(n),i.current=n)},[n,i]),[n,r,l]}({defaultProp:t,onChange:n}),s=void 0!==e,c=s?e:i;{let t=o.useRef(void 0!==e);o.useEffect(()=>{let e=t.current;if(e!==s){let t=s?"controlled":"uncontrolled";console.warn(`${r} is changing from ${e?"controlled":"uncontrolled"} to ${t}. Components should not switch from controlled to uncontrolled (or vice versa). Decide between using a controlled or uncontrolled value for the lifetime of the component.`)}t.current=s},[s,r])}return[c,o.useCallback(t=>{if(s){let n="function"==typeof t?t(e):t;n!==e&&u.current?.(n)}else l(t)},[s,e,l,u])]}Symbol("RADIX:SYNC_STATE")},9981:function(e,t,n){n.d(t,{b:function(){return o}});var r=n(67294),o=globalThis?.document?r.useLayoutEffect:()=>{}},68588:function(e,t,n){n.d(t,{M:function(){return r}});let r="data-"+(0,n(93193).D)("framerAppearId")},2445:function(e,t,n){n.d(t,{H:function(){return r}});function r(e){return null!==e&&"object"==typeof e&&"function"==typeof e.start}},9442:function(e,t,n){n.d(t,{featureDefinitions:function(){return o}});let r={animation:["animate","variants","whileHover","whileTap","exit","whileInView","whileFocus","whileDrag"],exit:["exit"],drag:["drag","dragControls"],focus:["whileFocus"],hover:["whileHover","onHoverStart","onHoverEnd"],tap:["whileTap","onTap","onTapStart","onTapCancel"],pan:["onPan","onPanStart","onPanSessionStart","onPanEnd"],inView:["whileInView","onViewportEnter","onViewportLeave"],layout:["layout","layoutId"]},o={};for(let e in r)o[e]={isEnabled:t=>r[e].some(e=>!!t[e])}},96728:function(e,t,n){n.d(t,{j:function(){return i}});var r=n(59354);let o={};function i(e,{layout:t,layoutId:n}){return r.G.has(e)||e.startsWith("origin")||(t||void 0!==n)&&(!!o[e]||"opacity"===e)}},93193:function(e,t,n){n.d(t,{D:function(){return r}});let r=e=>e.replace(/([a-z])([A-Z])/gu,"$1-$2").toLowerCase()},62627:function(e,t,n){n.d(t,{q:function(){return o}});let r=["animate","circle","defs","desc","ellipse","g","image","line","filter","marker","mask","metadata","path","pattern","polygon","polyline","rect","stop","switch","symbol","svg","text","tspan","use","view"];function o(e){if("string"!=typeof e||e.includes("-"));else if(r.indexOf(e)>-1||/[A-Z]/u.test(e))return!0;return!1}},41069:function(e,t,n){n.d(t,{r:function(){return s}});var r=n(59354),o=n(21219);let i=(e,t)=>t&&"number"==typeof e?t.transform(e):e;var a=n(20354);let l={x:"translateX",y:"translateY",z:"translateZ",transformPerspective:"perspective"},u=r._.length;function s(e,t,n){let{style:s,vars:c,transformOrigin:d}=e,f=!1,p=!1;for(let e in t){let n=t[e];if(r.G.has(e)){f=!0;continue}if((0,o.f)(e)){c[e]=n;continue}{let t=i(n,a.j[e]);e.startsWith("origin")?(p=!0,d[e]=t):s[e]=t}}if(!t.transform&&(f||n?s.transform=function(e,t,n){let o="",s=!0;for(let c=0;c<u;c++){let u=r._[c],d=e[u];if(void 0===d)continue;let f=!0;if(!(f="number"==typeof d?d===(u.startsWith("scale")?1:0):0===parseFloat(d))||n){let e=i(d,a.j[u]);if(!f){s=!1;let t=l[u]||u;o+=`${t}(${e}) `}n&&(t[u]=e)}}return o=o.trim(),n?o=n(t,s?"":o):s&&(o="none"),o}(t,e.transform,n):s.transform&&(s.transform="none")),p){let{originX:e="50%",originY:t="50%",originZ:n=0}=d;s.transformOrigin=`${e} ${t} ${n}`}}},50189:function(e,t,n){n.d(t,{U:function(){return i}});var r=n(32558),o=n(96728);function i(e,t,n){let{style:i}=e,a={};for(let l in i)((0,r.i)(i[l])||t.style&&(0,r.i)(t.style[l])||(0,o.j)(l,e)||n?.getValue(l)?.liveStyle!==void 0)&&(a[l]=i[l]);return a}},42617:function(e,t,n){n.d(t,{i:function(){return l}});var r=n(41069),o=n(37259);let i={offset:"stroke-dashoffset",array:"stroke-dasharray"},a={offset:"strokeDashoffset",array:"strokeDasharray"};function l(e,{attrX:t,attrY:n,attrScale:l,pathLength:u,pathSpacing:s=1,pathOffset:c=0,...d},f,p,m){if((0,r.r)(e,d,p),f){e.style.viewBox&&(e.attrs.viewBox=e.style.viewBox);return}e.attrs=e.style,e.style={};let{attrs:h,style:v}=e;h.transform&&(v.transform=h.transform,delete h.transform),(v.transform||h.transformOrigin)&&(v.transformOrigin=h.transformOrigin??"50% 50%",delete h.transformOrigin),v.transform&&(v.transformBox=m?.transformBox??"fill-box",delete h.transformBox),void 0!==t&&(h.x=t),void 0!==n&&(h.y=n),void 0!==l&&(h.scale=l),void 0!==u&&function(e,t,n=1,r=0,l=!0){e.pathLength=1;let u=l?i:a;e[u.offset]=o.px.transform(-r);let s=o.px.transform(t),c=o.px.transform(n);e[u.array]=`${s} ${c}`}(h,u,s,c,!1)}},79854:function(e,t,n){n.d(t,{a:function(){return r}});let r=e=>"string"==typeof e&&"svg"===e.toLowerCase()},16832:function(e,t,n){n.d(t,{U:function(){return a}});var r=n(32558),o=n(59354),i=n(50189);function a(e,t,n){let a=(0,i.U)(e,t,n);for(let n in e)((0,r.i)(e[n])||(0,r.i)(t[n]))&&(a[-1!==o._.indexOf(n)?"attr"+n.charAt(0).toUpperCase()+n.substring(1):n]=e[n]);return a}},7504:function(e,t,n){n.d(t,{G:function(){return a},M:function(){return l}});var r=n(2445),o=n(97732),i=n(22963);function a(e){return(0,r.H)(e.animate)||i.V.some(t=>(0,o.$)(e[t]))}function l(e){return!!(a(e)||e.variants)}},97732:function(e,t,n){n.d(t,{$:function(){return r}});function r(e){return"string"==typeof e||Array.isArray(e)}},79432:function(e,t,n){function r(e){let t=[{},{}];return e?.values.forEach((e,n)=>{t[0][n]=e.get(),t[1][n]=e.getVelocity()}),t}function o(e,t,n,o){if("function"==typeof t){let[i,a]=r(o);t=t(void 0!==n?n:e.custom,i,a)}if("string"==typeof t&&(t=e.variants&&e.variants[t]),"function"==typeof t){let[i,a]=r(o);t=t(void 0!==n?n:e.custom,i,a)}return t}n.d(t,{o:function(){return o}})},22963:function(e,t,n){n.d(t,{V:function(){return o},e:function(){return r}});let r=["animate","whileInView","whileFocus","whileHover","whileTap","whileDrag","exit"],o=["initial",...r]},11741:function(e,t,n){n.d(t,{j:function(){return r}});let r="undefined"!=typeof window},21219:function(e,t,n){n.d(t,{f:function(){return o},t:function(){return a}});let r=e=>t=>"string"==typeof t&&t.startsWith(e),o=r("--"),i=r("var(--"),a=e=>!!i(e)&&l.test(e.split("/*")[0].trim()),l=/var\(--(?:[\w-]+\s*|[\w-]+\s*,(?:\s*[^)(\s]|\s*\((?:[^)(]|\([^)(]*\))*\))+\s*)\)$/iu},93674:function(e,t,n){n.d(t,{Z:function(){return a}});var r=n(42218);let o=["setup","read","resolveKeyframes","preUpdate","update","preRender","render","postRender"];var i=n(57275);function a(e,t){let n=!1,a=!0,l={delta:0,timestamp:0,isProcessing:!1},u=()=>n=!0,s=o.reduce((e,n)=>(e[n]=function(e,t){let n=new Set,r=new Set,o=!1,a=!1,l=new WeakSet,u={delta:0,timestamp:0,isProcessing:!1},s=0;function c(t){l.has(t)&&(d.schedule(t),e()),s++,t(u)}let d={schedule:(e,t=!1,i=!1)=>{let a=i&&o?n:r;return t&&l.add(e),a.has(e)||a.add(e),e},cancel:e=>{r.delete(e),l.delete(e)},process:e=>{if(u=e,o){a=!0;return}o=!0,[n,r]=[r,n],n.forEach(c),t&&i.f.value&&i.f.value.frameloop[t].push(s),s=0,n.clear(),o=!1,a&&(a=!1,d.process(e))}};return d}(u,t?n:void 0),e),{}),{setup:c,read:d,resolveKeyframes:f,preUpdate:p,update:m,preRender:h,render:v,postRender:g}=s,b=()=>{let o=r.c.useManualTiming?l.timestamp:performance.now();n=!1,r.c.useManualTiming||(l.delta=a?1e3/60:Math.max(Math.min(o-l.timestamp,40),1)),l.timestamp=o,l.isProcessing=!0,c.process(l),d.process(l),f.process(l),p.process(l),m.process(l),h.process(l),v.process(l),g.process(l),l.isProcessing=!1,n&&t&&(a=!1,e(b))},y=()=>{n=!0,a=!0,l.isProcessing||e(b)};return{schedule:o.reduce((e,t)=>{let r=s[t];return e[t]=(e,t=!1,o=!1)=>(n||y(),r.schedule(e,t,o)),e},{}),cancel:e=>{for(let t=0;t<o.length;t++)s[o[t]].cancel(e)},state:l,steps:s}}},59354:function(e,t,n){n.d(t,{G:function(){return o},_:function(){return r}});let r=["transformPerspective","x","y","z","translateX","translateY","translateZ","scale","scaleX","scaleY","rotate","rotateX","rotateY","rotateZ","skew","skewX","skewY"],o=new Set(r)},57275:function(e,t,n){n.d(t,{f:function(){return r}});let r={value:null,addProjectionMetrics:null}},77596:function(e,t,n){n.d(t,{R:function(){return r}});function r(e){return"object"==typeof e&&null!==e&&"offsetHeight"in e}},20354:function(e,t,n){n.d(t,{j:function(){return l}});var r=n(57958);let o={...r.Rx,transform:Math.round};var i=n(37259);let a={rotate:i.RW,rotateX:i.RW,rotateY:i.RW,rotateZ:i.RW,scale:r.bA,scaleX:r.bA,scaleY:r.bA,scaleZ:r.bA,skew:i.RW,skewX:i.RW,skewY:i.RW,distance:i.px,translateX:i.px,translateY:i.px,translateZ:i.px,x:i.px,y:i.px,z:i.px,perspective:i.px,transformPerspective:i.px,opacity:r.Fq,originX:i.$C,originY:i.$C,originZ:i.px},l={borderWidth:i.px,borderTopWidth:i.px,borderRightWidth:i.px,borderBottomWidth:i.px,borderLeftWidth:i.px,borderRadius:i.px,radius:i.px,borderTopLeftRadius:i.px,borderTopRightRadius:i.px,borderBottomRightRadius:i.px,borderBottomLeftRadius:i.px,width:i.px,maxWidth:i.px,height:i.px,maxHeight:i.px,top:i.px,right:i.px,bottom:i.px,left:i.px,padding:i.px,paddingTop:i.px,paddingRight:i.px,paddingBottom:i.px,paddingLeft:i.px,margin:i.px,marginTop:i.px,marginRight:i.px,marginBottom:i.px,marginLeft:i.px,backgroundPositionX:i.px,backgroundPositionY:i.px,...a,zIndex:o,fillOpacity:r.Fq,strokeOpacity:r.Fq,numOctaves:o}},57958:function(e,t,n){n.d(t,{Fq:function(){return i},Rx:function(){return o},bA:function(){return a}});var r=n(488);let o={test:e=>"number"==typeof e,parse:parseFloat,transform:e=>e},i={...o,transform:e=>(0,r.u)(0,1,e)},a={...o,default:1}},37259:function(e,t,n){n.d(t,{$C:function(){return s},RW:function(){return o},aQ:function(){return i},px:function(){return a},vh:function(){return l},vw:function(){return u}});let r=e=>({test:t=>"string"==typeof t&&t.endsWith(e)&&1===t.split(" ").length,parse:parseFloat,transform:t=>`${t}${e}`}),o=r("deg"),i=r("%"),a=r("px"),l=r("vh"),u=r("vw"),s={...i,parse:e=>i.parse(e)/100,transform:e=>i.transform(100*e)}},32558:function(e,t,n){n.d(t,{i:function(){return r}});let r=e=>!!(e&&e.getVelocity)},488:function(e,t,n){n.d(t,{u:function(){return r}});let r=(e,t,n)=>n>t?t:n<e?e:n},42218:function(e,t,n){n.d(t,{c:function(){return r}});let r={}},11886:function(e,t,n){var r;function o(e){let t=Object.prototype.toString.call(e);return e instanceof Date||"object"==typeof e&&"[object Date]"===t?new e.constructor(+e):new Date("number"==typeof e||"[object Number]"===t||"string"==typeof e||"[object String]"===t?e:NaN)}function i(e,t){let n=o(e),r=o(t),i=n.getTime()-r.getTime();return i<0?-1:i>0?1:i}n.d(t,{B:function(){return h}});let a={lessThanXSeconds:{one:"less than a second",other:"less than {{count}} seconds"},xSeconds:{one:"1 second",other:"{{count}} seconds"},halfAMinute:"half a minute",lessThanXMinutes:{one:"less than a minute",other:"less than {{count}} minutes"},xMinutes:{one:"1 minute",other:"{{count}} minutes"},aboutXHours:{one:"about 1 hour",other:"about {{count}} hours"},xHours:{one:"1 hour",other:"{{count}} hours"},xDays:{one:"1 day",other:"{{count}} days"},aboutXWeeks:{one:"about 1 week",other:"about {{count}} weeks"},xWeeks:{one:"1 week",other:"{{count}} weeks"},aboutXMonths:{one:"about 1 month",other:"about {{count}} months"},xMonths:{one:"1 month",other:"{{count}} months"},aboutXYears:{one:"about 1 year",other:"about {{count}} years"},xYears:{one:"1 year",other:"{{count}} years"},overXYears:{one:"over 1 year",other:"over {{count}} years"},almostXYears:{one:"almost 1 year",other:"almost {{count}} years"}};function l(e){return function(){let t=arguments.length>0&&void 0!==arguments[0]?arguments[0]:{},n=t.width?String(t.width):e.defaultWidth;return e.formats[n]||e.formats[e.defaultWidth]}}let u={date:l({formats:{full:"EEEE, MMMM do, y",long:"MMMM do, y",medium:"MMM d, y",short:"MM/dd/yyyy"},defaultWidth:"full"}),time:l({formats:{full:"h:mm:ss a zzzz",long:"h:mm:ss a z",medium:"h:mm:ss a",short:"h:mm a"},defaultWidth:"full"}),dateTime:l({formats:{full:"{{date}} 'at' {{time}}",long:"{{date}} 'at' {{time}}",medium:"{{date}}, {{time}}",short:"{{date}}, {{time}}"},defaultWidth:"full"})},s={lastWeek:"'last' eeee 'at' p",yesterday:"'yesterday at' p",today:"'today at' p",tomorrow:"'tomorrow at' p",nextWeek:"eeee 'at' p",other:"P"};function c(e){return(t,n)=>{let r;if("formatting"===((null==n?void 0:n.context)?String(n.context):"standalone")&&e.formattingValues){let t=e.defaultFormattingWidth||e.defaultWidth,o=(null==n?void 0:n.width)?String(n.width):t;r=e.formattingValues[o]||e.formattingValues[t]}else{let t=e.defaultWidth,o=(null==n?void 0:n.width)?String(n.width):e.defaultWidth;r=e.values[o]||e.values[t]}return r[e.argumentCallback?e.argumentCallback(t):t]}}function d(e){return function(t){let n,r=arguments.length>1&&void 0!==arguments[1]?arguments[1]:{},o=r.width,i=o&&e.matchPatterns[o]||e.matchPatterns[e.defaultMatchWidth],a=t.match(i);if(!a)return null;let l=a[0],u=o&&e.parsePatterns[o]||e.parsePatterns[e.defaultParseWidth],s=Array.isArray(u)?function(e,t){for(let n=0;n<e.length;n++)if(t(e[n]))return n}(u,e=>e.test(l)):function(e,t){for(let n in e)if(Object.prototype.hasOwnProperty.call(e,n)&&t(e[n]))return n}(u,e=>e.test(l));return n=e.valueCallback?e.valueCallback(s):s,{value:n=r.valueCallback?r.valueCallback(n):n,rest:t.slice(l.length)}}}let f={code:"en-US",formatDistance:(e,t,n)=>{let r;let o=a[e];return(r="string"==typeof o?o:1===t?o.one:o.other.replace("{{count}}",t.toString()),null==n?void 0:n.addSuffix)?n.comparison&&n.comparison>0?"in "+r:r+" ago":r},formatLong:u,formatRelative:(e,t,n,r)=>s[e],localize:{ordinalNumber:(e,t)=>{let n=Number(e),r=n%100;if(r>20||r<10)switch(r%10){case 1:return n+"st";case 2:return n+"nd";case 3:return n+"rd"}return n+"th"},era:c({values:{narrow:["B","A"],abbreviated:["BC","AD"],wide:["Before Christ","Anno Domini"]},defaultWidth:"wide"}),quarter:c({values:{narrow:["1","2","3","4"],abbreviated:["Q1","Q2","Q3","Q4"],wide:["1st quarter","2nd quarter","3rd quarter","4th quarter"]},defaultWidth:"wide",argumentCallback:e=>e-1}),month:c({values:{narrow:["J","F","M","A","M","J","J","A","S","O","N","D"],abbreviated:["Jan","Feb","Mar","Apr","May","Jun","Jul","Aug","Sep","Oct","Nov","Dec"],wide:["January","February","March","April","May","June","July","August","September","October","November","December"]},defaultWidth:"wide"}),day:c({values:{narrow:["S","M","T","W","T","F","S"],short:["Su","Mo","Tu","We","Th","Fr","Sa"],abbreviated:["Sun","Mon","Tue","Wed","Thu","Fri","Sat"],wide:["Sunday","Monday","Tuesday","Wednesday","Thursday","Friday","Saturday"]},defaultWidth:"wide"}),dayPeriod:c({values:{narrow:{am:"a",pm:"p",midnight:"mi",noon:"n",morning:"morning",afternoon:"afternoon",evening:"evening",night:"night"},abbreviated:{am:"AM",pm:"PM",midnight:"midnight",noon:"noon",morning:"morning",afternoon:"afternoon",evening:"evening",night:"night"},wide:{am:"a.m.",pm:"p.m.",midnight:"midnight",noon:"noon",morning:"morning",afternoon:"afternoon",evening:"evening",night:"night"}},defaultWidth:"wide",formattingValues:{narrow:{am:"a",pm:"p",midnight:"mi",noon:"n",morning:"in the morning",afternoon:"in the afternoon",evening:"in the evening",night:"at night"},abbreviated:{am:"AM",pm:"PM",midnight:"midnight",noon:"noon",morning:"in the morning",afternoon:"in the afternoon",evening:"in the evening",night:"at night"},wide:{am:"a.m.",pm:"p.m.",midnight:"midnight",noon:"noon",morning:"in the morning",afternoon:"in the afternoon",evening:"in the evening",night:"at night"}},defaultFormattingWidth:"wide"})},match:{ordinalNumber:(r={matchPattern:/^(\d+)(th|st|nd|rd)?/i,parsePattern:/\d+/i,valueCallback:e=>parseInt(e,10)},function(e){let t=arguments.length>1&&void 0!==arguments[1]?arguments[1]:{},n=e.match(r.matchPattern);if(!n)return null;let o=n[0],i=e.match(r.parsePattern);if(!i)return null;let a=r.valueCallback?r.valueCallback(i[0]):i[0];return{value:a=t.valueCallback?t.valueCallback(a):a,rest:e.slice(o.length)}}),era:d({matchPatterns:{narrow:/^(b|a)/i,abbreviated:/^(b\.?\s?c\.?|b\.?\s?c\.?\s?e\.?|a\.?\s?d\.?|c\.?\s?e\.?)/i,wide:/^(before christ|before common era|anno domini|common era)/i},defaultMatchWidth:"wide",parsePatterns:{any:[/^b/i,/^(a|c)/i]},defaultParseWidth:"any"}),quarter:d({matchPatterns:{narrow:/^[1234]/i,abbreviated:/^q[1234]/i,wide:/^[1234](th|st|nd|rd)? quarter/i},defaultMatchWidth:"wide",parsePatterns:{any:[/1/i,/2/i,/3/i,/4/i]},defaultParseWidth:"any",valueCallback:e=>e+1}),month:d({matchPatterns:{narrow:/^[jfmasond]/i,abbreviated:/^(jan|feb|mar|apr|may|jun|jul|aug|sep|oct|nov|dec)/i,wide:/^(january|february|march|april|may|june|july|august|september|october|november|december)/i},defaultMatchWidth:"wide",parsePatterns:{narrow:[/^j/i,/^f/i,/^m/i,/^a/i,/^m/i,/^j/i,/^j/i,/^a/i,/^s/i,/^o/i,/^n/i,/^d/i],any:[/^ja/i,/^f/i,/^mar/i,/^ap/i,/^may/i,/^jun/i,/^jul/i,/^au/i,/^s/i,/^o/i,/^n/i,/^d/i]},defaultParseWidth:"any"}),day:d({matchPatterns:{narrow:/^[smtwf]/i,short:/^(su|mo|tu|we|th|fr|sa)/i,abbreviated:/^(sun|mon|tue|wed|thu|fri|sat)/i,wide:/^(sunday|monday|tuesday|wednesday|thursday|friday|saturday)/i},defaultMatchWidth:"wide",parsePatterns:{narrow:[/^s/i,/^m/i,/^t/i,/^w/i,/^t/i,/^f/i,/^s/i],any:[/^su/i,/^m/i,/^tu/i,/^w/i,/^th/i,/^f/i,/^sa/i]},defaultParseWidth:"any"}),dayPeriod:d({matchPatterns:{narrow:/^(a|p|mi|n|(in the|at) (morning|afternoon|evening|night))/i,any:/^([ap]\.?\s?m\.?|midnight|noon|(in the|at) (morning|afternoon|evening|night))/i},defaultMatchWidth:"any",parsePatterns:{any:{am:/^a/i,pm:/^p/i,midnight:/^mi/i,noon:/^no/i,morning:/morning/i,afternoon:/afternoon/i,evening:/evening/i,night:/night/i}},defaultParseWidth:"any"})},options:{weekStartsOn:0,firstWeekContainsDate:1}},p={};function m(e){let t=o(e),n=new Date(Date.UTC(t.getFullYear(),t.getMonth(),t.getDate(),t.getHours(),t.getMinutes(),t.getSeconds(),t.getMilliseconds()));return n.setUTCFullYear(t.getFullYear()),+e-+n}function h(e,t,n){var r,a,l,u,s,c;let d,h,v;let g=null!==(a=null!==(r=null==n?void 0:n.locale)&&void 0!==r?r:p.locale)&&void 0!==a?a:f,b=i(e,t);if(isNaN(b))throw RangeError("Invalid time value");let y=Object.assign({},n,{addSuffix:null==n?void 0:n.addSuffix,comparison:b});b>0?(d=o(t),h=o(e)):(d=o(e),h=o(t));let w=(l=h,u=d,(c=null==void 0?void 0:(void 0).roundingMethod,e=>{let t=(c?Math[c]:Math.trunc)(e);return 0===t?0:t})((+o(l)-+o(u))/1e3)),x=Math.round((w-(m(h)-m(d))/1e3)/60);if(x<2){if(null==n?void 0:n.includeSeconds){if(w<5)return g.formatDistance("lessThanXSeconds",5,y);if(w<10)return g.formatDistance("lessThanXSeconds",10,y);if(w<20)return g.formatDistance("lessThanXSeconds",20,y);if(w<40)return g.formatDistance("halfAMinute",0,y);else if(w<60)return g.formatDistance("lessThanXMinutes",1,y);else return g.formatDistance("xMinutes",1,y)}return 0===x?g.formatDistance("lessThanXMinutes",1,y):g.formatDistance("xMinutes",x,y)}if(x<45)return g.formatDistance("xMinutes",x,y);if(x<90)return g.formatDistance("aboutXHours",1,y);if(x<1440)return g.formatDistance("aboutXHours",Math.round(x/60),y);if(x<2520)return g.formatDistance("xDays",1,y);if(x<43200)return g.formatDistance("xDays",Math.round(x/1440),y);if(x<86400)return v=Math.round(x/43200),g.formatDistance("aboutXMonths",v,y);if((v=function(e,t){let n;let r=o(e),a=o(t),l=i(r,a),u=Math.abs(function(e,t){let n=o(e),r=o(t);return 12*(n.getFullYear()-r.getFullYear())+(n.getMonth()-r.getMonth())}(r,a));if(u<1)n=0;else{1===r.getMonth()&&r.getDate()>27&&r.setDate(30),r.setMonth(r.getMonth()-l*u);let t=i(r,a)===-l;(function(e){let t=o(e);return+function(e){let t=o(e);return t.setHours(23,59,59,999),t}(t)==+function(e){let t=o(e),n=t.getMonth();return t.setFullYear(t.getFullYear(),n+1,0),t.setHours(23,59,59,999),t}(t)})(o(e))&&1===u&&1===i(e,a)&&(t=!1),n=l*(u-Number(t))}return 0===n?0:n}(h,d))<12)return g.formatDistance("xMonths",Math.round(x/43200),y);{let e=v%12,t=Math.trunc(v/12);return e<3?g.formatDistance("aboutXYears",t,y):e<9?g.formatDistance("overXYears",t,y):g.formatDistance("almostXYears",t+1,y)}}}}]);